<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  4121 => 'Losanna',
  4122 => 'Ginevra',
  4126 => 'Friburgo',
  4131 => 'Berna',
  4132 => 'Bienne/Neuchâtel/Soletta/Giura',
  4141 => 'Lucerna',
  4143 => 'Zurigo',
  4144 => 'Zurigo',
  4161 => 'Basilea',
  4171 => 'San Gallo',
  4181 => 'Coira',
);
