<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  5993180 => 'St. Eustatius',
  5993182 => 'St. Eustatius',
  5993183 => 'St. Eustatius',
  5994160 => 'Saba',
  5994162 => 'Saba',
  5994163 => 'Saba',
  599417 => 'Saba',
  59971 => 'Bonaire',
  59972 => 'Bonaire',
  59975 => 'Bonaire',
);
