<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  6875 => 'OPT-NC',
  6877 => 'OPT-NC',
  68780 => 'OPT-NC',
  68781 => 'OPT-NC',
  68782 => 'OPT-NC',
  68783 => 'OPT-NC',
  68784 => 'OPT-NC',
  68785 => 'OPT-NC',
  68786 => 'OPT-NC',
  68787 => 'OPT-NC',
  68789 => 'OPT-NC',
  6879 => 'OPT-NC',
);
