<?php
namespace Aws\RecycleBin\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Recycle Bin** service.
 */
class RecycleBinException extends AwsException {}
