<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    /*
    |--------------------------------------------------------------------------
    | Authentication Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'failed' => 'Thông tin đăng nhập không đúng.',
    'throttle' => 'Đăng nhập thất bại nhiều lần. Vui lòng thử lại sau :seconds.',
    'not_authorized' => 'Bạn không có quyền thực hiện hành động này',
    'signup_disabled' => 'Việc đăng kí đang bị tạm dừng',
    'signup_error' => 'Có lỗi xảy ra khi đăng kí tài khoản',
    'back_homepage' => 'Quay lại trang chủ',
    'mfa_auth_otp' => 'Xác thực với xác thực hai yếu tố',
    'mfa_auth_webauthn' => 'Xác thực với khóa bảo mật (WebAuthn)',
    '2fa_title' => 'Xác minh 2 bước',
    '2fa_wrong_validation' => 'Xác thực hai bước thất bại.',
    '2fa_one_time_password' => 'Mã xác thực hai bước',
    '2fa_recuperation_code' => 'Nhập mã khôi phục hai bước',
    '2fa_one_time_or_recuperation' => 'Nhập mã xác thực hoặc khôi phục hai bước',
    '2fa_otp_help' => 'Mở ứng dụng mã xác thực hai bước và copy mã',

    'login_to_account' => 'Đăng nhập vào tài khoản của bạn',
    'login_with_recovery' => 'Đăng nhập với mã khôi phục',
    'login_again' => 'Hãy đăng nhập lại vào tài khoản của bạn',
    'email' => 'Email',
    'password' => 'Mật khẩu',
    'recovery' => 'Mã khôi phục',
    'login' => 'Đăng nhập',
    'button_remember' => 'Ghi nhớ đăng nhập',
    'password_forget' => 'Quên mật khẩu?',
    'password_reset' => 'Đặt lại mật khẩu',
    'use_recovery' => 'Hoặc bạn có thể dùng <a href=":url">mã khôi phục</a>',
    'signup_no_account' => 'Chưa có tài khoản?',
    'signup' => 'Đăng ký',
    'create_account' => 'Tạo tài khoản đầu tiên bằng cách <a href=":url">đăng ký</a>',
    'change_language_title' => 'Đổi ngôn ngữ:',
    'change_language' => 'Đổi ngôn ngữ thành :lang',

    'password_reset_title' => 'Đặt lại mật khẩu',
    'password_reset_email' => 'Địa chỉ E-Mail',
    'password_reset_send_link' => 'Gửi liên kết đặt lại mật khẩu',
    'password_reset_password' => 'Mật khẩu',
    'password_reset_password_confirm' => 'Xác nhận mật khẩu',
    'password_reset_action' => 'Đặt lại mật khẩu',
    'password_reset_email_content' => 'Nhấn vào đây để đặt lại mật khẩu của bạn:',

    'register_title_welcome' => 'Chào mừng bạn đến với hệ thống Monica mới cài đặt',
    'register_create_account' => 'Bạn cần tạo tài khoản để sử dụng Monica',
    'register_title_create' => 'Tạo tài khoản Monica của bạn',
    'register_login' => '<a href=":url">Đăng nhập</a> nếu bạn đã có tài khoản.',
    'register_email' => 'Nhập địa chỉ email hợp lệ',
    'register_email_example' => 'you@home',
    'register_firstname' => 'Tên',
    'register_firstname_example' => 'ví dụ: Dũng',
    'register_lastname' => 'Họ',
    'register_lastname_example' => 'eg. Nguyễn',
    'register_password' => 'Mật khẩu',
    'register_password_example' => 'Nhập mật khẩu bảo mật',
    'register_password_confirmation' => 'Xác nhận mật khẩu',
    'register_action' => 'Đăng kí',
    'register_policy' => 'Đăng kí có nghĩa là bạn đã đọc và đồng ý với <a href=":url" hreflang=":hreflang">Điều khoản bảo mật</a> và <a href=":urlterm" hreflang=":hreflang">Thỏa thuận sử dụng</a>.',
    'register_invitation_email' => 'Vì mục đích bảo mật, vui lòng cho biết email của người đã mời bạn tham gia tài khoản này. Thông tin này được cung cấp trong email mời.',

    'confirmation_title' => 'Kiểm tra lại địa chỉ e-mail',
    'confirmation_fresh' => 'Một liên kết xác nhận mới đã được gửi vào địa chỉ email của bạn.',
    'confirmation_check' => 'Trước khi tiếp tục, hãy kiểm tra email của bạn cho liên kết xác thực.',
    'confirmation_request_another' => 'Nếu bạn không nhận được email  <a :action>bấm vào đây để yêu cầu một email khác</a>.',

    'confirmation_again' => 'Nếu bạn muốn đổi địa chỉ email, bạn có thể <a href=":url" class="alert-link">bấm vào đây</a>.',
    'email_change_current_email' => 'Địa chỉ email hiện tại:',
    'email_change_title' => 'Đổi địa chỉ email',
    'email_change_new' => 'Địa chỉ email mới',
    'email_changed' => 'Địa chỉ email của bạn đã được thay đổi. Hãy kiểm tra hòm thư để xác nhận lại.',
];
