<?php
namespace Aws\EKSAuth\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon EKS Auth** service.
 */
class EKSAuthException extends AwsException {}
