<?php
namespace Aws\Bedrock\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Bedrock** service.
 */
class BedrockException extends AwsException {}
