<?php
namespace Aws\ChimeSDKMessaging\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Chime SDK Messaging** service.
 */
class ChimeSDKMessagingException extends AwsException {}
