<?php
namespace Aws\CleanRoomsML\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **cleanrooms-ml** service.
 */
class CleanRoomsMLException extends AwsException {}
