<?php
namespace Aws\DeviceFarm\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Amazon DeviceFarm service.
 */
class DeviceFarmException extends AwsException {}