<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    //index
    'people_not_found' => 'Δεν βρέθηκε η επαφή',
    'people_list_number_kids' => ':count παιδί|:count παιδιά',
    'people_list_last_updated' => 'Συμβουλευτήκατε τελευταία:',
    'people_list_number_reminders' => ':count υπενθύμιση|:count υπενθυμίσεις',
    'people_list_blank_title' => 'Δεν υπάρχει κάποια επαφή στον λογαριασμό σας ακόμη',
    'people_list_blank_cta' => 'Προσθέστε κάποιον',
    'people_list_sort' => 'Ταξινόμηση',
    'people_list_stats' => ':count επαφή|:count επαφές',
    'people_list_firstnameAZ' => 'Ταξινόμηση με Όνομα Α → Ω',
    'people_list_firstnameZA' => 'Ταξινόμηση με Όνομα Ω → Α',
    'people_list_lastnameAZ' => 'Ταξινόμηση με Επώνυμο Α → Ω',
    'people_list_lastnameZA' => 'Ταξινόμηση με Επώνυμο Ω → Α',
    'people_list_lastactivitydateNewtoOld' => 'Ταξινόμηση κατά την τελευταία ημερομηνία δραστηριότητας, νεότερη έως παλαιότερη',
    'people_list_lastactivitydateOldtoNew' => 'Ταξινόμηση κατά την τελευταία ημερομηνία δραστηριότητας, παλαιότερη έως νεότερη',
    'people_list_filter_tag' => 'Εμφάνιση όλων των επαφών με ετικέτα',
    'people_list_clear_filter' => 'Κατάργηση φίλτρου',
    'people_list_contacts_per_tags' => ':count επαφή|:count επαφές',
    'people_list_show_dead' => 'Εμφάνιση θανόντων (:count)',
    'people_list_hide_dead' => 'Απόκρυψη θανόντων (:count)',
    'people_search' => 'Αναζήτηση στις επαφές σας…',
    'people_search_no_results' => 'Δε βρέθηκαν αποτελέσματα',
    'people_search_next' => 'Επόμενο',
    'people_search_prev' => 'Προηγούμενο',
    'people_search_rows_per_page' => 'Γραμμές ανά σελίδα',
    'people_search_of' => 'από',
    'people_search_page' => 'Σελίδα',
    'people_search_all' => 'Όλα',
    'people_add_new' => 'Προσθήκη νέου ατόμου',
    'people_list_account_usage' => 'Χρήση του λογαριασμού σας: :current/:limit επαφές',
    'people_list_account_upgrade_title' => 'Αναβαθμίστε τον λογαριασμό σας για να ξεκλειδώσετε όλες τις δυνατότητες του.',
    'people_list_account_upgrade_cta' => 'Αναβάθμιση τώρα',
    'people_list_untagged' => 'Εμφάνιση επαφών χωρίς ετικέτα',
    'people_list_filter_untag' => 'Εμφάνιση όλων των επαφών χωρίς ετικέτες',
    'archived_contact_readonly' => 'Δεν είναι δυνατή η επεξεργασία της αρχειοθετημένης επαφής, παρακαλώ επαναφέρετε την επαφή πρώτα.',

    // people add
    'people_add_title' => 'Προσθήκη νέου ατόμου',
    'people_add_missing' => 'Δεν βρέθηκε άτομο – προσθέστε ένα νέο τώρα',
    'people_add_firstname' => 'Όνομα',
    'people_add_middlename' => 'Μεσαίο όνομα (προαιρετικό)',
    'people_add_lastname' => 'Επίθετο (προαιρετικό)',
    'people_add_email' => 'Email (προαιρετικό)',
    'people_add_nickname' => 'Ψευδώνυμο (προαιρετικό)',
    'people_add_cta' => 'Προσθήκη',
    'people_save_and_add_another_cta' => 'Αποθήκευση και προσθήκη νέου',
    'people_add_success' => 'Η επαφή :name δημιουργήθηκε με επιτυχία',
    'people_add_gender' => 'Φύλο',
    'people_delete_success' => 'Η επαφή έχει διαγραφεί',
    'people_delete_message' => 'Διαγραφή επαφής',
    'people_delete_confirmation' => 'Είστε σίγουροι ότι θέλετε να διαγράψετε την επαφή :name; Η διαγραφή είναι άμεση και μόνιμη.',
    'people_add_birthday_reminder' => 'Ευχηθείτε χρόνια πολλά στον :name',
    'people_add_birthday_reminder_deceased' => 'Την ημερομηνία αυτή, η επαφή :name, θα είχε γενέθλια',
    'people_add_import' => 'Θέλετε να <a href=":url">εισαγάγετε τις επαφές σας</a>;',
    'people_edit_email_error' => 'Μία επαφή με αυτή τη διεύθυνση email υπάρχει ήδη στον λογαριασμό σας. Παρακαλώ διαλέξτε μία άλλη.',
    'people_export' => 'Εξαγωγή ως vCard',
    'people_add_reminder_for_birthday' => 'Δημιουργία ετήσιας υπενθύμισης γενεθλίων',

    // show
    'section_contact_information' => 'Πληροφορίες επικοινωνίας',
    'section_personal_activities' => 'Δραστηριότητες',
    'section_personal_reminders' => 'Υπενθυμίσεις',
    'section_personal_tasks' => 'Εργασίες',
    'section_personal_gifts' => 'Δώρα',
    'section_personal_notes' => 'Σημειώσεις',

    // archived contacts
    'list_link_to_active_contacts' => 'Βλέπετε τις αρχειοθετημένες επαφές. Κάντε κλικ <a href=":url">εδώ</a> για να δείτε τη λίστα με τις ενεργές επαφές.',
    'list_link_to_archived_contacts' => 'Λίστα αρχειοθετημένων επαφών',

    // Header
    'me' => 'Αυτός είσαι εσύ',
    'edit_contact_information' => 'Επεξεργασία πληροφοριών επικοινωνίας',
    'contact_archive' => 'Αρχειοθέτηση επαφής',
    'contact_unarchive' => 'Ανάκληση αρχειοθέτησης επαφής',
    'contact_archive_help' => 'Οι αρχειοθετημένες επαφές δεν εμφανίζονται στη λίστα επαφών, αλλά εξακολουθούν να εμφανίζονται στα αποτελέσματα αναζήτησης.',
    'call_button' => 'Καταχώρηση κλήσης',
    'set_favorite' => 'Οι αγαπημένες επαφές εμφανίζονται στο πάνω μέρος της λίστας επαφών',

    // Stay in touch
    'stay_in_touch' => 'Μείνετε σε επαφή',
    'stay_in_touch_frequency' => 'Μείνετε σε επαφή κάθε μέρα|Μείνετε σε επαφή κάθε {count} μέρες',
    'stay_in_touch_next_date' => 'Επόμενη φορά: {date}',
    'stay_in_touch_invalid' => 'Η συχνότητα πρέπει να είναι ένας αριθμός μεγαλύτερος του 0.',
    'stay_in_touch_premium' => 'Πρέπει να κάνετε αναβάθμιση του λογαριασμού για να χρησιμοποιήσετε αυτή τη δυνατότητα',
    'stay_in_touch_modal_title' => 'Μείνετε σε επαφή',
    'stay_in_touch_modal_desc' => 'Μπορούμε να σας υπενθυμίζουμε με email να μείνετε σε επαφή με την επαφή {firstname} σε σταθερό ρυθμό.',
    'stay_in_touch_modal_label' => 'Στείλε μου email κάθε… {count} μέρα|Στείλε μου email κάθε… {count} μέρες',

    // Calls
    'modal_call_title' => 'Καταχώρηση κλήσης',
    'modal_call_comment' => 'Για τι μιλήσατε; (προαιρετικό)',
    'modal_call_exact_date' => 'Το τηλεφώνημα έγινε στις',
    'modal_call_who_called' => 'Ποιός πήρε τηλέφωνο;',
    'modal_call_emotion' => 'Θέλετε να καταχωρήσετε το πως νιώσατε κατά τη διάρκεια του τηλεφωνήματος; (προαιρετικό)',
    'calls_add_success' => 'Η εγγραφή αποθηκεύτηκε.',
    'call_delete_confirmation' => 'Είστε σίγουροι ότι θέλετε να διαγράψετε την εγγραφή;',
    'call_delete_success' => 'Η εγγραφή έχει διαγραφεί με επιτυχία',
    'call_title' => 'Τηλεφωνικές κλήσεις',
    'call_empty_comment' => 'Δεν υπάρχουν λεπτομέρειες',
    'call_blank_title' => 'Παρακολουθήστε τις τηλεφωνικές κλήσεις που έχετε πραγματοποιήσει με την επαφή {name}',
    'call_blank_desc' => 'Κλήση σε {name}',
    'call_you_called' => 'Καλέσατε εσείς',
    'call_he_called' => 'κάλεσε η επαφή {name}',
    'call_emotions' => 'Συναισθήματα:',

    // Conversation
    'conversation_blank' => 'Καταγράψτε τις συνομιλίες σας με :name στα μέσα κοινωνικής δικτύωσης, SMS…',
    'conversation_delete_link' => 'Διαγραφή της συνομιλίας',
    'conversation_edit_title' => 'Επεξεργασία της συνομιλίας',
    'conversation_edit_delete' => 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την επαφή; Δεν γίνεται αναίρεση.',
    'conversation_add_success' => 'Η συνομιλία προστέθηκε με επιτυχία.',
    'conversation_edit_success' => 'Η συνομιλία ενημερώθηκε με επιτυχία.',
    'conversation_delete_success' => 'Η συνομιλία έχει διαγραφεί επιτυχώς.',
    'conversation_add_title' => 'Εγγραφή μιας νέας συνομιλίας',
    'conversation_add_when' => 'Πότε είχατε αυτή τη συνομιλία;',
    'conversation_add_who_wrote' => 'Ποιος έστειλε αυτό το μήνυμα;',
    'conversation_add_how' => 'Πώς επικοινωνήσατε;',
    'conversation_add_you' => 'Εσείς',
    'conversation_add_content' => 'Γράψτε τι ειπώθηκε',
    'conversation_add_what_was_said' => 'Τι είπατε;',
    'conversation_add_another' => 'Προσθέστε άλλο ένα μήνυμα',
    'conversation_add_error' => 'Πρέπει να προσθέσετε τουλάχιστον ένα μήνυμα.',
    'conversation_list_table_messages' => 'Μυνήματα',
    'conversation_list_table_content' => 'Μερικό περιεχόμενο (τελευταίο μήνυμα)',
    'conversation_list_title' => 'Συνομιλίες',
    'conversation_list_cta' => 'Καταγράψτε μία συνομιλία',

    // age - birthday
    'birthdate_not_set' => 'Δεν έχει οριστεί ημέρα γενεθλίων',
    'age_approximate_in_years' => 'περίπου :age ετών',
    'age_exact_in_years' => ':age ετών',
    'age_exact_birthdate' => 'γεννήθηκε :date',

    // Last called
    'last_called' => 'Τελευταία κλήση: :date',
    'last_talked_to' => 'Τελευταία κλήση: {date}',
    'last_called_empty' => 'Τελευταία κλήση: άγνωστο',
    'last_activity_date' => 'Τελευταία δραστηριότητα μαζί: :date',
    'last_activity_date_empty' => 'Τελευταία δραστηριότητα μαζί: άγνωστο',

    // additional information
    'information_edit_success' => 'Προφίλ έχει ενημερωθεί με επιτυχία',
    'information_edit_title' => 'Επεξεργαστείτε τις προσωπικές πληροφορίες της επαφής :name',
    'information_edit_max_size' => 'Μέγιστο :size Kb.',
    'information_edit_max_size2' => 'Μέγιστο {size} Kb.',
    'information_edit_firstname' => 'Όνομα',
    'information_edit_lastname' => 'Επίθετο (προαιρετικό)',
    'information_edit_description' => 'Περιγραφή (προαιρετική)',
    'information_edit_description_help' => 'Χρησιμοποιείται στη λίστα επαφών για να προσθέσετε κάποια διευκρίνιση, εάν είναι απαραίτητη.',
    'information_edit_unknown' => 'Δεν γνωρίζω την ηλικία αυτού του ατόμου',
    'information_edit_probably' => 'Αυτό το άτομο είναι περίπου…',
    'information_edit_not_year' => 'Ξέρω την ημέρα και το μήνα των γενεθλίων αυτού του ατόμου, αλλά όχι το έτος…',
    'information_edit_exact' => 'Γνωρίζω τα ακριβή γενέθλια αυτού του ατόμου…',
    'information_edit_birthdate_label' => 'Ημερομηνία γέννησης',
    'information_no_work_defined' => 'Δεν έχουν προσδιοριστεί πληροφορίες εργασίας',
    'information_work_at' => 'στο :company',
    'work_add_cta' => 'Ενημέρωση πληροφοριών εργασίας',
    'work_edit_success' => 'Οι πληροφορίες εργασίας ενημερώθηκαν',
    'work_edit_title' => 'Ενημέρωση πληροφοριών εργασίας της επαφής :name',
    'work_edit_job' => 'Επαγγελματικός τίτλος (προαιρετικό)',
    'work_edit_company' => 'Εταιρεία (προαιρετικό)',
    'work_information' => 'Πληροφορίες εργασίας',

    // food preferences
    'food_preferences_add_success' => 'Οι διατροφικές προτιμήσεις έχουν αποθηκευτεί',
    'food_preferences_edit_description' => 'Ίσως η επαφή με το όνομα :firstname ή κάποιος άλλος στην οικογένεια :family να έχει αλλεργία. Ή δεν του αρέσει ένα συγκεκριμένο μπουκάλι κρασί. Σημειώστε το εδώ για να το θυμάστε την επόμενη φορά που θα τους καλέσετε για δείπνο',
    'food_preferences_edit_description_no_last_name' => 'Ίσως η επαφή με το όνομα :firstname να έχει αλλεργία. Ή δεν του αρέσει ένα συγκεκριμένο μπουκάλι κρασί. Σημειώστε το εδώ για να το θυμάστε την επόμενη φορά που θα τον καλέσετε για δείπνο',
    'food_preferences_edit_title' => 'Προσδιορίστε τις διατροφικές προτιμήσεις',
    'food_preferences_edit_cta' => 'Αποθήκευση διατροφικών προτιμήσεων',
    'food_preferences_title' => 'Διατροφικές προτιμήσεις',
    'food_preferences_cta' => 'Προσθήκη διατροφικών προτιμήσεων',

    // reminders
    'reminders_blank_title' => 'Υπάρχει κάτι που θέλετε να σας υπενθυμίσουμε για το άτομο :name;',
    'reminders_blank_add_activity' => 'Προσθήκη υπενθύμισης',
    'reminders_add_title' => 'Τι θα θέλατε να σας υπενθυμίσουμε για το άτομο :name;',
    'reminders_add_description' => 'Παρακαλώ υπενθυμίστε μου να…',
    'reminders_add_next_time' => 'Πότε είναι η επόμενη φορά που θα θέλατε να σας το υπενθυμίσουμε;',
    'reminders_add_once' => 'Υπενθύμιση γι\' αυτό μόνο μία φορά',
    'reminders_add_recurrent' => 'Υπενθύμιση για αυτό κάθε',
    'reminders_add_starting_from' => 'ξεκινώντας από την παραπάνω ημερομηνία',
    'reminders_add_cta' => 'Προσθήκη υπενθύμισης',
    'reminders_edit_update_cta' => 'Ενημερώση υπενθύμισης',
    'reminders_add_error_custom_text' => 'Πρέπει να υποδείξετε ένα κείμενο για αυτήν την υπενθύμιση',
    'reminders_create_success' => 'Η υπενθύμιση προστέθηκε με επιτυχία',
    'reminders_delete_success' => 'Η υπενθύμιση έχει διαγραφεί με επιτυχία',
    'reminders_update_success' => 'Η υπενθύμιση έχει ενημερωθεί με επιτυχία',
    'reminders_add_optional_comment' => 'Προαιρετικό σχόλιο',

    'reminder_frequency_day' => 'κάθε μέρα|κάθε :number μέρες',
    'reminder_frequency_week' => 'κάθε εβδομάδα|κάθε :number εβδομάδες',
    'reminder_frequency_month' => 'κάθε μήνα|κάθε :number μήνες',
    'reminder_frequency_year' => 'κάθε έτος|κάθε :number έτη',
    'reminder_frequency_one_time' => 'στις :date',
    'reminders_delete_confirmation' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτήν την υπενθύμιση;',
    'reminders_delete_cta' => 'Διαγραφή',
    'reminders_next_expected_date' => 'στις',
    'reminders_cta' => 'Προσθήκη υπενθύμισης',
    'reminders_description' => 'Θα στείλουμε ένα μήνυμα ηλεκτρονικού ταχυδρομείου για κάθε μία από τις υπενθυμίσεις παρακάτω. Οι υπενθυμίσεις αποστέλλονται κάθε πρωί την ημέρα που θα συμβούν γεγονότα. Οι υπενθυμίσεις που προστίθενται αυτόματα για τα γενέθλια δεν μπορούν να διαγραφούν. Αν θέλετε να αλλάξετε αυτές τις ημερομηνίες, επεξεργαστείτε τα γενέθλια των επαφών.',
    'reminders_one_time' => 'Μία φορά',
    'reminders_type_week' => 'εβδομάδα',
    'reminders_type_month' => 'μήνας',
    'reminders_type_year' => 'έτος',
    'reminders_birthday' => 'Γενέθλια του ατόμου :name',
    'reminders_free_plan_warning' => 'Είστε στο δωρεάν πρόγραμμα. Δεν αποστέλλονται μηνύματα ηλεκτρονικού ταχυδρομείου σε αυτό το σχέδιο. Για να λάβετε τις υπενθυμίσεις σας μέσω ηλεκτρονικού ταχυδρομείου, αναβαθμίστε το λογαριασμό σας.',

    // relationships
    'relationship_form_add' => 'Προσθήκη σχέσης',
    'relationship_form_edit' => 'Επεξεργασία υπάρχουσας σχέσης',
    'relationship_form_is_with' => 'Αυτό το άτομο είναι…',
    'relationship_form_is_with_name' => 'Η επαφή :name είναι…',
    'relationship_form_add_choice' => 'Με ποιον είναι η σχέση;',
    'relationship_form_create_contact' => 'Προσθήκη νέου ατόμου',
    'relationship_form_associate_contact' => 'Υπάρχουσα επαφή',
    'relationship_form_associate_dropdown' => 'Αναζήτηση και επιλογή μιας υπάρχουσας επαφής από το πτυσσόμενο μενού παρακάτω',
    'relationship_form_associate_dropdown_placeholder' => 'Αναζήτηση και επιλογή μιας υπάρχουσας επαφής',
    'relationship_form_also_create_contact' => 'Δημιουργήστε μια καταχώρηση επαφής για αυτό το άτομο.',
    'relationship_form_add_description' => 'Αυτό θα σας επιτρέψει να χειριστείτε αυτό το άτομο όπως κάθε άλλη επαφή.',
    'relationship_form_add_no_existing_contact' => 'Δεν έχετε επαφές που σχετίζονται με την επαφή :name αυτή τη στιγμή.',
    'relationship_delete_confirmation' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτή τη σχέση? Η διαγραφή είναι μόνιμη.',
    'relationship_unlink_confirmation' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτή τη σχέση? Αυτό το άτομο δεν θα διαγραφεί – μόνο η σχέση μεταξύ των δύο.',
    'relationship_form_add_success' => 'Η σχέση έχει οριστεί με επιτυχία.',
    'relationship_form_deletion_success' => 'Η σχέση έχει διαγραφεί.',

    // tasks
    'tasks_title' => 'Εργασίες',
    'tasks_blank_title' => 'Δεν έχετε καμία εργασία.',
    'tasks_form_title' => 'Τίτλος',
    'tasks_form_description' => 'Περιγραφή (προαιρετικό)',
    'tasks_add_task' => 'Προσθέστε μια εργασία',
    'tasks_delete_success' => 'Η εργασία έχει διαγραφεί με επιτυχία',
    'tasks_complete_success' => 'Η κατάσταση της εργασίες άλλαξε επιτυχώς',

    // activities
    'activity_title' => 'Δραστηριότητες',
    'activity_type_category_simple_activities' => 'Απλές δραστηριότητες',
    'activity_type_category_sport' => 'Αθλητισμός',
    'activity_type_category_food' => 'Φαγητό',
    'activity_type_category_cultural_activities' => 'Πολιτιστικές δραστηριότητες',
    'activity_type_just_hung_out' => 'απλά κάναμε παρέα',
    'activity_type_watched_movie_at_home' => 'παρακολουθήσαμε μια ταινία στο σπίτι',
    'activity_type_talked_at_home' => 'απλά μιλήσαμε στο σπίτι',
    'activity_type_did_sport_activities_together' => 'κάναμε ένα άθλημα μαζί',
    'activity_type_ate_at_his_place' => 'έφαγα στο σπίτι τους',
    'activity_type_went_bar' => 'πήγαμε σε ένα μπαρ',
    'activity_type_ate_at_home' => 'φάγαμε στο σπίτι',
    'activity_type_picnicked' => 'κάναμε πικ νικ',
    'activity_type_ate_restaurant' => 'φάγαμε σε ένα εστιατόριο',
    'activity_type_went_theater' => 'πήγαμε στο θέατρο',
    'activity_type_went_concert' => 'πήγαμε σε μια συναυλία',
    'activity_type_went_play' => 'πήγαμε σε μία παράσταση',
    'activity_type_went_museum' => 'πήγαμε στο μουσείο',
    'activities_add_activity' => 'Προσθήκη δραστηριότητας',
    'activities_add_more_details' => 'Προσθέστε περισσότερες λεπτομέρειες',
    'activities_add_emotions' => 'Προσθήκη συναισθημάτων',
    'activities_add_category' => 'Δηλώστε μια κατηγορία',
    'activities_add_participants_cta' => 'Προσθήκη συμμετεχόντων',
    'activities_item_information' => ':Activity. Συνέβη στις :date',
    'activities_add_title' => 'Τι κάνατε με {name};',
    'activities_summary' => 'Περιγράψτε τι κάνατε',
    'activities_add_pick_activity' => 'Θα θέλατε να κατηγοριοποιήσετε αυτήν τη δραστηριότητα; Δεν χρειάζεται, αλλά θα σας δώσει στατιστικά αργότερα (προαιρετικό)',
    'activities_add_date_occured' => 'Η δραστηριότητα συνέβη την…',
    'activities_add_participants' => 'Ποιοι, εκτός από την επαφή {name}, συμμετείχαν σε αυτή τη δραστηριότητα; (προαιρετικό)',
    'activities_add_emotions_title' => 'Θέλετε να καταγράψετε πώς αισθανθήκατε κατά τη διάρκεια αυτής της δραστηριότητας; (προαιρετικό)',
    'activities_blank_title' => 'Παρακολουθήστε τι έχετε κάνει με την επαφή {name} στο παρελθόν και για τι έχετε μιλήσει',
    'activities_blank_add_activity' => 'Προσθήκη δραστηριότητας',
    'activities_add_success' => 'Η δραστηριότητα προστέθηκε με επιτυχία',
    'activities_add_error' => 'Σφάλμα κατά την προσθήκη δραστηριότητας',
    'activities_update_success' => 'Η δραστηριότητα ενημερώθηκε με επιτυχία',
    'activities_delete_success' => 'Η δραστηριότητα διαγράφηκε με επιτυχία',
    'activities_who_was_involved' => 'Ποιός συμμετείχε;',
    'activities_activity' => 'Κατηγορία Δραστηριότητας',
    'activities_view_activities_report' => 'Προβολή αναφοράς δραστηριοτήτων',
    'activities_profile_title' => 'Αναφορά δραστηριοτήτων μεταξύ :name και εσάς',
    'activities_profile_subtitle' => 'Έχετε καταγράψει συνολικά :total_activities δραστηριότητα με την επαφή :name ενώ ήταν :activities_last_twelve_months τους τελευταίους 12 μήνες . Έχετε καταγράψει συνολικά :total_activities δραστηριότητες με την επαφή :name ενώ ήταν :activities_last_twelve_months τους τελευταίους 12 μήνες.',
    'activities_profile_year_summary_activity_types' => 'Ακολουθεί μια ανάλυση του είδους των δραστηριοτήτων που έχετε κάνει μαζί το :year',
    'activities_profile_year_summary' => 'Δείτε εδώ τι έχετε κάνει εσείς οι δύο το :year',
    'activities_profile_number_occurences' => ':value δραστηριότητα|:value δραστηριότητες',
    'activities_list_participants' => 'Συμμετέχοντες ({total}):',
    'activities_list_emotions' => 'Συναισθήματα:',
    'activities_list_date' => 'Συνέβη στις',
    'activities_list_category' => 'Κατηγορία:',

    // notes
    'notes_create_success' => 'Η σημείωση έχει δημιουργηθεί με επιτυχία',
    'notes_update_success' => 'Η σημείωση αποθηκεύτηκε με επιτυχία',
    'notes_delete_success' => 'Η σημείωση διαγράφηκε με επιτυχία',
    'notes_add_cta' => 'Προσθήκη σημείωσης',
    'notes_favorite' => 'Προσθήκη/διαγραφή από τα αγαπημένα',
    'notes_delete_title' => 'Διαγραφή σημείωσης',
    'notes_delete_confirmation' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτή τη σημείωση; Η διαγραφή είναι μόνιμη',

    // gifts
    'gifts_title' => 'Δώρα',
    'gifts_add_success' => 'Το δώρο έχει προστεθεί με επιτυχία',
    'gifts_delete_success' => 'Το δώρο έχει διαγραφεί με επιτυχία',
    'gifts_delete_confirmation' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτό το δώρο;',
    'gifts_add_gift' => 'Προσθέστε ένα δώρο',
    'gifts_link' => 'Σύνδεσμος',
    'gifts_for' => 'Για: {name}',
    'gifts_delete_cta' => 'Διαγραφή',
    'gifts_add_title' => 'Διαχείριση δώρων για :name',
    'gifts_add_gift_idea' => 'Ιδέα για δώρο',
    'gifts_add_gift_already_offered' => 'Δώρο που το δώσατε',
    'gifts_add_gift_received' => 'Δώρο που το λάβατε',
    'gifts_add_gift_title' => 'Τι είναι αυτό το δώρο;',
    'gifts_add_gift_name' => 'Όνομα δώρου',
    'gifts_add_link' => 'Σύνδεσμος στην ιστοσελίδα (προαιρετικό)',
    'gifts_add_value' => 'Τιμή (προαιρετικό)',
    'gifts_add_comment' => 'Σχόλιο (προαιρετικό)',
    'gifts_add_recipient' => 'Παραλήπτης (προαιρετικό)',
    'gifts_add_recipient_field' => 'Παραλήπτης',
    'gifts_add_photo' => 'Φωτογραφία (προαιρετικό)',
    'gifts_add_photo_title' => 'Προσθέστε μια φωτογραφία για αυτό το δώρο',
    'gifts_add_someone' => 'Αυτό το δώρο είναι ειδικά για κάποιον στην οικογένεια της επαφής {name}',
    'gifts_delete_title' => 'Διαγραφή ενός δώρου',
    'gifts_ideas' => 'Ιδέες για δώρο',
    'gifts_offered' => 'Δώρα που έχετε δώσει',
    'gifts_offered_as_an_idea' => 'Σήμανση ως μία ιδέα',
    'gifts_received' => 'Δώρα που έχετε λάβει',
    'gifts_view_comment' => 'Προβολή σχολίου',
    'gifts_mark_offered' => 'Σήμανση ως δοσμένο',
    'gifts_update_success' => 'Το δώρο έχει ενημερωθεί με επιτυχία',
    'gifts_add_date' => 'Ημερομηνία (προαιρετικό)',

    // debts
    'debt_delete_confirmation' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτό το χρέος;',
    'debt_delete_success' => 'Το χρέος έχει διαγραφεί με επιτυχία',
    'debt_add_success' => 'Το χρέος έχει προστεθεί με επιτυχία',
    'debt_title' => 'Χρέη',
    'debt_add_cta' => 'Προσθέστε χρέος',
    'debt_you_owe' => 'Χρωστάτε :amount',
    'debt_they_owe' => 'Ε επαφή :name σας χρωστάει :amount',
    'debt_add_title' => 'Διαχείριση χρέους',
    'debt_add_you_owe' => 'Χρωστάς στην επαφή :name',
    'debt_add_they_owe' => 'Η επαφή :name σου χρωστάει',
    'debt_add_amount' => 'το σύνολο του',
    'debt_add_reason' => 'για τον παρακάτω λόγο (προαιρετικό)',
    'debt_add_add_cta' => 'Προσθέστε χρέος',
    'debt_edit_update_cta' => 'Ενημέρωση χρέους',
    'debt_edit_success' => 'Το χρέος ενημερώθηκε με επιτυχία',
    'debts_blank_title' => 'Διαχείριση χρέους που χρωστάτε ή σας χρωστάει η επαφή :name',

    // tags
    'tag_edit' => 'Επεξεργασία ετικέτας',
    'tag_add' => 'Προσθήκη ετικέτας',
    'tag_add_search' => 'Προσθήκη ή αναζήτηση ετικετών',
    'tag_no_tags' => 'Δεν υπάρχουν ετικέτες ακόμη',

    // Introductions
    'introductions_sidebar_title' => 'Πώς γνωριστήκατε;',
    'introductions_blank_cta' => 'Αναφέρετε πώς γνωριστήκατε με την επαφή :name',
    'introductions_title_edit' => 'Πως γνωριστήκατε με την επαφή :name;',
    'introductions_additional_info' => 'Εξηγήστε πώς και πού γνωριστήκατε',
    'introductions_edit_met_through' => 'Σας έχει συστήσει κάποιος σε αυτό το άτομο;',
    'introductions_no_met_through' => 'Κανένας',
    'introductions_first_met_date' => 'Ημερομηνία που γνωριστήκατε',
    'introductions_no_first_met_date' => 'Δεν γνωρίζω την ημερομηνία που γνωριστήκαμε',
    'introductions_first_met_date_known' => 'Αυτή είναι η ημερομηνία που γνωριστήκαμε',
    'introductions_add_reminder' => 'Προσθέστε μια υπενθύμιση για να γιορτάσετε αυτή την γνωριμία στην επέτειο που συνέβη αυτό το γεγονός',
    'introductions_update_success' => 'Έχετε ενημερώσει με επιτυχία τις πληροφορίες σχετικά με το πώς γνωρίσατε αυτό το άτομο',
    'introductions_met_through' => 'Γνωριστήκαμε μέσω <a href=":url">:name</a>',
    'introductions_met_date' => 'Γνωριστήκαμε στις :date',
    'introductions_reminder_title' => 'Επέτειος της ημέρας που γνωριστήκαμε για πρώτη φορά',

    // Deceased
    'deceased_reminder_title' => 'Επέτειος του θανάτου :name',
    'deceased_mark_person_deceased' => 'Σημειώστε αυτό το άτομο ως αποβιώσαν',
    'deceased_know_date' => 'Γνωρίζω την ημερομηνία που πέθανε αυτό το άτομο',
    'deceased_add_reminder' => 'Προσθήκη υπενθύμισης για αυτή την ημερομηνία',
    'deceased_label' => 'Απεβίωσε',
    'deceased_date_label' => 'Ημερομηνία αποβίωσης',
    'deceased_label_with_date' => 'Απεβίωσε στις :date',
    'deceased_age' => 'Ηλικία κατά το θάνατο',

    // Contact information
    'contact_info_title' => 'Στοιχεία επικοινωνίας',
    'contact_info_form_content' => 'Περιεχόμενο',
    'contact_info_form_contact_type' => 'Τύπος επαφής',
    'contact_info_form_personalize' => 'Εξατομίκευση',
    'contact_info_address' => 'Ζει σε',

    // Addresses
    'contact_address_title' => 'Διευθύνσεις',
    'contact_address_form_name' => 'Ετικέτα (προαιρετικό)',
    'contact_address_form_street' => 'Οδός (προαιρετικό)',
    'contact_address_form_city' => 'Πόλη (προαιρετικό)',
    'contact_address_form_province' => 'Επαρχία (προαιρετικό)',
    'contact_address_form_postal_code' => 'Ταχυδρομικός κώδικας (προαιρετικός)',
    'contact_address_form_country' => 'Χώρα (προαιρετικό)',
    'contact_address_form_latitude' => 'Γεωγραφικό πλάτος (μόνο αριθμοί) (προαιρετικό)',
    'contact_address_form_longitude' => 'Γεωγραφικό μήκος (μόνο αριθμοί) (προαιρετικό)',

    // Pets
    'pets_kind' => 'Είδος κατοικίδιου ζώου',
    'pets_name' => 'Όνομα (προαιρετικό)',
    'pets_create_success' => 'Το κατοικίδιο ζώο προστέθηκε με επιτυχία',
    'pets_update_success' => 'Το κατοικίδιο ζώο έχει ενημερωθεί',
    'pets_delete_success' => 'Το κατοικίδιο ζώο έχει διαγραφεί',
    'pets_title' => 'Κατοικίδια',
    'pets_reptile' => 'Ερπετό',
    'pets_bird' => 'Πτηνό',
    'pets_cat' => 'Γάτα',
    'pets_dog' => 'Σκύλος',
    'pets_fish' => 'Ψάρι',
    'pets_hamster' => 'Χάμστερ',
    'pets_horse' => 'Άλογο',
    'pets_rabbit' => 'Κουνέλι',
    'pets_rat' => 'Αρουραίος',
    'pets_small_animal' => 'Μικρό ζώο',
    'pets_other' => 'Άλλο',

    // life events
    'life_event_list_tab_life_events' => 'Εκδηλώσεις ζωής',
    'life_event_list_tab_other' => 'Σημειώσεις, υπενθυμίσεις, …',
    'life_event_list_title' => 'Εκδηλώσεις ζωής',
    'life_event_blank' => 'Καταγράψτε τι συμβαίνει στη ζωή του ατόμου {name} για τη μελλοντική ανασκόπηση.',
    'life_event_list_cta' => 'Προσθήκη συμβάντος ζωής',
    'life_event_create_category' => 'Όλες οι κατηγορίες',
    'life_event_create_life_event' => 'Προσθήκη συμβάντος ζωής',
    'life_event_create_default_title' => 'Τίτλος (προαιρετικό)',
    'life_event_create_default_story' => 'Ιστορία (προαιρετικό)',
    'life_event_create_date' => 'Δεν χρειάζεται να υποδείξετε ένα μήνα ή μια ημέρα - μόνο το έτος είναι υποχρεωτικό.',
    'life_event_create_default_description' => 'Προσθέστε πληροφορίες σχετικά με αυτά που γνωρίζετε',
    'life_event_create_add_yearly_reminder' => 'Προσθήκη ετήσιας υπενθύμισης για αυτό το γεγονός',
    'life_event_create_success' => 'Το συμβάν ζωής έχει προστεθεί',
    'life_event_delete_title' => 'Διαγραφή συμβάντος ζωής',
    'life_event_delete_description' => 'Είστε βέβαιοι ότι θέλετε να διαγράψετε αυτό το γεγονός ζωής; Η διαγραφή είναι μόνιμη.',
    'life_event_delete_success' => 'Το συμβάν ζωής έχει διαγραφεί',
    'life_event_date_it_happened' => 'Ημερομηνία που συνέβη',
    'life_event_category_work_education' => 'Εργασία και εκπαίδευση',
    'life_event_category_family_relationships' => 'Οικογένεια και σχέσεις',
    'life_event_category_home_living' => 'Οικία και διαβίωση',
    'life_event_category_health_wellness' => 'Υγεία και ευεξία',
    'life_event_category_travel_experiences' => 'Ταξίδια και εμπειρίες',
    'life_event_sentence_new_job' => 'Ξεκίνησε μια νέα εργασία',
    'life_event_sentence_retirement' => 'Συνταξιούχος',
    'life_event_sentence_new_school' => 'Ξεκίνησε σχολείο',
    'life_event_sentence_study_abroad' => 'Σπούδασε στο εξωτερικό',
    'life_event_sentence_volunteer_work' => 'Έγινε εθελοντής',
    'life_event_sentence_published_book_or_paper' => 'Δημοσίευσε μια εργασία',
    'life_event_sentence_military_service' => 'Ξεκίνησε στρατιωτική θητεία',
    'life_event_sentence_new_relationship' => 'Ξεκίνησε μια σχέση',
    'life_event_sentence_engagement' => 'Αρραβωνιάστηκε',
    'life_event_sentence_marriage' => 'Παντρεύτηκε',
    'life_event_sentence_anniversary' => 'Επέτειος',
    'life_event_sentence_expecting_a_baby' => 'Περιμένει μωρό',
    'life_event_sentence_new_child' => 'Έκανε ένα παιδί',
    'life_event_sentence_new_family_member' => 'Προστέθηκε νέο μέλος στην οικογένεια',
    'life_event_sentence_new_pet' => 'Πήρε κατοικίδιο',
    'life_event_sentence_end_of_relationship' => 'Τελείωσε μια σχέση',
    'life_event_sentence_loss_of_a_loved_one' => 'Έχασε κάποιον αγαπημένο',
    'life_event_sentence_moved' => 'Μετακόμισε',
    'life_event_sentence_bought_a_home' => 'Αγόρασε ένα σπίτι',
    'life_event_sentence_home_improvement' => 'Έκανε μια εργασία ή προσθήκη στο σπίτι',
    'life_event_sentence_holidays' => 'Πήγε διακοπές',
    'life_event_sentence_new_vehicle' => 'Πήρε ένα νέο όχημα',
    'life_event_sentence_new_roommate' => 'Απέκτησε συγκάτοικο',
    'life_event_sentence_overcame_an_illness' => 'Ξεπέρασε μια ασθένεια',
    'life_event_sentence_quit_a_habit' => 'Έκοψε μια συνήθεια',
    'life_event_sentence_new_eating_habits' => 'Ξεκίνησε νέες διατροφικές συνήθειες',
    'life_event_sentence_weight_loss' => 'Έχασε βάρος',
    'life_event_sentence_wear_glass_or_contact' => 'Ξεκίνησε να φοράει γυαλιά ή φακούς επαφής',
    'life_event_sentence_broken_bone' => 'Έσπασε κόκαλο',
    'life_event_sentence_removed_braces' => 'Έβγαλε τα σιδεράκια',
    'life_event_sentence_surgery' => 'Είχε χειρουργική επέμβαση',
    'life_event_sentence_dentist' => 'Πήγε στον οδοντίατρο',
    'life_event_sentence_new_sport' => 'Ξεκίνησε ένα άθλημα',
    'life_event_sentence_new_hobby' => 'Ξεκίνησε ένα χόμπι',
    'life_event_sentence_new_instrument' => 'Έμαθε ένα νέο όργανο',
    'life_event_sentence_new_language' => 'Έμαθε μια νέα γλώσσα',
    'life_event_sentence_tattoo_or_piercing' => 'Έκανε τατουάζ ή τρύπημα',
    'life_event_sentence_new_license' => 'Πήρε μια άδεια',
    'life_event_sentence_travel' => 'Ταξίδεψε',
    'life_event_sentence_achievement_or_award' => 'Πήρε ένα επίτευγμα ή ένα βραβείο',
    'life_event_sentence_changed_beliefs' => 'Άλλαξε πεποιθήσεις',
    'life_event_sentence_first_word' => 'Μίλησε για πρώτη φορά',
    'life_event_sentence_first_kiss' => 'Φιλήθηκε για πρώτη φορά',

    // documents
    'document_list_title' => 'Έγγραφα',
    'document_list_cta' => 'Μεταφόρτωση εγγράφου',
    'document_list_blank_desc' => 'Εδώ μπορείτε να αποθηκεύσετε έγγραφα που σχετίζονται με αυτό το άτομο.',
    'document_upload_zone_cta' => 'Μεταφορτώστε ένα αρχείο',
    'document_upload_zone_progress' => 'Μεταφόρτωση του εγγράφου…',
    'document_upload_zone_error' => 'Παρουσιάστηκε σφάλμα κατά τη μεταφόρτωση του εγγράφου. Παρακαλώ δοκιμάστε ξανά παρακάτω.',

    // Photos
    'photo_title' => 'Φωτογραφίες',
    'photo_list_title' => 'Σχετικές φωτογραφίες',
    'photo_list_cta' => 'Μεταφόρτωση φωτογραφίας',
    'photo_list_blank_desc' => 'Μπορείτε να αποθηκεύσετε εικόνες σχετικά με αυτήν την επαφή. Ανεβάστε μία τώρα!',
    'photo_upload_zone_cta' => 'Μεταφορτώστε μια φωτογραφία',
    'photo_current_profile_pic' => 'Τρέχουσα εικόνα προφίλ',
    'photo_make_profile_pic' => 'Δημιουργία εικόνας προφίλ',
    'photo_delete' => 'Διαγραφή φωτογραφίας',
    'photo_next' => 'Επόμενη φωτογραφία ❯',
    'photo_previous' => '❮ Προηγούμενη φωτογραφία',

    // Avatars
    'avatar_change_title' => 'Αλλαγή προσωπείου avatar',
    'avatar_question' => 'Ποια avatar θα θέλατε να χρησιμοποιήσετε;',
    'avatar_default_avatar' => 'Το προεπιλεγμένο avatar',
    'avatar_adorable_avatar' => 'Το αξιολάτρευτο avatar',
    'avatar_gravatar' => 'Το Gravatar που συνδέεται με τη διεύθυνση ηλεκτρονικού ταχυδρομείου αυτού του προσώπου. <a href="https://gravatar.com/">Gravatar</a> είναι ένα παγκόσμιο σύστημα που επιτρέπει στους χρήστες να συσχετίσουν τις διευθύνσεις ηλεκτρονικού ταχυδρομείου με φωτογραφίες.',
    'avatar_current' => 'Διατήρηση του τρέχοντος avatar',
    'avatar_photo' => 'Από μια φωτογραφία που μεταφορτώσατε',
    'avatar_crop_new_avatar_photo' => 'Περικοπή νέας εικόνας avatar',

    // emotions
    'emotion_this_made_me_feel' => 'Αυτό σας έκανε να αισθανθείτε…',

    // logs
    'auditlogs_link' => 'Ιστορικό',
    'auditlogs_title' => 'Όλα όσα συνέβησαν στο άτομο :name',
    'auditlogs_breadcrumb' => 'Ιστορικό',
    'auditlogs_author' => 'Με :name στις :date',

    // contact field label
    'contact_field_label_home' => 'Οικία',
    'contact_field_label_work' => 'Εργασία',
    'contact_field_label_cell' => 'Κινητό',
    'contact_field_label_fax' => 'Φαξ',
    'contact_field_label_pager' => 'Βομβητής',
    'contact_field_label_main' => 'Κυρίο',
    'contact_field_label_other' => 'Άλλο',
    'contact_field_label_personal' => 'Προσωπικό',
];
