<?php
namespace Aws\SecurityLake\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Security Lake** service.
 */
class SecurityLakeException extends AwsException {}
