<?php
namespace Aws\Personalize\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Personalize** service.
 */
class PersonalizeException extends AwsException {}
