<?php

return [
    'apc_cache_info',
    'apc_cas',
    'apc_compile_file',
    'apc_dec',
    'apc_define_constants',
    'apc_delete',
    'apc_delete_file',
    'apc_inc',
    'apc_load_constants',
    'apc_sma_info',
    'arsort',
    'array_replace',
    'array_replace_recursive',
    'array_combine',
    'array_flip',
    'asort',
    'event_add',
    'event_base_loopbreak',
    'event_base_loopexit',
    'event_base_new',
    'event_base_priority_init',
    'event_base_reinit',
    'event_base_set',
    'event_buffer_base_set',
    'event_buffer_disable',
    'event_buffer_enable',
    'event_buffer_new',
    'event_buffer_priority_set',
    'event_buffer_set_callback',
    'event_buffer_write',
    'event_del',
    'event_new',
    'event_priority_set',
    'event_set',
    'event_timer_set',
    'gmdate',
    'imagepsencodefont',
    'imagepsextendfont',
    'imagepsfreefont',
    'imagepsslantfont',
    'krsort',
    'ksort',
    'mktime',
    'mssql_bind',
    'mssql_close',
    'mssql_connect',
    'mssql_data_seek',
    'mssql_field_length',
    'mssql_field_name',
    'mssql_field_seek',
    'mssql_field_type',
    'mssql_free_result',
    'mssql_free_statement',
    'mssql_init',
    'mssql_pconnect',
    'mssql_query',
    'mssql_select_db',
    'mysqli_get_client_stats',
    'password_hash',
    'sort',
    'stats_covariance',
    'stats_standard_deviation',
    'stats_stat_correlation',
    'stats_stat_innerproduct',
    'stats_variance',
    'sleep',
    'substr',
    'usort',
    'vsprintf',
];
