<?php
namespace Aws\SageMakerMetrics\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon SageMaker Metrics Service** service.
 */
class SageMakerMetricsException extends AwsException {}
