<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    /*
    |--------------------------------------------------------------------------
    | Authentication Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'failed' => 'Kredensial ini tidak cocok dengan catatan kami.',
    'throttle' => 'Terlalu banyak upaya login. Silakan coba lagi dalam :seconds detik.',
    'not_authorized' => 'Anda tidak memiliki izin untuk menjalankan tindakan ini',
    'signup_disabled' => 'Pendaftaran saat ini dinonaktifkan',
    'signup_error' => 'Terjadi kesalahan saat mencoba mendaftarkan pengguna',
    'back_homepage' => 'Kembali ke halaman beranda',
    'mfa_auth_otp' => 'Otentikasi dengan perangkat dua faktor Anda',
    'mfa_auth_webauthn' => 'Otentikasi dengan sebuah kunci keamanan (WebAuthn)',
    '2fa_title' => 'Otentikasi Dua Faktor',
    '2fa_wrong_validation' => 'Otentikasi dua faktor telah gagal.',
    '2fa_one_time_password' => 'Kode otentikasi dua faktor',
    '2fa_recuperation_code' => 'Masukkan sebuah kode pemulihan dua faktor',
    '2fa_one_time_or_recuperation' => 'Masukkan sebuah kode otentikasi dua faktor atau sebuah kode pemulihan',
    '2fa_otp_help' => 'Buka aplikasi seluler otentikasi dua faktor Anda dan salin kode tersebut',

    'login_to_account' => 'Masuk ke akun Anda',
    'login_with_recovery' => 'Masuk dengan sebuah kode pemulihan',
    'login_again' => 'Silakan masuk lagi ke akun Anda',
    'email' => 'Email',
    'password' => 'Kata sandi',
    'recovery' => 'Kode pemulihan',
    'login' => 'Masuk',
    'button_remember' => 'Ingat Saya',
    'password_forget' => 'Lupa kata sandi Anda?',
    'password_reset' => 'Atur ulang kata sandi Anda',
    'use_recovery' => 'Atau kamu bisa menggunakan sebuah <a href=":url">kode pemulihan</a>',
    'signup_no_account' => 'Tidak punya akun?',
    'signup' => 'Daftar',
    'create_account' => 'Buat akun pertama dengan <a href=":url">mendaftar</a>',
    'change_language_title' => 'Ganti bahasa:',
    'change_language' => 'Ganti bahasa ke :lang',

    'password_reset_title' => 'Atur ulang kata sandi',
    'password_reset_email' => 'Alamat Email',
    'password_reset_send_link' => 'Kirim Tautan Atur Ulang Kata Sandi',
    'password_reset_password' => 'Kata sandi',
    'password_reset_password_confirm' => 'Komfirmasi Kata Sandi',
    'password_reset_action' => 'Atur ulang kata sandi',
    'password_reset_email_content' => 'Klik di sini untuk mengatur ulang kata sandi Anda:',

    'register_title_welcome' => 'Wilujeng sumping ke contoh pemasangan Monica Anda yang baru saja dipasang',
    'register_create_account' => 'Anda harus membuat sebuah akun untuk menggunakan Monica',
    'register_title_create' => 'Buat Akun Monica Anda',
    'register_login' => '<a href=":url">Masuk</a> jika Anda sudah memiliki akun.',
    'register_email' => 'Masukkan sebuah alamat email yang valid',
    'register_email_example' => 'kamu@beranda',
    'register_firstname' => 'Nama depan',
    'register_firstname_example' => 'mis. Asep',
    'register_lastname' => 'Nama keluarga',
    'register_lastname_example' => 'mis. Surasep',
    'register_password' => 'Kata sandi',
    'register_password_example' => 'Masukkan sebuah kata sandi yang aman',
    'register_password_confirmation' => 'Konfirmasi kata sandi',
    'register_action' => 'Daftar',
    'register_policy' => 'Dengan mendaftar menandakan Anda telah membaca dan menyetujui <a href=":url" hreflang=":hreflang">Kebijakan Privasi </a> dan <a href=":urlterm" hreflang=":hreflang">Ketentuan penggunaan</a>.',
    'register_invitation_email' => 'Untuk tujuan keamanan, silahkan cantumkan email orang yang telah mengundang Anda untuk bergabung dengan akun ini. Informasi ini disediakan dalam email invitasi.',

    'confirmation_title' => 'Verifikasi Alamat Email Anda',
    'confirmation_fresh' => 'Tautan verifikasi baru telah dikirimkan ke alamat email Anda.',
    'confirmation_check' => 'Sebelum melanjutkan, silakan periksa email Anda untuk sebuah tautan verifikasi.',
    'confirmation_request_another' => 'Jika Anda tidak menerima email <a :action>>klik di sini untuk meminta lagi</a>.',

    'confirmation_again' => 'Jika Anda ingin mengganti alamat email Anda, Anda bisa <a href=":url" class="alert-link">klik di sini</a>.',
    'email_change_current_email' => 'Alamat email saat ini:',
    'email_change_title' => 'Ganti alamat email Anda',
    'email_change_new' => 'Alamat email baru',
    'email_changed' => 'Alamat email Anda telah diubah. Periksa kotak surat Anda untuk memvalidasinya.',
];
