<?php
namespace Aws\LexRuntimeService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Lex Runtime Service** service.
 */
class LexRuntimeServiceException extends AwsException {}
