<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Ja',
    'no' => 'Nee',
    'update' => 'Bijwerken',
    'save' => 'Opslaan',
    'add' => 'Toevoegen',
    'cancel' => 'Annuleren',
    'confirm' => 'Bevestigen',
    'delete_confirm' => 'Zeker weten?',
    'delete' => 'Verwijderen',
    'edit' => 'Bewerken',
    'upload' => 'Uploaden',
    'download' => 'Download',
    'save_close' => 'Opslaan & sluiten',
    'close' => 'Sluiten',
    'copy' => 'Kopieer',
    'create' => 'Maak',
    'remove' => 'Verwijderen',
    'revoke' => 'Intrekken',
    'done' => 'Gereed',
    'back' => 'Terug',
    'verify' => 'Bevestigen',
    'new' => 'nieuw',
    'unknown' => 'Ik weet het niet',
    'load_more' => 'Meer laden',
    'loading' => 'Laden…',
    'with' => 'met',
    'today' => 'vandaag',
    'yesterday' => 'gisteren',
    'another_day' => 'een andere dag',
    'date' => 'Datum',
    'type' => 'Soort',
    'zoom' => 'Inzoomen',
    'upgrade' => 'Upgrade om te ontgrendelen',
    'percent_uploaded' => '{percent}% geüpload',
    'retry' => 'Opnieuw Proberen',
    'filter' => 'Filter de lijst',
    'go_back' => 'Terug',
    'file_selected' => 'Één bestand geselecteerd…|{count} bestanden geselecteerd…',

    'application_title' => 'Monica – persoonlijke relatie manager',
    'application_description' => 'Monica is een app voor het beheren van interacties met uw geliefden, vrienden en familie.',
    'application_og_title' => 'Heb betere relaties met je geliefden. Gratis online CRM voor familie en vrienden.',

    'markdown_description' => 'Wilt u uw tekst opmaken op een leuke manier? Wij ondersteunen Markdown om vet, cursief, lijsten en meer toe te voegen.',
    'markdown_link' => 'Lees documentatie',

    'header_settings_link' => 'Instellingen',
    'header_logout_link' => 'Uitloggen',
    'header_changelog_link' => 'Productwijzigingen',

    'main_nav_cta' => 'Personen toevoegen',
    'main_nav_dashboard' => 'Dashboard',
    'main_nav_family' => 'Contacten',
    'main_nav_journal' => 'Dagboek',
    'main_nav_activities' => 'Activiteiten',
    'main_nav_tasks' => 'Taken',

    'footer_remarks' => 'Opmerkingen?',
    'footer_send_email' => 'Stuur ons een e-mail',
    'footer_privacy' => 'Privacybeleid',
    'footer_release' => 'Releaseopmerkingen',
    'footer_newsletter' => 'Nieuwsbrief',
    'footer_source_code' => 'Bijdragen',
    'footer_version' => 'Versie: :version',
    'footer_new_version' => 'Er is een nieuwe versie van Monica beschikbaar',

    'footer_modal_version_whats_new' => 'Wat is er nieuw',
    'footer_modal_version_release_away' => 'Je loopt 1 versie achter op de laatst beschikbare versie. Je zou je applicatie moeten bijwerken.|Je loopt :number versies achter op de laatst beschikbare versie. Je zou je applicatie moeten bijwerken.',

    'breadcrumb_dashboard' => 'Dashboard',
    'breadcrumb_list_contacts' => 'Lijst van mensen',
    'breadcrumb_archived_contacts' => 'Gearchiveerde contacten',
    'breadcrumb_journal' => 'Dagboek',
    'breadcrumb_settings' => 'Instellingen',
    'breadcrumb_settings_export' => 'Exporteren',
    'breadcrumb_settings_users' => 'Gebruikers',
    'breadcrumb_settings_users_add' => 'Gebruiker toevoegen',
    'breadcrumb_settings_subscriptions' => 'Abonnement',
    'breadcrumb_settings_import' => 'Importeren',
    'breadcrumb_settings_import_report' => 'Importrapport',
    'breadcrumb_settings_import_upload' => 'Uploaden',
    'breadcrumb_settings_tags' => 'Labels',
    'breadcrumb_add_significant_other' => 'Partner toevoegen',
    'breadcrumb_edit_significant_other' => 'Partner bewerken',
    'breadcrumb_add_note' => 'Notitie toevoegen',
    'breadcrumb_edit_note' => 'Notitie bewerken',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'DAV-bronnen',
    'breadcrumb_edit_introductions' => 'Hoe hebben jullie elkaar ontmoet',
    'breadcrumb_settings_personalization' => 'Personalisatie',
    'breadcrumb_settings_security' => 'Beveiliging',
    'breadcrumb_settings_security_2fa' => 'Tweestapsverificatie',
    'breadcrumb_profile' => 'Profiel van :name',

    'gender_male' => 'Man',
    'gender_female' => 'Vrouw',
    'gender_none' => 'Zeg ik liever niet',
    'gender_no_gender' => 'Geen geslacht',

    'error_title' => 'Oeps! Er is iets misgegaan.',
    'error_unauthorized' => 'Je hebt niet de rechten om dit onderdeel te bewerken.',
    'error_user_account' => 'Deze gebruiker behoort niet tot het opgegeven account.',
    'error_save' => 'Er is een fout opgetreden bij het opslaan van de gegevens.',
    'error_try_again' => 'Er ging iets mis. Probeer opnieuw.',
    'error_id' => 'Fout-ID: :id',
    'error_unavailable' => 'Service niet beschikbaar',
    'error_maintenance' => 'Werkzaamheden zijn bezig. Een ogenblik graag.',
    'error_help' => 'We zijn zo terug.',
    'error_twitter' => '<a href="https://twitter.com/:twitter">Volg ons op Twitter</a> als je gewaarschuwd wilt worden als we terug zijn.',
    'error_no_term' => 'Er zijn nog geen voorwaarden opgesteld voor deze server.',

    'default_save_success' => 'De gegevens zijn opgeslagen.',

    'compliance_title' => 'Sorry voor de onderbreking.',
    'compliance_desc' => 'We hebben onze <a href=":urlterm" hreflang=":hreflang">gebruiksvoorwaarden</a> en ons <a href=":url" hreflang=":hreflang">privacybeleid</a> aangepast. We zijn verplicht u te vragen deze opnieuw te lezen en goed te keuren, om je account te kunnen blijven gebruiken.',
    'compliance_desc_end' => 'Wij doen niets vervelends met uw gegevens of account en zullen dit ook nooit doen.',
    'compliance_terms' => 'Accepteer de nieuwe voorwaarden en privacybeleid',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Liefdesrelaties',
    'relationship_type_group_family' => 'Familierelaties',
    'relationship_type_group_friend' => 'Vriendschappen',
    'relationship_type_group_work' => 'Collega’s',
    'relationship_type_group_other' => 'Andere relaties',

    'relationship_type_partner' => 'partner',
    'relationship_type_partner_female' => 'partner',
    'relationship_type_partner_male' => 'partner',
    'relationship_type_partner_with_name' => ':name’s van partner',
    'relationship_type_partner_female_with_name' => ':name’s partner',
    'relationship_type_partner_male_with_name' => ':name’s partner',

    'relationship_type_spouse' => 'echtgenoot',
    'relationship_type_spouse_female' => 'vrouw',
    'relationship_type_spouse_male' => 'echtgenoot',
    'relationship_type_spouse_with_name' => ':name’s van echtgeno(o)t(e)',
    'relationship_type_spouse_female_with_name' => ':name’s vrouw',
    'relationship_type_spouse_male_with_name' => 'array[\'relationship_type_spouse_male_with_name\']',

    'relationship_type_date' => 'date',
    'relationship_type_date_female' => 'date',
    'relationship_type_date_male' => 'date',
    'relationship_type_date_with_name' => ':name’s date',
    'relationship_type_date_female_with_name' => ':name’s date',
    'relationship_type_date_male_with_name' => ':name’s date',

    'relationship_type_lover' => 'geliefde',
    'relationship_type_lover_female' => 'geliefde',
    'relationship_type_lover_male' => 'geliefde',
    'relationship_type_lover_with_name' => ':name’s geliefde',
    'relationship_type_lover_female_with_name' => ':name’s geliefde',
    'relationship_type_lover_male_with_name' => ':name’s geliefde',

    'relationship_type_inlovewith' => 'verliefd op',
    'relationship_type_inlovewith_female' => 'verliefd op',
    'relationship_type_inlovewith_male' => 'verliefd op',
    'relationship_type_inlovewith_with_name' => 'iemand :name is verliefd op',
    'relationship_type_inlovewith_female_with_name' => 'iemand :name is verliefd op',
    'relationship_type_inlovewith_male_with_name' => 'iemand :name is verliefd op',

    'relationship_type_lovedby' => 'begeert door',
    'relationship_type_lovedby_female' => 'begeert door',
    'relationship_type_lovedby_male' => 'geliefd door',
    'relationship_type_lovedby_with_name' => ':name’s geheime minnaar',
    'relationship_type_lovedby_female_with_name' => ':name’s geheime minnaar',
    'relationship_type_lovedby_male_with_name' => ':name’s geheime minnaar',

    'relationship_type_ex' => 'ex-partner',
    'relationship_type_ex_female' => 'ex-vriendin',
    'relationship_type_ex_male' => 'ex-vriend',
    'relationship_type_ex_with_name' => ':name’s ex-partner',
    'relationship_type_ex_female_with_name' => ':name’s ex-vriendinnetje',
    'relationship_type_ex_male_with_name' => ':name’s ex-vriend',

    'relationship_type_parent' => 'ouder',
    'relationship_type_parent_female' => 'moeder',
    'relationship_type_parent_male' => 'vader',
    'relationship_type_parent_with_name' => ':name’s ouder',
    'relationship_type_parent_female_with_name' => ':name’s moeder',
    'relationship_type_parent_male_with_name' => ':name’s vader',

    'relationship_type_child' => 'kind',
    'relationship_type_child_female' => 'dochter',
    'relationship_type_child_male' => 'zoon',
    'relationship_type_child_with_name' => ':name’s kind',
    'relationship_type_child_female_with_name' => ':name’s dochter',
    'relationship_type_child_male_with_name' => ':name’s zoon',

    'relationship_type_stepparent' => 'stiefouder',
    'relationship_type_stepparent_female' => 'stiefmoeder',
    'relationship_type_stepparent_male' => 'stiefvader',
    'relationship_type_stepparent_with_name' => ':name’s stiefouder',
    'relationship_type_stepparent_female_with_name' => ':name’s stiefmoeder',
    'relationship_type_stepparent_male_with_name' => ':name’s stiefvader',

    'relationship_type_stepchild' => 'stiefkind',
    'relationship_type_stepchild_female' => 'stiefdochter',
    'relationship_type_stepchild_male' => 'stiefzoon',
    'relationship_type_stepchild_with_name' => ':name’s stiefkind',
    'relationship_type_stepchild_female_with_name' => ':name’s stiefdochter',
    'relationship_type_stepchild_male_with_name' => ':name’s stiefzoon',

    'relationship_type_sibling' => 'broer of zus',
    'relationship_type_sibling_female' => 'zus',
    'relationship_type_sibling_male' => 'broer',
    'relationship_type_sibling_with_name' => ':name’s broer of zus',
    'relationship_type_sibling_female_with_name' => ':name’s zus',
    'relationship_type_sibling_male_with_name' => ':name’s broer',

    'relationship_type_grandparent' => 'grootouder',
    'relationship_type_grandparent_female' => 'oma',
    'relationship_type_grandparent_male' => 'opa',
    'relationship_type_grandparent_with_name' => ':name’s grootouder',
    'relationship_type_grandparent_female_with_name' => ':name’s oma',
    'relationship_type_grandparent_male_with_name' => ':name’s opa',

    'relationship_type_grandchild' => 'kleinkind',
    'relationship_type_grandchild_female' => 'kleindochter',
    'relationship_type_grandchild_male' => 'kleinzoon',
    'relationship_type_grandchild_with_name' => ':name’s kleinkind',
    'relationship_type_grandchild_female_with_name' => ':name’s kleindochter',
    'relationship_type_grandchild_male_with_name' => ':name\'s kleinzoon',

    'relationship_type_uncle' => 'oom',
    'relationship_type_uncle_female' => 'tante',
    'relationship_type_uncle_male' => 'oom',
    'relationship_type_uncle_with_name' => ':name’s oom',
    'relationship_type_uncle_female_with_name' => ':name’s tante',
    'relationship_type_uncle_male_with_name' => ':name’s oom',

    'relationship_type_nephew' => 'neef',
    'relationship_type_nephew_female' => 'nicht',
    'relationship_type_nephew_male' => 'neef',
    'relationship_type_nephew_with_name' => ':name’s neef',
    'relationship_type_nephew_female_with_name' => ':name’s nicht',
    'relationship_type_nephew_male_with_name' => ':name’s neef',

    'relationship_type_cousin' => 'neef',
    'relationship_type_cousin_female' => 'nicht',
    'relationship_type_cousin_male' => 'neef',
    'relationship_type_cousin_with_name' => ':name’s neef',
    'relationship_type_cousin_female_with_name' => ':name’s nicht',
    'relationship_type_cousin_male_with_name' => ':name’s neef',

    'relationship_type_godfather' => 'peetouder',
    'relationship_type_godfather_female' => 'peet moeder',
    'relationship_type_godfather_male' => 'peetoom',
    'relationship_type_godfather_with_name' => ':name’s peetoom',
    'relationship_type_godfather_female_with_name' => ':name’s peetmoeder',
    'relationship_type_godfather_male_with_name' => ':name\'s peetoom',

    'relationship_type_godson' => 'petekind',
    'relationship_type_godson_female' => 'peetdochter',
    'relationship_type_godson_male' => 'peetzoon',
    'relationship_type_godson_with_name' => ':name’s petekind',
    'relationship_type_godson_female_with_name' => ':name’s schoondochter',
    'relationship_type_godson_male_with_name' => ':name’s peetzoon',

    'relationship_type_friend' => 'vriend',
    'relationship_type_friend_female' => 'vriend',
    'relationship_type_friend_male' => 'vriend',
    'relationship_type_friend_with_name' => ':name’s vriend',
    'relationship_type_friend_female_with_name' => ':name’s vriend',
    'relationship_type_friend_male_with_name' => ':name’s vriend',

    'relationship_type_bestfriend' => 'beste vriend',
    'relationship_type_bestfriend_female' => 'beste vriend',
    'relationship_type_bestfriend_male' => 'beste vriend',
    'relationship_type_bestfriend_with_name' => ':name’s beste vriend',
    'relationship_type_bestfriend_female_with_name' => ':name’s beste vriend',
    'relationship_type_bestfriend_male_with_name' => ':name’s beste vriend',

    'relationship_type_colleague' => 'collega',
    'relationship_type_colleague_female' => 'collega',
    'relationship_type_colleague_male' => 'collega',
    'relationship_type_colleague_with_name' => ':name’s collega',
    'relationship_type_colleague_female_with_name' => ':name’s collega',
    'relationship_type_colleague_male_with_name' => ':name’s collega',

    'relationship_type_boss' => 'baas',
    'relationship_type_boss_female' => 'baas',
    'relationship_type_boss_male' => 'baas',
    'relationship_type_boss_with_name' => ':name’s baas',
    'relationship_type_boss_female_with_name' => ':name’s baas',
    'relationship_type_boss_male_with_name' => ':name’s baas',

    'relationship_type_subordinate' => 'ondergeschikte',
    'relationship_type_subordinate_female' => 'ondergeschikte',
    'relationship_type_subordinate_male' => 'ondergeschikte',
    'relationship_type_subordinate_with_name' => ':name’s ondergeschikte',
    'relationship_type_subordinate_female_with_name' => ':name’s ondergeschikte',
    'relationship_type_subordinate_male_with_name' => ':name’s ondergeschikte',

    'relationship_type_mentor' => 'mentor',
    'relationship_type_mentor_female' => 'mentor',
    'relationship_type_mentor_male' => 'mentor',
    'relationship_type_mentor_with_name' => ':name’s mentor',
    'relationship_type_mentor_female_with_name' => ':name’s mentor',
    'relationship_type_mentor_male_with_name' => ':name’s mentor',

    'relationship_type_protege' => 'pupil',
    'relationship_type_protege_female' => 'pupil',
    'relationship_type_protege_male' => 'pupil',
    'relationship_type_protege_with_name' => ':name\'s pupil',
    'relationship_type_protege_female_with_name' => ':name\'s pupil',
    'relationship_type_protege_male_with_name' => ':name\'s pupil',

    'relationship_type_ex_husband' => 'ex-man',
    'relationship_type_ex_husband_female' => 'ex-vrouw',
    'relationship_type_ex_husband_male' => 'ex-man',
    'relationship_type_ex_husband_with_name' => ':naam ex-echtgenoot',
    'relationship_type_ex_husband_female_with_name' => ':name’s ex-vrouw',
    'relationship_type_ex_husband_male_with_name' => ':naam ex-man',

    // emotions
    'emotion_primary_love' => 'Liefde',
    'emotion_primary_joy' => 'Blijdschap',
    'emotion_primary_surprise' => 'Verrast',
    'emotion_primary_anger' => 'Boos',
    'emotion_primary_sadness' => 'Verdriet',
    'emotion_primary_fear' => 'Angst',

    'emotion_secondary_affection' => 'Genegenheid',
    'emotion_secondary_lust' => 'Lust',
    'emotion_secondary_longing' => 'Verlangen',
    'emotion_secondary_cheerfulness' => 'Opgewekt',
    'emotion_secondary_zest' => 'Vol vuur',
    'emotion_secondary_contentment' => 'Tevreden',
    'emotion_secondary_pride' => 'Trots',
    'emotion_secondary_optimism' => 'Optimisme',
    'emotion_secondary_enthrallment' => 'Betoverend',
    'emotion_secondary_relief' => 'Opgelucht',
    'emotion_secondary_surprise' => 'Verrast',
    'emotion_secondary_irritation' => 'Irritatie',
    'emotion_secondary_exasperation' => 'Wrevel',
    'emotion_secondary_rage' => 'Woedend',
    'emotion_secondary_disgust' => 'Afschuw',
    'emotion_secondary_envy' => 'Afgunst',
    'emotion_secondary_suffering' => 'Pijn',
    'emotion_secondary_sadness' => 'Verdriet',
    'emotion_secondary_disappointment' => 'Teleurstelling',
    'emotion_secondary_shame' => 'Schaamte',
    'emotion_secondary_neglect' => 'Verwaarloosd',
    'emotion_secondary_sympathy' => 'Meelevend',
    'emotion_secondary_horror' => 'Afgrijzen',
    'emotion_secondary_nervousness' => 'Zenuwachtig',

    'emotion_adoration' => 'Aanbidding',
    'emotion_affection' => 'Genegenheid',
    'emotion_love' => 'Liefde',
    'emotion_fondness' => 'Warmte',
    'emotion_liking' => 'Voorliefde',
    'emotion_attraction' => 'Aantrekking',
    'emotion_caring' => 'Zorgzaamheid',
    'emotion_tenderness' => 'Tederheid',
    'emotion_compassion' => 'Compassie',
    'emotion_sentimentality' => 'Sentimenteel',
    'emotion_arousal' => 'Opwinding',
    'emotion_desire' => 'Verlangen',
    'emotion_lust' => 'Lust',
    'emotion_passion' => 'Passie',
    'emotion_infatuation' => 'Bevlieging',
    'emotion_longing' => 'Verlangen',
    'emotion_amusement' => 'Plezier',
    'emotion_bliss' => 'Gelukzaligheid',
    'emotion_cheerfulness' => 'Opgewekt',
    'emotion_gaiety' => 'Pret',
    'emotion_glee' => 'Vrolijk',
    'emotion_jolliness' => 'Jolig',
    'emotion_joviality' => 'Joviaal',
    'emotion_joy' => 'Vreugde',
    'emotion_delight' => 'Verrukking',
    'emotion_enjoyment' => 'Genot',
    'emotion_gladness' => 'Verheugd',
    'emotion_happiness' => 'Blijdschap',
    'emotion_jubilation' => 'Vervoering',
    'emotion_elation' => 'Opgetogen',
    'emotion_satisfaction' => 'Genoegen',
    'emotion_ecstasy' => 'Vervoering',
    'emotion_euphoria' => 'Euforie',
    'emotion_enthusiasm' => 'Enthousiasme',
    'emotion_zeal' => 'Geestdrift',
    'emotion_zest' => 'Vol vuur',
    'emotion_excitement' => 'Opwinding',
    'emotion_thrill' => 'Sensatie',
    'emotion_exhilaration' => 'Opbeuring',
    'emotion_contentment' => 'Voldoening',
    'emotion_pleasure' => 'Genoegen',
    'emotion_pride' => 'Trots',
    'emotion_eagerness' => 'Gretig',
    'emotion_hope' => 'Hoopvol',
    'emotion_optimism' => 'Optimistisch',
    'emotion_enthrallment' => 'Betoverend',
    'emotion_rapture' => 'Extase',
    'emotion_relief' => 'Opgelucht',
    'emotion_amazement' => 'Verbazing',
    'emotion_surprise' => 'Verrast',
    'emotion_astonishment' => 'Verwonderd',
    'emotion_aggravation' => 'Vervelend',
    'emotion_irritation' => 'Irritatie',
    'emotion_agitation' => 'Geërgerd',
    'emotion_annoyance' => 'Ergernis',
    'emotion_grouchiness' => 'Humeurig',
    'emotion_grumpiness' => 'Mopperend',
    'emotion_exasperation' => 'Wrevel',
    'emotion_frustration' => 'Frustratie',
    'emotion_anger' => 'Boosheid',
    'emotion_rage' => 'Woede',
    'emotion_outrage' => 'Verbolgenheid',
    'emotion_fury' => 'Razend',
    'emotion_wrath' => 'Toorn',
    'emotion_hostility' => 'Vijandig',
    'emotion_ferocity' => 'Wreed',
    'emotion_bitterness' => 'Bitter',
    'emotion_hate' => 'Haat',
    'emotion_loathing' => 'Afkeer',
    'emotion_scorn' => 'Verachting',
    'emotion_spite' => 'Wrok',
    'emotion_vengefulness' => 'Wraakzuchtig',
    'emotion_dislike' => 'Aversie',
    'emotion_resentment' => 'Verontwaardiging',
    'emotion_disgust' => 'Afschuw',
    'emotion_revulsion' => 'Walging',
    'emotion_contempt' => 'Minachting',
    'emotion_envy' => 'Afgunst',
    'emotion_jealousy' => 'Jaloezie',
    'emotion_agony' => 'Pijn',
    'emotion_suffering' => 'Lijden',
    'emotion_hurt' => 'Kwelling',
    'emotion_anguish' => 'Leed',
    'emotion_depression' => 'Depressief',
    'emotion_despair' => 'Wanhoop',
    'emotion_hopelessness' => 'Hopeloos',
    'emotion_gloom' => 'Zwaarmoedig',
    'emotion_glumness' => 'Mistroostig',
    'emotion_sadness' => 'Verdrietig',
    'emotion_unhappiness' => 'Ongelukkig',
    'emotion_grief' => 'Droevig',
    'emotion_sorrow' => 'Rouw',
    'emotion_woe' => 'Smart',
    'emotion_misery' => 'Ellendig',
    'emotion_melancholy' => 'Neerslachtig',
    'emotion_dismay' => 'Verbijstering',
    'emotion_disappointment' => 'Teleurstellend',
    'emotion_displeasure' => 'Ongenoegen',
    'emotion_guilt' => 'Schuldig',
    'emotion_shame' => 'Schaamte',
    'emotion_regret' => 'Spijt',
    'emotion_remorse' => 'Wroeging',
    'emotion_alienation' => 'Vervreemding',
    'emotion_isolation' => 'Afzondering',
    'emotion_neglect' => 'Verwaarlozing',
    'emotion_loneliness' => 'Eenzaam',
    'emotion_rejection' => 'Verworpen',
    'emotion_homesickness' => 'Heimwee',
    'emotion_defeat' => 'Verslagen',
    'emotion_dejection' => 'Mismoedig',
    'emotion_insecurity' => 'Onzeker',
    'emotion_embarrassment' => 'Verlegenheid',
    'emotion_humiliation' => 'Vernederd',
    'emotion_insult' => 'Beledigd',
    'emotion_pity' => 'Medelijden',
    'emotion_sympathy' => 'Meelevend',
    'emotion_alarm' => 'Geschrokken',
    'emotion_shock' => 'Geschokt',
    'emotion_fear' => 'Angst',
    'emotion_fright' => 'Vrees',
    'emotion_horror' => 'Afgrijzen',
    'emotion_terror' => 'Verschrikking',
    'emotion_panic' => 'Paniek',
    'emotion_hysteria' => 'Hysterie',
    'emotion_mortification' => 'Gekrenkt',
    'emotion_anxiety' => 'Berzorgd',
    'emotion_nervousness' => 'Nerveus',
    'emotion_tenseness' => 'Gespannen',
    'emotion_uneasiness' => 'Onbehaagelijk',
    'emotion_apprehension' => 'Vrees',
    'emotion_worry' => 'Bezorgdheid',
    'emotion_distress' => 'Ontsteltenis',
    'emotion_dread' => 'Doodsangst',

    // weather
    'weather_sunny' => 'Zonnig',
    'weather_clear' => 'Helder',
    'weather_clear-day' => 'Helder',
    'weather_clear-night' => 'Heldere nacht',
    'weather_light-drizzle' => 'Lichte motregen',
    'weather_patchy-light-drizzle' => 'Af en toe motregen',
    'weather_patchy-light-rain' => 'Af en toe regenval',
    'weather_light-rain' => 'Lichte regen',
    'weather_moderate-rain-at-times' => 'Nu en dan matige regenval',
    'weather_moderate-rain' => 'Matige regenval',
    'weather_patchy-rain-possible' => 'Plaatselijk regen mogelijk',
    'weather_heavy-rain-at-times' => 'Nu en dan hevige regen',
    'weather_heavy-rain' => 'Heavy rain',
    'weather_light-freezing-rain' => 'Light freezing rain',
    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
    'weather_light-sleet' => 'Light sleet',
    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
    'weather_light-rain-shower' => 'Light rain shower',
    'weather_torrential-rain-shower' => 'Torrential rain shower',
    'weather_rain' => 'Regen',
    'weather_snow' => 'Sneeuw',
    'weather_blowing-snow' => 'Blowing snow',
    'weather_patchy-light-snow' => 'Patchy light snow',
    'weather_light-snow' => 'Light snow',
    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
    'weather_moderate-snow' => 'Moderate snow',
    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
    'weather_heavy-snow' => 'Heavy snow',
    'weather_light-snow-showers' => 'Light snow showers',
    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
    'weather_patchy-snow-possible' => 'Patchy snow possible',
    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
    'weather_light-sleet-showers' => 'Light sleet showers',
    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
    'weather_sleet' => 'Natte sneeuw',
    'weather_wind' => 'Wind',
    'weather_fog' => 'Mist',
    'weather_freezing-fog' => 'Freezing fog',
    'weather_mist' => 'Mist',
    'weather_blizzard' => 'Blizzard',
    'weather_overcast' => 'Overcast',
    'weather_cloudy' => 'Bewolkt',
    'weather_partly-cloudy-day' => 'Partly cloudy',
    'weather_partly-cloudy-night' => 'Partly cloudy',
    'weather_freezing-drizzle' => 'Freezing drizzle',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Ice pellets',
    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Huidig weer',

    // dav
    'dav_contacts' => 'Contacten',
    'dav_contacts_description' => 'Contacten van :name',
    'dav_birthdays' => 'Verjaardagen',
    'dav_birthdays_description' => 'Verjaardagen van de contacten van :name',
    'dav_tasks' => 'Taken',
    'dav_tasks_description' => ':name’s taken',

    // contact list
    'contact_list_avatar' => 'Avatar',
    'contact_list_name' => 'Contact',
    'contact_list_description' => 'Beschrijving',

];
