<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  6762 => 'Nuku\'alofa',
  67629 => 'Pea',
  67630 => 'Pea',
  67631 => 'Muʻa',
  67632 => 'Muʻa',
  67633 => 'Kolonga',
  67634 => 'Kolonga',
  67635 => 'Nakolo',
  67636 => 'Nakolo',
  67637 => 'Vaini',
  67638 => 'Vaini',
  67640 => 'Kolovai',
  67641 => 'Masilamea',
  67642 => 'Masilamea',
  67643 => 'Matangiake',
  67650 => '‘Eua',
  67660 => 'Ha’apai',
  67669 => 'Ha’apai',
  67670 => 'Vava’u',
  67671 => 'Vava’u',
  67672 => 'Vava’u',
  67674 => 'Vava’u',
  67675 => 'Vava’u',
  67676 => 'Vava’u',
  67679 => 'Vava’u',
  67680 => 'Niuas',
  67685 => 'Niuas',
);
