<?php
namespace Aws\drs\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Elastic Disaster Recovery Service** service.
 */
class drsException extends AwsException {}
