<?php
namespace Aws\ControlCatalog\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Control Catalog** service.
 */
class ControlCatalogException extends AwsException {}
