<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Günün nasıl geçti? Günde bir defa derecelendirebilirsin.',
    'journal_come_back' => 'Teşekkürler. Gününü değerlendirmek için yarın tekrar gel.',
    'journal_description' => 'Not: günlük içerikleri hem sizin tarafınızdan hem de bağlantılarınızla olan etkinliklerden otomatik oluşturulur. Günlük girdilerini silebilirsiniz, etkinlikleri bağlantı sayfalarından silmeniz gerekir.',
    'journal_add' => 'Bir günlük girdisi ekle',
    'journal_edit' => 'Bir günlük girdisini düzenle',
    'journal_empty' => 'Boş günlük',
    'journal_created_at' => 'Created at {date}',
    'journal_created_automatically' => 'Otomatik olarak oluşturuldu',
    'journal_entry_type_journal' => 'Günlük girdisi',
    'journal_entry_type_activity' => 'Faaliyet',
    'journal_entry_rate' => 'Gününü değerlendirdin.',
    'journal_add_comment' => 'Yorum eklemek ister misiniz (isteğe bağlı)?',
    'journal_show_comment' => 'Yorumu göster',
    'entry_delete_success' => 'Günlük girdisi başarıyla silindi.',
    'journal_add_title' => 'Başlık (isteğe bağlı)',
    'journal_add_date' => 'Tarih',
    'journal_add_post' => 'Girdi',
    'journal_add_cta' => 'Kaydet',
    'journal_blank_cta' => 'İlk günlük içeriğini yaz',
    'journal_blank_description' => 'Günlük başından geçen olayları yazmanı ve onları tekrar hatırlamanı sağlar.',
    'delete_confirmation' => 'Bu girdiyi silmek istediğinizden emin misiniz?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
