<?php

return [
    'login_failed' => 'Authentication failed',
    'user_unauthenticated' => 'You need to log in before doing a Webauthn authentication',
    'auth_data_not_found' => 'Authentication data not found',
    'create_data_not_found' => 'Register data not found',
    'cannot_register_new_key' => 'The user cannot register a new key at this time',
    'wrong_validation' => 'Error during the validation of the key',
    'object_not_found' => 'Object not found',

    'not_supported' => 'Your browser doesn’t currently support WebAuthn.',
    'not_secured' => 'WebAuthn only supports secure connections. For testing over HTTP, you can use the origin "localhost".',
    'key_already_used' => 'This key is already registered. It’s not necessary to register it again.',
    'key_not_allowed' => 'The operation either timed out or was not allowed.',

];
