<?php
// This file was auto-generated from sdk-root/src/data/medical-imaging/2023-07-19/paginators-1.json
return [ 'pagination' => [ 'ListDICOMImportJobs' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'jobSummaries', ], 'ListDatastores' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'datastoreSummaries', ], 'ListImageSetVersions' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'imageSetPropertiesList', ], 'SearchImageSets' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'imageSetsMetadataSummaries', ], ],];
