<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'dashboard_blank_title' => 'Chào mừng đến với tài khoản của bạn!',
    'dashboard_blank_description' => 'Monica là nơi sắp xếp tất cả tương tác của bạn với người mà bạn quan tâm.',
    'dashboard_blank_cta' => 'Thêm liên hệ đầu tiên',
    'dashboard_blank_illustration' => 'Minh họa bởi <a href=":url">Freepik</a>',

    'notes_title' => 'Bạn chưa có ghi chú gắn dấu sao nào.',

    'tab_recent_calls' => 'Cuộc gọi gần đây',
    'tab_favorite_notes' => 'Ghi chú ưa thích',
    'tab_calls_blank' => 'Bạn chưa ghi nhật ký cuộc gọi nào.',
    'tab_debts' => 'Khoản nợ',
    'tab_debts_blank' => 'Bạn chưa ghi khoản nợ nào.',
    'tab_tasks' => 'Nhiệm vụ',
    'tab_tasks_blank' => 'Bạn chưa có nhiệm vụ nào.',

    'tasks_add_task_placeholder' => 'Nhiệm vụ này làm gì?',
    'tasks_tab_your_contacts' => 'Nhiệm vụ liên quan đến liên hệ của bạn',
    'tasks_tab_your_tasks' => 'Nhiệm vụ của bạn',
    'tasks_add_note' => 'Nhấn <kbd>Enter</kbd> để thêm nhiệm vụ.',
    'task_add_cta' => 'Thêm nhiệm vụ',

    'debts_you_owe' => 'Bạn nợ',

    'statistics_contacts' => 'Danh bạ',
    'statistics_activities' => 'Hoạt động',
    'statistics_gifts' => 'Quà tặng',

    'reminders_next_months' => 'Sự kiện trong 3 tháng tới',
    'reminders_none' => 'Không có nhắc nhở nào trong tháng này.',

    'product_changes' => 'Cập nhật sản phẩm',
    'product_view_details' => 'Xem chi tiết',
];
