<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  4202 => 'Prague',
  42031 => 'Central Bohemian Region',
  42032 => 'Central Bohemian Region',
  42035 => 'Karlovy Vary Region',
  42037 => 'Plzeň Region',
  42038 => 'South Bohemian Region',
  42039 => 'South Bohemian Region',
  42041 => 'Ústí nad Labem Region',
  42046 => 'Pardubice Region',
  42047 => 'Ústí nad Labem Region',
  42048 => 'Liberec Region',
  42049 => 'Hradec Králové Region',
  42051 => 'South Moravian Region',
  42053 => 'South Moravian Region',
  42054 => 'South Moravian Region',
  42055 => 'Moravian-Silesian Region',
  42056 => 'Vysočina Region',
  42057 => 'Zlín Region',
  42058 => 'Olomouc Region',
  42059 => 'Moravian-Silesian Region',
);
