<?php

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/*
 * Authors:
 * - Muhammad Nasir Rahimi
 * - Nassim Nasibullah (spinzar)
 */
return [
    'year' => ':count کال|:count کاله',
    'y' => ':countکال|:countکاله',
    'month' => ':count مياشت|:count مياشتي',
    'm' => ':countمياشت|:countمياشتي',
    'week' => ':count اونۍ|:count اونۍ',
    'w' => ':countاونۍ|:countاونۍ',
    'day' => ':count ورځ|:count ورځي',
    'd' => ':countورځ|:countورځي',
    'hour' => ':count ساعت|:count ساعته',
    'h' => ':countساعت|:countساعته',
    'minute' => ':count دقيقه|:count دقيقې',
    'min' => ':countدقيقه|:countدقيقې',
    'second' => ':count ثانيه|:count ثانيې',
    's' => ':countثانيه|:countثانيې',
    'ago' => ':time دمخه',
    'from_now' => ':time له اوس څخه',
    'after' => ':time وروسته',
    'before' => ':time دمخه',
    'list' => ['، ', ' او '],
    'meridiem' => ['غ.م.', 'غ.و.'],
    'weekdays' => ['اتوار', 'ګل', 'نهه', 'شورو', 'زيارت', 'جمعه', 'خالي'],
    'weekdays_short' => ['ا', 'ګ', 'ن', 'ش', 'ز', 'ج', 'خ'],
    'weekdays_min' => ['ا', 'ګ', 'ن', 'ش', 'ز', 'ج', 'خ'],
    'months' => ['جنوري', 'فبروري', 'مارچ', 'اپریل', 'مۍ', 'جون', 'جولای', 'اگست', 'سېپتمبر', 'اکتوبر', 'نومبر', 'دسمبر'],
    'months_short' => ['جنوري', 'فبروري', 'مارچ', 'اپریل', 'مۍ', 'جون', 'جولای', 'اگست', 'سېپتمبر', 'اکتوبر', 'نومبر', 'دسمبر'],
    'months_standalone' => ['جنوري', 'فېبروري', 'مارچ', 'اپریل', 'مۍ', 'جون', 'جولای', 'اگست', 'سپتمبر', 'اکتوبر', 'نومبر', 'دسمبر'],
    'months_short_standalone' => ['جنوري', 'فبروري', 'مارچ', 'اپریل', 'مۍ', 'جون', 'جولای', 'اگست', 'سپتمبر', 'اکتوبر', 'نومبر', 'دسمبر'],
    'first_day_of_week' => 6,
    'weekend' => [4, 5],
    'formats' => [
        'LT' => 'H:mm',
        'LTS' => 'H:mm:ss',
        'L' => 'YYYY/M/d',
        'LL' => 'YYYY MMM D',
        'LLL' => 'د YYYY د MMMM D H:mm',
        'LLLL' => 'dddd د YYYY د MMMM D H:mm',
    ],
];
