<?php

/**
 * ⚠️ Edition not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'user_unauthenticated' => 'Du må logge inn før du utfører en Webauthn-autentisering',
    'auth_data_not_found' => 'Autentiseringsdata ikke funnet',
    'create_data_not_found' => 'Registreringsdata ikke funnet',
    'object_not_found' => 'Objektet ble ikke funnet',

];
