<?php
// This file was auto-generated from sdk-root/src/data/codeguru-reviewer/2019-09-19/paginators-1.json
return [ 'pagination' => [ 'ListCodeReviews' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', ], 'ListRecommendationFeedback' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', ], 'ListRecommendations' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', ], 'ListRepositoryAssociations' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'RepositoryAssociationSummaries', ], ],];
