<?php
namespace Aws\LexRuntimeV2\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Lex Runtime V2** service.
 */
class LexRuntimeV2Exception extends AwsException {}
