<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reset Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'reset' => 'Je wachtwoord is gereset!',
    'sent' => 'We hebben een e-mail verstuurd met instructies om een nieuw wachtwoord in te stellen.',
    'token' => 'Deze wachtwoord reset token is ongeldig.',
    'user' => 'Geen gebruiker bekend met het e-mailadres.',
    'changed' => 'Wachtwoord succesvol gewijzigd.',
    'invalid' => 'Het ingevoerde wachtwoord is niet correct.',
    'throttled' => 'Wacht alsjeblieft even voor je het opnieuw probeert.',

];
