<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  2542 => 'Nairobi',
  25440 => 'Kwale/Ukunda/Msambweni/Lungalunga',
  25441 => 'Mombasa/Mariakani/Kilifi',
  25442 => 'Malindi/Lamu/Garsen',
  25443 => 'Voi/Wundanyi/Mwatate/Taveta',
  25444 => 'Machakos/Makueni/Mwingi/Kitui',
  25445 => 'Kajiado/Ngong/Loitokitok/Athi River',
  25446 => 'Garissa/Hola/Wajir/Mandera',
  25450 => 'Naivasha/Narok/Gilgil',
  25451 => 'Nakuru/Njoro/Molo',
  25452 => 'Kericho/Bomet',
  25453 => 'Eldoret/Turbo/Kapsabet/Iten/Kabarnet',
  25454 => 'Kitale/Moi\'s Bridge/Kapenguria/Lodwar',
  25455 => 'Bungoma/Busia',
  25456 => 'Kakamega/Mbale/Butere/Mumias/Vihiga',
  25457 => 'Kisumu/Siaya/Maseno',
  25458 => 'Kisii/Kilgoris/Oyugis/Nyamira',
  25459 => 'Homabay/Migori',
  25460 => 'Muranga/Kerugoya',
  25461 => 'Nyeri/Karatina',
  25462 => 'Nanyuki',
  25464 => 'Meru/Maua/Chuka',
  25465 => 'Nyahururu/Maralal',
  25466 => 'Thika/Ruiru',
  25467 => 'Kiambu/Kikuyu',
  25468 => 'Embu',
  25469 => 'Marsabit/Moyale',
);
