<?php
namespace Aws\DirectConnect\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the AWS Direct Connect service.
 */
class DirectConnectException extends AwsException {}
