<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    //index
    'people_not_found' => 'Không tìm thấy liên hệ',
    'people_list_number_kids' => ':count con',
    'people_list_last_updated' => 'Danh sách liên hệ mới cập nhật:',
    'people_list_number_reminders' => ':count lời nhắc',
    'people_list_blank_title' => 'Bạn không có ai trong tài khoản',
    'people_list_blank_cta' => 'Thêm ai đó',
    'people_list_sort' => 'Sắp xếp',
    'people_list_stats' => ':count liên hệ',
    'people_list_firstnameAZ' => 'Xếp theo tên A → Z',
    'people_list_firstnameZA' => 'Xếp theo tên Z → A',
    'people_list_lastnameAZ' => 'Xếp theo họ A → Z',
    'people_list_lastnameZA' => 'Xếp theo họ Z → A',
    'people_list_lastactivitydateNewtoOld' => 'Xếp theo hoạt động gần đây nhất',
    'people_list_lastactivitydateOldtoNew' => 'Xếp theo hoạt động lâu nhất',
    'people_list_filter_tag' => 'Hiện tất cả liên hệ được tag với',
    'people_list_clear_filter' => 'Xoá bộ lọc',
    'people_list_contacts_per_tags' => ':count liên hệ|:count liên hệ',
    'people_list_show_dead' => 'Hiện người đã qua đời (:count)',
    'people_list_hide_dead' => 'Ẩn người đã qua đời (:count)',
    'people_search' => 'Tìm kiếm liên hệ…',
    'people_search_no_results' => 'Không tìm thấy kết quả',
    'people_search_next' => 'Kế tiếp',
    'people_search_prev' => 'Trước',
    'people_search_rows_per_page' => 'Số dòng trên mỗi trang',
    'people_search_of' => 'của',
    'people_search_page' => 'Trang',
    'people_search_all' => 'Tất cả',
    'people_add_new' => 'Thêm người mới',
    'people_list_account_usage' => 'Tài khoản của bạn sử dụng: :current/:limit liên hệ',
    'people_list_account_upgrade_title' => 'Nâng cấp tài khoản của bạn để mở khoá tất cả tính năng.',
    'people_list_account_upgrade_cta' => 'Nâng cấp ngay',
    'people_list_untagged' => 'Xem liên hệ không được gắn thẻ',
    'people_list_filter_untag' => 'Hiện tất cả liên hệ không được gắn thẻ',
    'archived_contact_readonly' => 'Liên hệ đã lưu trữ không thể sửa, hãy bỏ lưu trữ trước.',

    // people add
    'people_add_title' => 'Thêm người mới',
    'people_add_missing' => 'Không có người nào - hãy thêm một người mới ngay bây giờ',
    'people_add_firstname' => 'Tên',
    'people_add_middlename' => 'Tên đệm (tùy chọn)',
    'people_add_lastname' => 'Họ (Tuỳ chọn)',
    'people_add_email' => 'Email (Tùy chọn)',
    'people_add_nickname' => 'Biệt danh (Tuỳ chọn)',
    'people_add_cta' => 'Thêm',
    'people_save_and_add_another_cta' => 'Gửi và thêm một người khác',
    'people_add_success' => ':name đã được tạo thành công',
    'people_add_gender' => 'Giới tính',
    'people_delete_success' => 'Liên hệ đã bị xoá',
    'people_delete_message' => 'Xóa liên hệ',
    'people_delete_confirmation' => 'Bạn chắc chắn muốn xóa liên hệ :name? Việc xóa sẽ không thể khôi phục.',
    'people_add_birthday_reminder' => 'Chúc mừng sinh nhật tới :name',
    'people_add_birthday_reminder_deceased' => ':name sẽ tổ chức sinh nhật vào ngày này',
    'people_add_import' => 'Bạn có muốn <a href=":url">nhập danh bạ của bạn</a>?',
    'people_edit_email_error' => 'Đã có liên hệ trong tài khoản của bạn sử dụng địa chỉ email này. Hãy chọn một cái khác.',
    'people_export' => 'Xuất dưới dạng vCard',
    'people_add_reminder_for_birthday' => 'Tạo lời nhắc sinh nhật hàng năm',

    // show
    'section_contact_information' => 'Thông tin liên hệ',
    'section_personal_activities' => 'Hoạt động',
    'section_personal_reminders' => 'Lời nhắc',
    'section_personal_tasks' => 'Nhiệm vụ',
    'section_personal_gifts' => 'Quà tặng',
    'section_personal_notes' => 'Ghi chú',

    // archived contacts
    'list_link_to_active_contacts' => 'Bạn đang xem liên hệ đã lưu trữ. Hãy xem <a href=":url">danh sách liên hệ đang hoạt động</a>.',
    'list_link_to_archived_contacts' => 'Danh sách các liên hệ đã lưu trữ',

    // Header
    'me' => 'Đây là bạn',
    'edit_contact_information' => 'Sửa thông tin liên hệ',
    'contact_archive' => 'Lưu trữ liên hệ',
    'contact_unarchive' => 'Bỏ lưu trữ liên hệ',
    'contact_archive_help' => 'Liên hệ đã lưu trữ sẽ không hiện ở danh sách liên hệ, nhưng vẫn hiển thị ở kết quả tìm kiếm.',
    'call_button' => 'Ghi nhật ký cuộc gọi',
    'set_favorite' => 'Liên hệ ưa thích sẽ được đặt ở đầu danh sách',

    // Stay in touch
    'stay_in_touch' => 'Giữ liên lạc',
    'stay_in_touch_frequency' => 'Giữ liên lạc mỗi ngày|Giữ liên lạc mỗi  {count} ngày',
    'stay_in_touch_next_date' => 'Next due: {date}',
    'stay_in_touch_invalid' => 'Tần suất phải là số lớn hơn 0.',
    'stay_in_touch_premium' => 'Bạn cần nâng cấp tài khoản để sử dụng tính năng này',
    'stay_in_touch_modal_title' => 'Giữ liên lạc',
    'stay_in_touch_modal_desc' => 'Chúng tôi có thể nhắc nhở bạn bằng email để giữ liên lạc với {firstname} đều đặn.',
    'stay_in_touch_modal_label' => 'Gửi email cho tôi mỗi... {count} ngày',

    // Calls
    'modal_call_title' => 'Ghi nhật ký cuộc gọi',
    'modal_call_comment' => 'Bạn đã nói về chuyện gì? (tùy chọn)',
    'modal_call_exact_date' => 'Cuộc gọi xảy ra vào',
    'modal_call_who_called' => 'Ai đã gọi?',
    'modal_call_emotion' => 'Bạn có muốn ghi lại cảm giác của bạn trong cuộc gọi này không? (tùy chọn)',
    'calls_add_success' => 'Đã lưu cuộc gọi.',
    'call_delete_confirmation' => 'Bạn chắc chắn muốn xóa cuộc gọi này?',
    'call_delete_success' => 'Đã xóa cuộc gọi thành công',
    'call_title' => 'Cuộc gọi điện thoại',
    'call_empty_comment' => 'Không có chi tiết',
    'call_blank_title' => 'Giữ theo dõi các cuộc gọi bạn đã thực hiện với {name}',
    'call_blank_desc' => 'Bạn đã gọi {name}',
    'call_you_called' => 'Bạn đã gọi',
    'call_he_called' => '{name} đã gọi',
    'call_emotions' => 'Cảm xúc:',

    // Conversation
    'conversation_blank' => 'Ghi lại cuộc hội thoại giữa bạn và :name trên mạng xã hội, SMS…',
    'conversation_delete_link' => 'Xóa cuộc hội thoại',
    'conversation_edit_title' => 'Sửa cuộc hội thoại',
    'conversation_edit_delete' => 'Bạn chắc chắn muốn xóa vĩnh viễn cuộc hội thoại này?',
    'conversation_add_success' => 'Thêm hội thoại thành công.',
    'conversation_edit_success' => 'Cập nhật hội thoại thành công.',
    'conversation_delete_success' => 'Xóa hội thoại thành công.',
    'conversation_add_title' => 'Ghi cuộc hội thoại mới',
    'conversation_add_when' => 'Bạn có cuộc hội thoại này khi nào?',
    'conversation_add_who_wrote' => 'Ai đã gửi tin nhắn này?',
    'conversation_add_how' => 'Bạn giao tiếp như thế nào?',
    'conversation_add_you' => 'bạn',
    'conversation_add_content' => 'Ghi xuống những gì đã được nói',
    'conversation_add_what_was_said' => 'Bạn đã nói gì?',
    'conversation_add_another' => 'Thêm tin nhắn khác',
    'conversation_add_error' => 'Phải có ít nhất một tin nhắn.',
    'conversation_list_table_messages' => 'Tin nhắn',
    'conversation_list_table_content' => 'Một phần nội dung (tin nhắn mới nhất)',
    'conversation_list_title' => 'Cuộc trò chuyện',
    'conversation_list_cta' => 'Nhật ký trò chuyện',

    // age - birthday
    'birthdate_not_set' => 'Ngày sinh chưa được cài đặt',
    'age_approximate_in_years' => 'khoảng :age tuổi',
    'age_exact_in_years' => ':age tuổi',
    'age_exact_birthdate' => 'sinh ngày :date',

    // Last called
    'last_called' => 'Lần gọi gần đây nhất: :date',
    'last_talked_to' => 'Lần gọi gần đây nhất: {date}',
    'last_called_empty' => 'Lần gọi gần đây nhất: không rõ',
    'last_activity_date' => 'Lần hoạt động cùng nhau gần đây nhất: :date',
    'last_activity_date_empty' => 'Lần hoạt động cùng nhau gần đây nhất: không rõ',

    // additional information
    'information_edit_success' => 'Hồ sơ đã được cập nhật thành công',
    'information_edit_title' => 'Sửa thông tin cá nhân của :name',
    'information_edit_max_size' => 'Tối đa :size Kb.',
    'information_edit_max_size2' => 'Tối đa {size} Kb.',
    'information_edit_firstname' => 'Tên',
    'information_edit_lastname' => 'Họ (Tùy chọn)',
    'information_edit_description' => 'Mô tả (tùy chọn)',
    'information_edit_description_help' => 'Sử dụng trong danh sách liên hệ để thêm vài ngữ cảnh nếu cần thiết.',
    'information_edit_unknown' => 'Tôi không biết tuổi người này',
    'information_edit_probably' => 'Người này có lẽ là…',
    'information_edit_not_year' => 'Tôi biết ngày và tháng sinh của người này, nhưng không biết năm…',
    'information_edit_exact' => 'Tôi biết chính xác sinh nhật của người này…',
    'information_edit_birthdate_label' => 'Sinh nhật',
    'information_no_work_defined' => 'Không có thông tin công việc',
    'information_work_at' => 'ở :company',
    'work_add_cta' => 'Cập nhật thông tin công việc',
    'work_edit_success' => 'Đã cập nhật thông tin công việc',
    'work_edit_title' => 'Cập nhật thông tin công việc của :name',
    'work_edit_job' => 'Tên công việc (tuỳ chọn)',
    'work_edit_company' => 'Tên công ty (nếu có)',
    'work_information' => 'Chi tiết công việc',

    // food preferences
    'food_preferences_add_success' => 'Sở thích ăn uống đã được lưu',
    'food_preferences_edit_description' => 'Có thể :firstname hoặc ai đó trong gia đình :family bị dị ứng. Hoặc không thích một chai rượu cụ thể. Đánh dấu ở đây để bạn có thể nhớ trong lần tới bạn mời họ ăn tối',
    'food_preferences_edit_description_no_last_name' => 'Có thể :firstname bị dị ứng. Hoặc không thích một chai rượu cụ thể. Đánh dấu ở đây để bạn có thể nhớ trong lần tới bạn mời họ ăn tối',
    'food_preferences_edit_title' => 'Trình bày sở thích ăn uống',
    'food_preferences_edit_cta' => 'Lưu sở thích ăn uống',
    'food_preferences_title' => 'Sở thích ăn uống',
    'food_preferences_cta' => 'Thêm sở thích ăn uống',

    // reminders
    'reminders_blank_title' => 'Có điều gì bạn muốn được nhắc về :name?',
    'reminders_blank_add_activity' => 'Thêm lời nhắc',
    'reminders_add_title' => 'Bạn muốn được nhắc điều gì về :name?',
    'reminders_add_description' => 'Hãy nhắc tôi…',
    'reminders_add_next_time' => 'Lần tới là khi nào bạn muốn được nhắc về điều này?',
    'reminders_add_once' => 'Nhắc tôi về cái này một lần',
    'reminders_add_recurrent' => 'Nhắc tôi về cái này mỗi',
    'reminders_add_starting_from' => 'bắt đầu từ ngày chọn phía trên',
    'reminders_add_cta' => 'Thêm lời nhắc',
    'reminders_edit_update_cta' => 'Cập nhật lời nhắc',
    'reminders_add_error_custom_text' => 'Bạn cần chỉ ra một lời nhắn cho lời nhắc này',
    'reminders_create_success' => 'Thêm nhắc nhở thành công',
    'reminders_delete_success' => 'Xóa nhắc nhở thành công',
    'reminders_update_success' => 'Cập nhật nhắc nhở thành công',
    'reminders_add_optional_comment' => 'Bình luận không bắt buộc',

    'reminder_frequency_day' => 'mỗi :number ngày',
    'reminder_frequency_week' => 'mỗi :number tuần',
    'reminder_frequency_month' => 'mỗi :number tháng',
    'reminder_frequency_year' => 'mỗi :number năm',
    'reminder_frequency_one_time' => 'vào ngày :date',
    'reminders_delete_confirmation' => 'Bạn chắc chắn muốn hủy lời nhắc này?',
    'reminders_delete_cta' => 'Xóa',
    'reminders_next_expected_date' => 'vào',
    'reminders_cta' => 'Thêm lời nhắc',
    'reminders_description' => 'Chúng tôi sẽ gửi email cho mỗi lời nhắc bên dưới. Nhắc nhở được gửi mỗi buổi sáng của ngày sự kiện sẽ xảy ra. Lời nhắc sinh nhật được tự động thêm vào sẽ không thể xóa. Nếu bạn muốn đổi ngày, hãy sửa sinh nhật trong liên hệ.',
    'reminders_one_time' => 'Một lần',
    'reminders_type_week' => 'tuần',
    'reminders_type_month' => 'tháng',
    'reminders_type_year' => 'năm',
    'reminders_birthday' => 'Sinh nhật của :name',
    'reminders_free_plan_warning' => 'Bạn đang ở gói miễn phí. Không email nào được gửi ở gói này. Để nhận lời nhắc của bạn qua email, hãy nâng cấp tài khoản.',

    // relationships
    'relationship_form_add' => 'Thêm mối quan hệ mới',
    'relationship_form_edit' => 'Sửa mối quan hệ hiện tại',
    'relationship_form_is_with' => 'Người này là…',
    'relationship_form_is_with_name' => ':name là…',
    'relationship_form_add_choice' => 'Ai là người có mối quan hệ với?',
    'relationship_form_create_contact' => 'Thêm người mới',
    'relationship_form_associate_contact' => 'Thêm vào một liên hệ có sẵn',
    'relationship_form_associate_dropdown' => 'Tìm và chọn liên hệ ở dropdown dưới đây',
    'relationship_form_associate_dropdown_placeholder' => 'Tìm và chọn liên hệ đã có',
    'relationship_form_also_create_contact' => 'Tạo mục liên hệ cho người này.',
    'relationship_form_add_description' => 'Điều này sẽ cho phép bạn đối xử người này giống với các liên hệ khác.',
    'relationship_form_add_no_existing_contact' => 'Bạn không có liên hệ nào có liên quan đến :name lúc này.',
    'relationship_delete_confirmation' => 'Bạn chắc chắn muốn xóa mối quan hệ này? Việc xóa sẽ không thể khôi phục.',
    'relationship_unlink_confirmation' => 'Bạn chắc chắn muốn xóa mối quan hệ này? Người này sẽ không bị xóa - chỉ có mối quan hệ giữa hai người bị xóa.',
    'relationship_form_add_success' => 'Thiết lập mối quan hệ thành công.',
    'relationship_form_deletion_success' => 'Đã xóa mối quan hệ.',

    // tasks
    'tasks_title' => 'Nhiệm vụ',
    'tasks_blank_title' => 'Bạn chưa có nhiệm vụ nào.',
    'tasks_form_title' => 'Tiêu đề',
    'tasks_form_description' => 'Mô tả (tùy chọn)',
    'tasks_add_task' => 'Thêm nhiệm vụ',
    'tasks_delete_success' => 'Đã xóa nhiệm vụ thành công',
    'tasks_complete_success' => 'Đã thay đổi trạng thái nhiệm vụ thành công',

    // activities
    'activity_title' => 'Hoạt động',
    'activity_type_category_simple_activities' => 'Hoạt động đơn giản',
    'activity_type_category_sport' => 'Thể thao',
    'activity_type_category_food' => 'Ẩm thực',
    'activity_type_category_cultural_activities' => 'Hoạt động văn hoá',
    'activity_type_just_hung_out' => 'vừa đi chơi',
    'activity_type_watched_movie_at_home' => 'xem phim ở nhà',
    'activity_type_talked_at_home' => 'nói chuyện ở nhà',
    'activity_type_did_sport_activities_together' => 'chơi thể thao cùng nhau',
    'activity_type_ate_at_his_place' => 'ăn ở chỗ của họ',
    'activity_type_went_bar' => 'đến bar',
    'activity_type_ate_at_home' => 'ăn ở nhà',
    'activity_type_picnicked' => 'picnic',
    'activity_type_ate_restaurant' => 'ăn ở nhà hàng',
    'activity_type_went_theater' => 'đến rạp chiếu phim',
    'activity_type_went_concert' => 'đến concert',
    'activity_type_went_play' => 'đi chơi',
    'activity_type_went_museum' => 'đến viện bảo tàng',
    'activities_add_activity' => 'Thêm hoạt động',
    'activities_add_more_details' => 'Thêm thông tin chi tiết hơn',
    'activities_add_emotions' => 'Thêm cảm xúc',
    'activities_add_category' => 'Cho biết một danh mục',
    'activities_add_participants_cta' => 'Thêm người tham gia',
    'activities_item_information' => ':Activity. Đã xảy ra vào :date',
    'activities_add_title' => 'Bạn đã làm gì với {name}?',
    'activities_summary' => 'Mô tả những gì bạn đã làm',
    'activities_add_pick_activity' => 'Bạn có muốn phân loại hoạt động này không? Bạn không nhất thiết phải làm, nhưng nó sẽ giúp thống kê sau này (không bắt buộc)',
    'activities_add_date_occured' => 'Hoạt động này xảy ra vào…',
    'activities_add_participants' => 'Ai đã tham gia hoạt động này ngoài {name}? (không bắt buộc)',
    'activities_add_emotions_title' => 'Bạn có muốn ghi lại cảm giác của mình trong hoạt động này không? (không bắt buộc)',
    'activities_blank_title' => 'Theo dõi những gì bạn đã làm với {name} trong quá khứ và những gì bạn đã nói',
    'activities_blank_add_activity' => 'Thêm hoạt động',
    'activities_add_success' => 'Thêm hoạt động thành công',
    'activities_add_error' => 'Có lỗi xảy ra khi thêm hoạt động',
    'activities_update_success' => 'Cập nhật hoạt động thành công',
    'activities_delete_success' => 'Xoá hoạt động thành công',
    'activities_who_was_involved' => 'Ai đã tham gia?',
    'activities_activity' => 'Danh mục hoạt động',
    'activities_view_activities_report' => 'Xem báo cáo hoạt động',
    'activities_profile_title' => 'Báo cáo hoạt động giữa :name và bạn',
    'activities_profile_subtitle' => 'Bạn đã ghi lại tất cả :total_activities hoạt động với :name và :activities_last_twelve_months hoạt động trong 12 tháng qua.',
    'activities_profile_year_summary_activity_types' => 'Dưới đây là bảng phân tích các loại hoạt động các bạn đã làm cùng nhau trong năm :year',
    'activities_profile_year_summary' => 'Dưới đây là những gì hai bạn đã làm trong năm :year',
    'activities_profile_number_occurences' => ':value hoạt động',
    'activities_list_participants' => 'Participants ({total}):',
    'activities_list_emotions' => 'Cảm thấy:',
    'activities_list_date' => 'Xảy ra vào',
    'activities_list_category' => 'Thể loại:',

    // notes
    'notes_create_success' => 'Tạo ghi chú thành công',
    'notes_update_success' => 'Lưu ghi chú thành công',
    'notes_delete_success' => 'Xoá ghi chú thành công',
    'notes_add_cta' => 'Thêm ghi chú',
    'notes_favorite' => 'Thêm/xoá khỏi mục yêu thích',
    'notes_delete_title' => 'Xoá ghi chú',
    'notes_delete_confirmation' => 'Bạn chắc chắn muốn xoá ghi chú này vĩnh viễn?',

    // gifts
    'gifts_title' => 'Quà tặng',
    'gifts_add_success' => 'Thêm quà thành công',
    'gifts_delete_success' => 'Xoá quà thành công',
    'gifts_delete_confirmation' => 'Bạn có chắc muốn xoá quà này?',
    'gifts_add_gift' => 'Thêm quà',
    'gifts_link' => 'Liên kết',
    'gifts_for' => 'Cho: {name}',
    'gifts_delete_cta' => 'Xóa',
    'gifts_add_title' => 'Quản lý quà cho :name',
    'gifts_add_gift_idea' => 'Ý tưởng quà tặng',
    'gifts_add_gift_already_offered' => 'Quà đã tặng',
    'gifts_add_gift_received' => 'Quà đã nhận',
    'gifts_add_gift_title' => 'Đây là quà gì?',
    'gifts_add_gift_name' => 'Tên quà',
    'gifts_add_link' => 'Đường dẫn đến trang web (tuỳ chọn)',
    'gifts_add_value' => 'Giá trị (tuỳ chọn)',
    'gifts_add_comment' => 'Nhận xét (tuỳ chọn)',
    'gifts_add_recipient' => 'Người nhận (tuỳ chọn)',
    'gifts_add_recipient_field' => 'Người nhận',
    'gifts_add_photo' => 'Ảnh (tuỳ chọn)',
    'gifts_add_photo_title' => 'Thêm ảnh cho món quà này',
    'gifts_add_someone' => 'Món quà này đặc biệt dành cho một người nào đó trong gia đình của {name}',
    'gifts_delete_title' => 'Xoá quà tặng',
    'gifts_ideas' => 'Ý tưởng quà tặng',
    'gifts_offered' => 'Quà đã tặng',
    'gifts_offered_as_an_idea' => 'Đánh dấu là một ý tưởng',
    'gifts_received' => 'Quà đã nhận',
    'gifts_view_comment' => 'Xem bình luận',
    'gifts_mark_offered' => 'Đánh dấu là đã tặng',
    'gifts_update_success' => 'Cập nhật quà tặng thành công',
    'gifts_add_date' => 'Ngày (không bắt buộc)',

    // debts
    'debt_delete_confirmation' => 'Bạn chắc chắn muốn xóa khoản nợ này?',
    'debt_delete_success' => 'Đã xóa khoản nợ thành công',
    'debt_add_success' => 'Đã thêm khoản nợ thành công',
    'debt_title' => 'Khoản nợ',
    'debt_add_cta' => 'Thêm khoản nợ',
    'debt_you_owe' => 'Bạn nợ :amount',
    'debt_they_owe' => ':name nợ bạn :amount',
    'debt_add_title' => 'Quản lý khoản nợ',
    'debt_add_you_owe' => 'Bạn nợ :name',
    'debt_add_they_owe' => ':name nợ bạn',
    'debt_add_amount' => 'lấy tổng của',
    'debt_add_reason' => 'vì lý do sau (không bắt buộc)',
    'debt_add_add_cta' => 'Thêm khoản nợ',
    'debt_edit_update_cta' => 'Cập nhật khoản nợ',
    'debt_edit_success' => 'Cập nhật khoản nợ thành công',
    'debts_blank_title' => 'Quản lý các khoản bạn nợ :name hoặc :name nợ bạn',

    // tags
    'tag_edit' => 'Sửa thẻ tag',
    'tag_add' => 'Thêm thẻ tag',
    'tag_add_search' => 'Thêm hoặc tìm thẻ tag',
    'tag_no_tags' => 'Không có thẻ tag nào',

    // Introductions
    'introductions_sidebar_title' => 'Bạn đã gặp nhau như thế nào',
    'introductions_blank_cta' => 'Trình bày bạn đã gặp :name như thế nào',
    'introductions_title_edit' => 'Bạn đã gặp :name thế nào?',
    'introductions_additional_info' => 'Diễn giải làm thế nào bạn gặp và ở đâu',
    'introductions_edit_met_through' => 'Có ai đó giới thiệu bạn cho người này?',
    'introductions_no_met_through' => 'Không có ai',
    'introductions_first_met_date' => 'Ngày bạn gặp',
    'introductions_no_first_met_date' => 'Tôi không biết ngày chúng tôi gặp',
    'introductions_first_met_date_known' => 'Đây là ngày chúng tôi gặp',
    'introductions_add_reminder' => 'Thêm lời nhắc để kỷ niệm cuộc gặp gỡ này vào ngày kỷ niệm sự kiện này đã xảy ra',
    'introductions_update_success' => 'Cập nhật thông tin làm thế nào gặp người này thành công',
    'introductions_met_through' => 'Đã gặp qua <a href=":url">:name</a>',
    'introductions_met_date' => 'Gặp vào :date',
    'introductions_reminder_title' => 'Kỷ niệm ngày đầu tiên gặp nhau',

    // Deceased
    'deceased_reminder_title' => 'Kỷ niệm ngày mất của :name',
    'deceased_mark_person_deceased' => 'Đánh dấu người này đã qua đời',
    'deceased_know_date' => 'Tôi biết ngày người này mất',
    'deceased_add_reminder' => 'Thêm nhắc nhở cho ngày này',
    'deceased_label' => 'Đã qua đời',
    'deceased_date_label' => 'Ngày mất',
    'deceased_label_with_date' => 'Đã mất vào :date',
    'deceased_age' => 'Tuổi thọ',

    // Contact information
    'contact_info_title' => 'Thông tin liên hệ',
    'contact_info_form_content' => 'Nội dung',
    'contact_info_form_contact_type' => 'Loại liên hệ',
    'contact_info_form_personalize' => 'Cá nhân hoá',
    'contact_info_address' => 'Sống tại',

    // Addresses
    'contact_address_title' => 'Địa chỉ',
    'contact_address_form_name' => 'Nhãn (không bắt buộc)',
    'contact_address_form_street' => 'Tên đường (không bắt buộc)',
    'contact_address_form_city' => 'Thành phố (không bắt buộc)',
    'contact_address_form_province' => 'Tỉnh (không bắt buộc)',
    'contact_address_form_postal_code' => 'Mã bưu điện (không bắt buộc)',
    'contact_address_form_country' => 'Quốc gia (không bắt buộc)',
    'contact_address_form_latitude' => 'Vĩ độ (chỉ số) (không bắt buộc)',
    'contact_address_form_longitude' => 'Kinh độ (chỉ số) (không bắt buộc)',

    // Pets
    'pets_kind' => 'Loại thú cưng',
    'pets_name' => 'Tên (tùy chọn)',
    'pets_create_success' => 'Thêm thú cưng thành công',
    'pets_update_success' => 'Cập nhật thú cưng thành công',
    'pets_delete_success' => 'Đã xóa thú cưng',
    'pets_title' => 'Thú cưng',
    'pets_reptile' => 'Bò sát',
    'pets_bird' => 'Chim',
    'pets_cat' => 'Mèo',
    'pets_dog' => 'Chó',
    'pets_fish' => 'Cá',
    'pets_hamster' => 'Chuột hamster',
    'pets_horse' => 'Ngựa',
    'pets_rabbit' => 'Thỏ',
    'pets_rat' => 'Chuột',
    'pets_small_animal' => 'Động vật nhỏ',
    'pets_other' => 'Khác',

    // life events
    'life_event_list_tab_life_events' => 'Sự kiện trong đời',
    'life_event_list_tab_other' => 'Ghi chú, nhắc nhở, …',
    'life_event_list_title' => 'Sự kiện trong đời',
    'life_event_blank' => 'Ghi lại những gì xảy ra trong đời của {name} để tham chiếu trong tương lai.',
    'life_event_list_cta' => 'Thêm sự kiện trong đời',
    'life_event_create_category' => 'Tất cả thể loại',
    'life_event_create_life_event' => 'Thêm sự kiện trong đời',
    'life_event_create_default_title' => 'Tiêu đề (tuỳ chọn)',
    'life_event_create_default_story' => 'Câu chuyện (tuỳ chọn)',
    'life_event_create_date' => 'Bạn không cần chỉ rõ ngày hoặc tháng - chỉ bắt buộc năm.',
    'life_event_create_default_description' => 'Thêm thông tin về những gì bạn biết',
    'life_event_create_add_yearly_reminder' => 'Thêm nhắc nhở hàng năm cho sự kiện này',
    'life_event_create_success' => 'Đã thêm sự kiện trong đời',
    'life_event_delete_title' => 'Xoá sự kiện trong đời',
    'life_event_delete_description' => 'Bạn chắc chắn muốn xoá vĩnh viễn sự kiện này?',
    'life_event_delete_success' => 'Đã xoá sự kiện',
    'life_event_date_it_happened' => 'Ngày xảy ra',
    'life_event_category_work_education' => 'Công việc & học vấn',
    'life_event_category_family_relationships' => 'Gia đình & các mối quan hệ',
    'life_event_category_home_living' => 'Nhà cửa & đời sống',
    'life_event_category_health_wellness' => 'Sức khỏe thể chất & tinh thần',
    'life_event_category_travel_experiences' => 'Du lịch và trải nghiệm',
    'life_event_sentence_new_job' => 'Đã bắt đầu công việc mới',
    'life_event_sentence_retirement' => 'Nghỉ hưu',
    'life_event_sentence_new_school' => 'Đã bắt đầu đi học',
    'life_event_sentence_study_abroad' => 'Du học',
    'life_event_sentence_volunteer_work' => 'Bắt đầu công việc tình nguyện',
    'life_event_sentence_published_book_or_paper' => 'Xuất bản một nghiên cứu',
    'life_event_sentence_military_service' => 'Đã bắt đầu nghĩa vụ quân sự',
    'life_event_sentence_new_relationship' => 'Đã bắt đầu mối quan hệ',
    'life_event_sentence_engagement' => 'Đã đính hôn',
    'life_event_sentence_marriage' => 'Đã kết hơn',
    'life_event_sentence_anniversary' => 'Kỉ niệm',
    'life_event_sentence_expecting_a_baby' => 'Muốn có con',
    'life_event_sentence_new_child' => 'Đã có con',
    'life_event_sentence_new_family_member' => 'Đã thêm thành viên gia đình',
    'life_event_sentence_new_pet' => 'Đã có thú cưng',
    'life_event_sentence_end_of_relationship' => 'Đã kết thúc mối quan hệ',
    'life_event_sentence_loss_of_a_loved_one' => 'Đã mất một người thân yêu',
    'life_event_sentence_moved' => 'Đã chuyển đi',
    'life_event_sentence_bought_a_home' => 'Đã mua nhà',
    'life_event_sentence_home_improvement' => 'Cải tạo nhà',
    'life_event_sentence_holidays' => 'Đã đi vào ngày lễ',
    'life_event_sentence_new_vehicle' => 'Đã có xe mới',
    'life_event_sentence_new_roommate' => 'Đã có bạn cùng phòng',
    'life_event_sentence_overcame_an_illness' => 'Đã vượt qua bệnh tật',
    'life_event_sentence_quit_a_habit' => 'Bỏ một thói quen',
    'life_event_sentence_new_eating_habits' => 'Đã bắt đầu một thói quen ăn uống mới',
    'life_event_sentence_weight_loss' => 'Giảm cân',
    'life_event_sentence_wear_glass_or_contact' => 'Bắt đầu đeo kinh hoặc kính áp tròng',
    'life_event_sentence_broken_bone' => 'Gãy xương',
    'life_event_sentence_removed_braces' => 'Đã bỏ niềng',
    'life_event_sentence_surgery' => 'Đã phẫu thuật',
    'life_event_sentence_dentist' => 'Đến nha sĩ',
    'life_event_sentence_new_sport' => 'Bắt đầu chơi thể thao',
    'life_event_sentence_new_hobby' => 'Bắt đầu một sở thích',
    'life_event_sentence_new_instrument' => 'Học một nhạc cụ mới',
    'life_event_sentence_new_language' => 'Học một ngôn ngữ mới',
    'life_event_sentence_tattoo_or_piercing' => 'Có một hình xăm hoặc xỏ lỗ',
    'life_event_sentence_new_license' => 'Có bằng lái',
    'life_event_sentence_travel' => 'Du lịch',
    'life_event_sentence_achievement_or_award' => 'Có giải thưởng hoặc thành tựu',
    'life_event_sentence_changed_beliefs' => 'Thay đổi niềm tin',
    'life_event_sentence_first_word' => 'Nói lần đầu tiên',
    'life_event_sentence_first_kiss' => 'Hôn lần đầu tiên',

    // documents
    'document_list_title' => 'Tài liệu',
    'document_list_cta' => 'Tải tài liệu lên',
    'document_list_blank_desc' => 'Bạn có thể lưu trữ tài liệu liên quan đến người này ở đây.',
    'document_upload_zone_cta' => 'Tải lên tệp tin',
    'document_upload_zone_progress' => 'Đang tải lên tài liệu…',
    'document_upload_zone_error' => 'Có lỗi xảy ra khi tải tài liệu lên. Hãy thử lại sau.',

    // Photos
    'photo_title' => 'Ảnh',
    'photo_list_title' => 'Ảnh liên quan',
    'photo_list_cta' => 'Tải ảnh lên',
    'photo_list_blank_desc' => 'Bạn có thể lưu ảnh về liên hệ này. Tải lên ngay!',
    'photo_upload_zone_cta' => 'Tải ảnh lên',
    'photo_current_profile_pic' => 'Ảnh đại diện hiện tại',
    'photo_make_profile_pic' => 'Tạo ảnh đại diện',
    'photo_delete' => 'Xóa ảnh',
    'photo_next' => 'Ảnh tiếp theo ❯',
    'photo_previous' => '❮ Ảnh trước',

    // Avatars
    'avatar_change_title' => 'Đổi ảnh đại diện',
    'avatar_question' => 'Bạn muốn dùng ảnh đại diện nào?',
    'avatar_default_avatar' => 'Ảnh đại diện mặc định',
    'avatar_adorable_avatar' => 'Ảnh đại diện Adorable',
    'avatar_gravatar' => 'Gravatar được gắn với địa chỉ email của người này. <a href="https://gravatar.com/">Gravatar</a> là hệ thống toàn cầu giúp người dùng gắn email với ảnh đại diện.',
    'avatar_current' => 'Giữ hình đại diện hiện tại',
    'avatar_photo' => 'Từ ảnh bạn đã tải lên',
    'avatar_crop_new_avatar_photo' => 'Crop ảnh đại diện mới',

    // emotions
    'emotion_this_made_me_feel' => 'Điều này khiến bạn cảm thấy…',

    // logs
    'auditlogs_link' => 'Lịch sử',
    'auditlogs_title' => 'Mọi thứ đã xảy ra với :name',
    'auditlogs_breadcrumb' => 'Lịch sử',
    'auditlogs_author' => 'Bởi :name vào :date',

    // contact field label
    'contact_field_label_home' => 'Nhà',
    'contact_field_label_work' => 'Cơ quan',
    'contact_field_label_cell' => 'Di động',
    'contact_field_label_fax' => 'Fax',
    'contact_field_label_pager' => 'Máy nhắn tin',
    'contact_field_label_main' => 'Chính',
    'contact_field_label_other' => 'Khác',
    'contact_field_label_personal' => 'Cá nhân',
];
