<?php
namespace Aws\Artifact\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Artifact** service.
 */
class ArtifactException extends AwsException {}
