<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'dashboard_blank_title' => 'Seja bem-vindo à sua conta!',
    'dashboard_blank_description' => 'Monica é o lugar para organizar todas as suas interações com pessoas importantes para você.',
    'dashboard_blank_cta' => 'Adicione seu primeiro contato',
    'dashboard_blank_illustration' => 'Ilustração por <a href=":url">Freepik</a>',

    'notes_title' => 'Você ainda não tem nenhuma nota favorita.',

    'tab_recent_calls' => 'Chamadas recentes',
    'tab_favorite_notes' => 'Notas favoritas',
    'tab_calls_blank' => 'Você ainda não registrou uma chamada.',
    'tab_debts' => 'Dívidas',
    'tab_debts_blank' => 'Você ainda não registrou nenhuma dívida.',
    'tab_tasks' => 'Tarefas',
    'tab_tasks_blank' => 'Você ainda não tem nenhuma tarefa.',

    'tasks_add_task_placeholder' => 'De que se trata esta tarefa?',
    'tasks_tab_your_contacts' => 'Tarefas relacionadas aos seus contatos',
    'tasks_tab_your_tasks' => 'Suas tarefas',
    'tasks_add_note' => 'Pressione <kbd>Enter</kbd> para adicionar a tarefa.',
    'task_add_cta' => 'Adicionar tarefa',

    'debts_you_owe' => 'Você deve',

    'statistics_contacts' => 'Contatos',
    'statistics_activities' => 'Atividades',
    'statistics_gifts' => 'Presentes',

    'reminders_next_months' => 'Eventos nos próximos 3 meses',
    'reminders_none' => 'Nenhum lembrete para este mês.',

    'product_changes' => 'Atualizações de produtos',
    'product_view_details' => 'Ver detalhes',
];
