<?php
namespace Aws\TranscribeService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Transcribe Service** service.
 */
class TranscribeServiceException extends AwsException {}
