<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  43650 => 'tele.ring',
  43660 => 'Hutchison Drei Austria',
  43664 => 'A1 TA',
  43670 => 'spusu',
  43676 => 'T-Mobile AT',
  436770 => 'T-Mobile AT',
  436771 => 'T-Mobile AT',
  436772 => 'T-Mobile AT',
  436778 => 'T-Mobile AT',
  436779 => 'T-Mobile AT',
  4368181 => 'A1 TA',
  4368182 => 'A1 TA',
  4368183 => 'Orange AT',
  4368184 => 'A1 TA',
  43688 => 'Orange AT',
  43699 => 'Orange AT',
);
