<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reset Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'reset' => 'Heslo bylo obnoveno!',
    'sent' => 'E-mail s instrukcemi k obnovení hesla byl odeslán!',
    'token' => 'Klíč pro obnovu hesla je nesprávný.',
    'user' => 'Nepodařilo se najít uživatele s touto e-mailovou adresou.',
    'changed' => 'Password changed successfully.',
    'invalid' => 'Current password you entered is not correct.',
    'throttled' => 'Please wait before retrying.',

];
