<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Como foi o seu dia? Você pode avaliá-lo uma vez por dia.',
    'journal_come_back' => 'Obrigado. Volte amanhã para avaliar o seu dia novamente.',
    'journal_description' => 'Nota: o diário agrega entradas manuais e entradas automáticas tais como Atividades feitas com seus contactos. Embora possa apagar manualmente as entradas de diário, no caso das Atividades terá que apagá-las na página de contacto.',
    'journal_add' => 'Adicionar um registro no diário',
    'journal_edit' => 'Edit a journal entry',
    'journal_empty' => 'Empty journal',
    'journal_created_at' => 'Created at {date}',
    'journal_created_automatically' => 'Criado automaticamente',
    'journal_entry_type_journal' => 'Entrada de diário',
    'journal_entry_type_activity' => 'Atividade',
    'journal_entry_rate' => 'Você avaliou o seu dia.',
    'journal_add_comment' => 'Care to add a comment (optional)?',
    'journal_show_comment' => 'Show comment',
    'entry_delete_success' => 'O registro no diário foi eliminada com sucesso.',
    'journal_add_title' => 'Título (Opcional)',
    'journal_add_date' => 'Date',
    'journal_add_post' => 'Registro',
    'journal_add_cta' => 'Salvar',
    'journal_blank_cta' => 'Adicione seu primeiro registro no diário',
    'journal_blank_description' => 'O diário permite que você escreva eventos que aconteceram com você, para te lembrar.',
    'delete_confirmation' => 'Tem certeza que quer apagar esta entrada de diário?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
