<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  8864000 => 'Chunghwa Telecom',
  886900 => 'FarEasTone',
  8869006 => 'Chunghwa Telecom',
  8869007 => 'Chunghwa Telecom',
  8869008 => 'Chunghwa Telecom',
  8869009 => 'Chunghwa Telecom',
  8869010 => 'Taiwan Mobile',
  8869011 => 'Taiwan Mobile',
  8869012 => 'Taiwan Mobile',
  8869013 => 'Taiwan Mobile',
  8869014 => 'Taiwan Mobile',
  8869020 => 'T Star',
  8869021 => 'T Star',
  8869022 => 'T Star',
  8869023 => 'T Star',
  8869024 => 'T Star',
  8869025 => 'T Star',
  8869026 => 'T Star',
  886903 => 'FarEasTone',
  8869040 => 'Taiwan Mobile',
  8869041 => 'Taiwan Mobile',
  8869042 => 'Taiwan Mobile',
  886905 => 'Chunghwa Telecom',
  886906 => 'Asia-Pacific Telecom',
  886907 => 'Asia-Pacific Telecom',
  886908 => 'T Star',
  886909 => 'Taiwan Mobile',
  886910 => 'Chunghwa Telecom',
  886911 => 'Chunghwa Telecom',
  886912 => 'Chunghwa Telecom',
  886913 => 'FarEasTone',
  8869140 => 'Taiwan Mobile',
  8869141 => 'Taiwan Mobile',
  8869142 => 'Taiwan Mobile',
  886915 => 'FarEasTone',
  886916 => 'FarEasTone',
  886917 => 'FarEasTone',
  886918 => 'Taiwan Mobile',
  886919 => 'Chunghwa Telecom',
  886920 => 'Taiwan Mobile',
  886921 => 'Chunghwa Telecom',
  886922 => 'Taiwan Mobile',
  886923 => 'Taiwan Mobile',
  8869240 => 'Taiwan Mobile',
  8869241 => 'Taiwan Mobile',
  886925 => 'FarEasTone',
  886926 => 'FarEasTone',
  886927 => 'FarEasTone',
  886928 => 'Chunghwa Telecom',
  886929 => 'Taiwan Mobile',
  886930 => 'FarEasTone',
  886931 => 'Taiwan Mobile',
  8869310 => 'FarEasTone',
  8869311 => 'FarEasTone',
  8869312 => 'FarEasTone',
  8869313 => 'FarEasTone',
  886932 => 'Chunghwa Telecom',
  886933 => 'Chunghwa Telecom',
  886934 => 'Chunghwa Telecom',
  886935 => 'Taiwan Mobile',
  886936 => 'FarEasTone',
  886937 => 'Chunghwa Telecom',
  886938 => 'FarEasTone',
  886939 => 'Taiwan Mobile',
  886952 => 'Taiwan Mobile',
  886953 => 'Taiwan Mobile',
  8869540 => 'FarEasTone',
  8869541 => 'FarEasTone',
  886955 => 'FarEasTone',
  886956 => 'Taiwan Mobile',
  886958 => 'Taiwan Mobile',
  8869600 => 'Taiwan Mobile',
  8869601 => 'Taiwan Mobile',
  8869602 => 'Taiwan Mobile',
  8869603 => 'Taiwan Mobile',
  8869604 => 'Taiwan Mobile',
  8869605 => 'FarEasTone',
  8869606 => 'FarEasTone',
  8869607 => 'FarEasTone',
  8869608 => 'FarEasTone',
  8869609 => 'FarEasTone',
  8869610 => 'Taiwan Mobile',
  8869611 => 'Taiwan Mobile',
  8869612 => 'Taiwan Mobile',
  8869613 => 'Taiwan Mobile',
  8869614 => 'Taiwan Mobile',
  8869615 => 'Taiwan Mobile',
  8869620 => 'FarEasTone',
  886963 => 'Chunghwa Telecom',
  8869650 => 'Chunghwa Telecom',
  8869651 => 'Chunghwa Telecom',
  8869652 => 'Chunghwa Telecom',
  8869653 => 'Chunghwa Telecom',
  8869654 => 'Chunghwa Telecom',
  8869655 => 'Chunghwa Telecom',
  8869656 => 'Chunghwa Telecom',
  8869657 => 'Chunghwa Telecom',
  8869658 => 'Chunghwa Telecom',
  8869660 => 'Taiwan Mobile',
  8869661 => 'Taiwan Mobile',
  8869662 => 'Taiwan Mobile',
  8869663 => 'Taiwan Mobile',
  8869664 => 'Chunghwa Telecom',
  8869665 => 'Chunghwa Telecom',
  8869666 => 'Chunghwa Telecom',
  8869667 => 'Chunghwa Telecom',
  8869668 => 'FarEasTone',
  8869669 => 'FarEasTone',
  8869670 => 'FarEasTone',
  8869671 => 'FarEasTone',
  8869672 => 'FarEasTone',
  8869673 => 'FarEasTone',
  8869680 => 'FarEasTone',
  8869681 => 'FarEasTone',
  8869682 => 'Asia-Pacific Telecom',
  8869683 => 'Asia-Pacific Telecom',
  8869684 => 'Asia-Pacific Telecom',
  8869685 => 'Asia-Pacific Telecom',
  8869686 => 'T Star',
  8869687 => 'T Star',
  8869688 => 'T Star',
  8869689 => 'T Star',
  886970 => 'Taiwan Mobile',
  8869710 => 'Taiwan Mobile',
  8869711 => 'Taiwan Mobile',
  8869712 => 'T Star',
  8869713 => 'T Star',
  8869714 => 'T Star',
  8869715 => 'T Star',
  8869716 => 'T Star',
  8869717 => 'T Star',
  8869718 => 'T Star',
  886972 => 'Chunghwa Telecom',
  886973 => 'T Star',
  8869740 => 'Chunghwa Telecom',
  8869741 => 'Chunghwa Telecom',
  8869742 => 'FarEasTone',
  8869743 => 'FarEasTone',
  8869744 => 'Taiwan Mobile',
  8869745 => 'Taiwan Mobile',
  886975 => 'Chunghwa Telecom',
  886976 => 'FarEasTone',
  8869770 => 'Asia-Pacific Telecom',
  8869771 => 'Asia-Pacific Telecom',
  8869772 => 'Asia-Pacific Telecom',
  8869773 => 'Asia-Pacific Telecom',
  8869774 => 'Asia-Pacific Telecom',
  8869775 => 'Asia-Pacific Telecom',
  8869776 => 'Asia-Pacific Telecom',
  8869777 => 'Asia-Pacific Telecom',
  886978 => 'Chunghwa Telecom',
  886979 => 'Taiwan Mobile',
  886980 => 'Asia-Pacific Telecom',
  886981 => 'FarEasTone',
  886982 => 'Asia-Pacific Telecom',
  886983 => 'Taiwan Mobile',
  8869840 => 'FarEasTone',
  8869841 => 'FarEasTone',
  8869842 => 'Chunghwa Telecom',
  8869843 => 'Chunghwa Telecom',
  8869844 => 'Taiwan Mobile',
  8869845 => 'Taiwan Mobile',
  8869846 => 'T Star',
  8869847 => 'T Star',
  886985 => 'Asia-Pacific Telecom',
  886986 => 'T Star',
  886987 => 'Taiwan Mobile',
  886988 => 'Chunghwa Telecom',
  886989 => 'FarEasTone',
);
