<?php

/**
 * ⚠️ Edition not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'message' => 'Thanks for signing up! Please check your emails to confirm your email address.',
    'success' => 'You have successfully verified your account! You can now login.',
    'again' => 'You must verify your email before you can access the site.
                <br/>If you have not received the confirmation email check your spam folder.
                <br/>To get a new confirmation email please <a href=":url" class="alert-link">click here</a>.',
    'resend' => 'A confirmation message has been sent. Please check your mailbox.'
];
