<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  37410 => 'Երևան/Ջրվեժ',
  37411 => 'Երևան',
  37412 => 'Երևան',
  37415 => 'Երևան',
  3742220 => 'Աբովյան/Ակունք/Բյուրեղավան/Նոր Գյուղ/Վերին Պտղնի, Կոտայք',
  3742221 => 'Աբովյան/Ակունք/Բյուրեղավան/Նոր Գյուղ/Վերին Պտղնի, Կոտայք',
  3742222 => 'Աբովյան, Կոտայք',
  3742223 => 'Աբովյան, Կոտայք',
  3742224 => 'Աբովյան, Կոտայք',
  3742225 => 'Աբովյան/Արզնի/Առինջ/Գեղաշեն, Կոտայք',
  3742226 => 'Աբովյան, Կոտայք',
  3742227 => 'Գառնի/Աբովյան, Կոտայք',
  3742228 => 'Աբովյան/Ակունք/Բյուրեղավան/Նոր Գյուղ/Վերին Պտղնի, Կոտայք',
  37422281 => 'Աբովյան/Արզնի/Առինջ/Գեղաշեն, Կոտայք',
  37422290 => 'Մայակովսկի, Կոտայք',
  37422291 => 'Բալահովիտ/Կամարիս, Կոտայք',
  37422292 => 'Զովք/Աբովյան, Կոտայք',
  37422293 => 'Արամուս, Կոտայք',
  37422294 => 'Արզնի, Կոտայք',
  37422295 => 'Զովք/Աբովյան, Կոտայք',
  37422296 => 'Պտղնի, Կոտայք',
  37422297 => 'Գեղաշեն, Կոտայք',
  37422298 => 'Առինջ, Կոտայք',
  37422299 => 'Կոտայք',
  3742230 => 'Հանքավան/Հրազդան/Ծաղկաձոր, Կոտայք',
  3742231 => 'Հանքավան/Հրազդան/Ծաղկաձոր, Կոտայք',
  3742232 => 'Հրազդան, Կոտայք',
  3742233 => 'Հրազդան, Կոտայք',
  3742234 => 'Հրազդան, Կոտայք',
  3742235 => 'Ծաղկաձոր, Կոտայք',
  3742236 => 'Հրազդան, Կոտայք',
  37422370 => 'Հրազդան, Կոտայք',
  37422371 => 'Հրազդան, Կոտայք',
  37422372 => 'Հրազդան, Կոտայք',
  37422373 => 'Հրազդան, Կոտայք',
  37422374 => 'Հրազդան, Կոտայք',
  37422375 => 'Ծաղկաձոր, Կոտայք',
  37422376 => 'Ծաղկաձոր, Կոտայք',
  37422377 => 'Ծաղկաձոր, Կոտայք',
  37422378 => 'Ծաղկաձոր, Կոտայք',
  37422379 => 'Ծաղկաձոր, Կոտայք',
  3742238 => 'Հանքավան/Հրազդան/Ծաղկաձոր, Կոտայք',
  374223810 => 'Հրազդան, Կոտայք',
  374223811 => 'Հրազդան, Կոտայք',
  374223812 => 'Հրազդան, Կոտայք',
  374223813 => 'Հրազդան, Կոտայք',
  374223814 => 'Հրազդան, Կոտայք',
  374223815 => 'Ծաղկաձոր, Կոտայք',
  374223816 => 'Ծաղկաձոր, Կոտայք',
  374223817 => 'Ծաղկաձոր, Կոտայք',
  374223818 => 'Ծաղկաձոր, Կոտայք',
  374223819 => 'Ծաղկաձոր, Կոտայք',
  37422390 => 'Հրազդան, Կոտայք',
  37422391 => 'Լեռնանիստ, Կոտայք',
  37422392 => 'Հրազդան, Կոտայք',
  37422393 => 'Մեղրաձոր, Կոտայք',
  37422394 => 'Փյունիք, Կոտայք',
  37422395 => 'Հրազդան, Կոտայք',
  37422396 => 'Հրազդան, Կոտայք',
  37422397 => 'Սոլակ, Կոտայք',
  37422398 => 'Բջնի, Կոտայք',
  37422399 => 'Հրազդան, Կոտայք',
  3742240 => 'Քանաքեռավան/Նոր Գեղի/Նոր Հաճն/Եղվարդ, Կոտայք',
  3742241 => 'Քանաքեռավան/Նոր Գեղի/Նոր Հաճն/Եղվարդ, Կոտայք',
  3742242 => 'Եղվարդ, Կոտայք',
  3742243 => 'Եղվարդ, Կոտայք',
  3742244 => 'Նոր Հաճն, Կոտայք',
  3742245 => 'Եղվարդ, Կոտայք',
  37422452 => 'Զովունի, Կոտայք',
  37422453 => 'Պռոշյան, Կոտայք',
  37422454 => 'Արգել, Կոտայք',
  3742246 => 'Եղվարդ, Կոտայք',
  3742247 => 'Եղվարդ/Նոր Հաճն, Կոտայք',
  3742248 => 'Քանաքեռավան/Նոր Գեղի/Նոր Հաճն/Եղվարդ, Կոտայք',
  374224810 => 'Եղվարդ, Կոտայք',
  374224811 => 'Եղվարդ, Կոտայք',
  374224812 => 'Եղվարդ, Կոտայք',
  374224813 => 'Եղվարդ, Կոտայք',
  374224814 => 'Եղվարդ, Կոտայք',
  374224815 => 'Նոր Հաճն, Կոտայք',
  374224816 => 'Նոր Հաճն, Կոտայք',
  374224817 => 'Նոր Հաճն, Կոտայք',
  374224818 => 'Նոր Հաճն, Կոտայք',
  374224819 => 'Նոր Հաճն, Կոտայք',
  3742249 => 'Եղվարդ, Կոտայք',
  374226 => 'Չարենցավան, Կոտայք',
  37422672 => 'Արզական, Կոտայք',
  37422675 => 'Ալապարս/Վարդանավանք, Կոտայք',
  3742310 => 'Էջմիածին/Մուսալեռ/Փարաքար/Զվարթնոց, Արմավիր',
  3742311 => 'Էջմիածին/Մուսալեռ/Փարաքար/Զվարթնոց, Արմավիր',
  3742312 => 'Էջմիածին, Արմավիր',
  3742313 => 'Զվարթնոց, Արմավիր',
  3742314 => 'Էջմիածին, Արմավիր',
  3742315 => 'Էջմիածին, Արմավիր',
  3742316 => 'Էջմիածին, Արմավիր',
  3742317 => 'Զվարթնոց, Արմավիր',
  3742318 => 'Էջմիածին/Մուսալեռ/Փարաքար/Զվարթնոց, Արմավիր',
  37423181 => 'Էջմիածին, Արմավիր',
  374231817 => 'Զվարթնոց, Արմավիր',
  374231818 => 'Զվարթնոց, Արմավիր',
  374231819 => 'Զվարթնոց, Արմավիր',
  37423190 => 'Բաղրամյան, Արմավիր',
  37423191 => 'Վաչե, Արմավիր',
  37423192 => 'Էջմիածին, Արմավիր',
  37423193 => 'Էջմիածին, Արմավիր',
  37423194 => 'Էջմիածին, Արմավիր',
  37423195 => 'Նորակերտ, Արմավիր',
  37423196 => 'Էջմիածին, Արմավիր',
  37423197 => 'Էջմիածին, Արմավիր',
  37423198 => 'Ջրառատ, Արմավիր',
  37423199 => 'Խորոնք, Արմավիր',
  3742320 => 'Աղձք/Աշտարակ/Կարբի/Օշական, Արագածոտն',
  3742321 => 'Աղձք/Աշտարակ/Կարբի/Օշական, Արագածոտն',
  3742322 => 'Աշտարակ, Արագածոտն',
  3742323 => 'Աշտարակ, Արագածոտն',
  3742324 => 'Աշտարակ/Բյուրական/Օհանավան, Արագածոտն',
  3742325 => 'Աղձք/Աշտարակ/Կարբի/Օշական, Արագածոտն',
  3742326 => 'Աշտարակ, Արագածոտն',
  3742327 => 'Աղձք/Աշտարակ/Կարբի/Օշական, Արագածոտն',
  3742328 => 'Աղձք/Աշտարակ/Կարբի/Օշական, Արագածոտն',
  37423281 => 'Աշտարակ/Բյուրական/Օհանավան, Արագածոտն',
  3742329 => 'Աշտարակ, Արագածոտն',
  37423290 => 'Օհանավան, Արագածոտն',
  37423294 => 'Բյուրական, Արագածոտն',
  3742330 => 'Բաղրամյան/Լեռնագոգ, Արմավիր',
  3742331 => 'Բաղրամյան/Լեռնագոգ, Արմավիր',
  3742332 => 'Բաղրամյան, Արմավիր',
  3742333 => 'Բաղրամյան/Մյասնիկյան, Արմավիր',
  3742334 => 'Բաղրամյան/Լեռնագոգ, Արմավիր',
  3742335 => 'Բաղրամյան/Լեռնագոգ, Արմավիր',
  3742336 => 'Բաղրամյան, Արմավիր',
  3742337 => 'Բաղրամյան, Արմավիր',
  37423374 => 'Մյասնիկյան, Արմավիր',
  37423375 => 'Քարակերտ, Արմավիր',
  37423376 => 'Դալարիկ, Արմավիր',
  3742338 => 'Բաղրամյան/Լեռնագոգ, Արմավիր',
  37423381 => 'Բաղրամյան/Մյասնիկյան, Արմավիր',
  3742339 => 'Բաղրամյան, Արմավիր',
  374234 => 'Արարատ/Վեդի, Արարատ',
  3742340 => 'Արարատ/Վեդի/Ոսկետափ, Արարատ',
  3742341 => 'Արարատ/Վեդի/Ոսկետափ, Արարատ',
  3742345 => 'Արարատ/Վեդի/Ոսկետափ, Արարատ',
  374234510 => 'Վեդի, Արարատ',
  374234511 => 'Վեդի, Արարատ',
  374234512 => 'Վեդի, Արարատ',
  374234513 => 'Վեդի, Արարատ',
  374234514 => 'Վեդի, Արարատ',
  374234515 => 'Արարատ/Ուրցաձոր, Արարատ',
  374234516 => 'Արարատ/Ուրցաձոր, Արարատ',
  374234517 => 'Արարատ/Ուրցաձոր, Արարատ',
  374234518 => 'Արարատ/Ուրցաձոր, Արարատ',
  374234519 => 'Արարատ/Ուրցաձոր, Արարատ',
  37423470 => 'Վեդի, Արարատ',
  37423471 => 'Վեդի, Արարատ',
  37423472 => 'Վեդի, Արարատ',
  37423473 => 'Վեդի, Արարատ',
  37423474 => 'Վեդի, Արարատ',
  37423475 => 'Արարատ/Ուրցաձոր, Արարատ',
  37423476 => 'Արարատ/Ուրցաձոր, Արարատ',
  37423477 => 'Արարատ/Ուրցաձոր, Արարատ',
  37423478 => 'Արարատ/Ուրցաձոր, Արարատ',
  37423479 => 'Արարատ/Ուրցաձոր, Արարատ',
  37423481 => 'Այգավան, Արարատ',
  37423486 => 'Ուրցաձոր, Արարատ',
  37423492 => 'Մարտիրոսյան, Արարատ',
  37423497 => 'Փոքր Վեդի, Արարատ',
  37423498 => 'Տափերական, Արարատ',
  3742350 => 'Արտաշատ/Այգեզարդ/Դալար/Քաղցրաշեն/Մխչյան/Շահումյան, Արարատ',
  3742351 => 'Արտաշատ/Այգեզարդ/Դալար/Քաղցրաշեն/Մխչյան/Շահումյան, Արարատ',
  3742352 => 'Արտաշատ, Արարատ',
  3742353 => 'Արտաշատ/Նորաշեն, Արարատ',
  3742354 => 'Արտաշատ/Այգեզարդ/Դալար/Քաղցրաշեն/Մխչյան/Շահումյան, Արարատ',
  3742355 => 'Արտաշատ, Արարատ',
  3742356 => 'Արտաշատ, Արարատ',
  3742357 => 'Արտաշատ, Արարատ',
  3742358 => 'Արտաշատ/Այգեզարդ/Դալար/Քաղցրաշեն/Մխչյան/Շահումյան, Արարատ',
  37423581 => 'Արտաշատ/Նորաշեն, Արարատ',
  3742359 => 'Արտաշատ/Նորաշեն, Արարատ',
  3742360 => 'Այնթապ/Մասիս/Նոր Խարբերդ/Նորաբաց, Արարատ',
  3742361 => 'Այնթապ/Մասիս/Նոր Խարբերդ/Նորաբաց, Արարատ',
  3742362 => 'Մասիս, Արարատ',
  3742363 => 'Այնթապ/Մասիս, Արարատ',
  3742364 => 'Մասիս, Արարատ',
  3742365 => 'Մասիս, Արարատ',
  3742366 => 'Մասիս, Արարատ',
  3742367 => 'Այնթապ/Մասիս/Նոր Խարբերդ/Նորաբաց, Արարատ',
  3742368 => 'Այնթապ/Մասիս/Նոր Խարբերդ/Նորաբաց, Արարատ',
  37423681 => 'Մասիս, Արարատ',
  3742369 => 'Մասիս, Արարատ',
  37423699 => 'Դաշտավան, Արարատ',
  3742370 => 'Արաքս/Արմավիր/Հոկտեմբեր/Լենուղի/Մեծամոր/Զարթոնք, Արմավիր',
  3742371 => 'Արաքս/Արմավիր/Հոկտեմբեր/Լենուղի/Մեծամոր/Զարթոնք, Արմավիր',
  3742372 => 'Արմավիր',
  3742373 => 'Մեծամոր, Արմավիր',
  3742374 => 'Արմավիր',
  37423747 => 'Արաքս/Արմավիր/Հոկտեմբեր/Լենուղի/Մեծամոր/Զարթոնք, Արմավիր',
  37423748 => 'Արաքս/Արմավիր/Հոկտեմբեր/Լենուղի/Մեծամոր/Զարթոնք, Արմավիր',
  37423749 => 'Արաքս/Արմավիր/Հոկտեմբեր/Լենուղի/Մեծամոր/Զարթոնք, Արմավիր',
  3742375 => 'Արմավիր',
  3742376 => 'Արմավիր',
  3742377 => 'Արմավիր/Մրգաշատ',
  37423771 => 'Արմավիր',
  37423772 => 'Մրգաշատ, Արմավիր',
  37423779 => 'Բամբակաշատ, Արմավիր',
  3742378 => 'Արաքս/Արմավիր/Հոկտեմբեր/Լենուղի/Մեծամոր/Զարթոնք, Արմավիր',
  37423781 => 'Արմավիր',
  3742379 => 'Արմավիր/Նալբանդյան',
  37423792 => 'Նալբանդյան, Արմավիր',
  37423794 => 'Մարգարա, Արմավիր',
  37423796 => 'Տանձուտ, Արմավիր',
  37423798 => 'Շենավան, Արմավիր',
  374238 => 'Արարատ/Ավշար/Սուրենավան/Երասխ',
  3742420 => 'Մարալիկ/Սառնաղբյուր, Շիրակ',
  3742421 => 'Մարալիկ/Սառնաղբյուր, Շիրակ',
  3742422 => 'Մարալիկ, Շիրակ',
  3742423 => 'Մարալիկ, Շիրակ',
  37424231 => 'Սառնաղբյուր, Շիրակ',
  3742424 => 'Մարալիկ, Շիրակ',
  3742425 => 'Մարալիկ/Սառնաղբյուր, Շիրակ',
  3742426 => 'Մարալիկ, Շիրակ',
  3742427 => 'Մարալիկ/Սառնաղբյուր, Շիրակ',
  3742428 => 'Մարալիկ/Սառնաղբյուր, Շիրակ',
  3742429 => 'Մարալիկ, Շիրակ',
  37424293 => 'Շիրակավան, Շիրակ',
  37424297 => 'Անի Կայարան, Շիրակ',
  37424300 => 'Ախուրյան/Առափի/Կամո/Մուսայելյան, Շիրակ',
  3742440 => 'Արթիկ/Պեմզաշեն, Շիրակ',
  3742441 => 'Արթիկ/Պեմզաշեն, Շիրակ',
  3742442 => 'Արթիկ, Շիրակ',
  3742443 => 'Արթիկ, Շիրակ',
  3742444 => 'Արթիկ/Փանիկ, Շիրակ',
  3742445 => 'Արթիկ, Շիրակ',
  3742446 => 'Արթիկ, Շիրակ',
  3742447 => 'Արթիկ/Պեմզաշեն, Շիրակ',
  3742448 => 'Արթիկ/Պեմզաշեն, Շիրակ',
  37424481 => 'Արթիկ/Փանիկ, Շիրակ',
  3742449 => 'Արթիկ, Շիրակ',
  37424492 => 'Փանիկ, Շիրակ',
  37424495 => 'Արևշատ, Շիրակ',
  37424496 => 'Մեծ Մանթաշ, Շիրակ',
  374245 => 'Աշոցք, Շիրակ',
  374246 => 'Ամասիա, Շիրակ',
  374249 => 'Թալին, Արագածոտն',
  3742494 => 'Թալին/Արագած/Կաթնաղբյուր/Մաստարա, Արագածոտն',
  37424973 => 'Կաթնաղբյուր, Արագածոտն',
  37424981 => 'Թալին/Արագած/Կաթնաղբյուր/Մաստարա, Արագածոտն',
  3742499 => 'Արագածավան/Թալին, Արագածոտն',
  37424995 => 'Արագած, Արագածոտն',
  37424997 => 'Մաստարա, Արագածոտն',
  374252 => 'Ապարան, Արագածոտն',
  3742524 => 'Ապարան/Արտավան/Քուչակ, Արագածոտն',
  37425281 => 'Ապարան/Արտավան/Քուչակ, Արագածոտն',
  37425291 => 'Քուչակ, Արագածոտն',
  37425295 => 'Արտավան, Արագածոտն',
  3742530 => 'Ալավերդի/Օձուն/Ծաղկաշատ/Թումանյան, Լոռի',
  3742531 => 'Ալավերդի/Օձուն/Ծաղկաշատ/Թումանյան, Լոռի',
  3742532 => 'Ալավերդի, Լոռի',
  3742533 => 'Ալավերդի, Լոռի',
  3742534 => 'Ալավերդի, Լոռի',
  3742535 => 'Ալավերդի, Լոռի',
  37425352 => 'Ախթալա, Լոռի',
  37425353 => 'Շնող, Լոռի',
  37425356 => 'Ճոճկան, Լոռի',
  37425357 => 'Թումանյան, Լոռի',
  3742536 => 'Ալավերդի, Լոռի',
  3742537 => 'Ալավերդի/Ախթալա/Թումանյան, Լոռի',
  3742538 => 'Ալավերդի/Օձուն/Ծաղկաշատ/Թումանյան, Լոռի',
  37425381 => 'Ալավերդի/Ախթալա/Թումանյան, Լոռի',
  3742539 => 'Ալավերդի/Օձուն/Ծաղկաշատ/Թումանյան, Լոռի',
  374254 => 'Տաշիր, Լոռի',
  3742543 => 'Տաշիր/Մեծավան, Լոռի',
  37425481 => 'Տաշիր/Մեծավան, Լոռի',
  3742549 => 'Տաշիր/Մեծավան, Լոռի',
  37425494 => 'Մեծավան, Լոռի',
  374255 => 'Սպիտակ, Լոռի',
  3742560 => 'Բովաձոր/Ստեփանավան, Լոռի',
  3742561 => 'Բովաձոր/Ստեփանավան, Լոռի',
  3742562 => 'Ստեփանավան, Լոռի',
  3742563 => 'Ստեփանավան, Լոռի',
  3742564 => 'Ստեփանավան, Լոռի',
  3742565 => 'Բովաձոր/Ստեփանավան, Լոռի',
  3742566 => 'Ստեփանավան, Լոռի',
  3742567 => 'Բովաձոր/Ստեփանավան, Լոռի',
  3742568 => 'Բովաձոր/Ստեփանավան, Լոռի',
  37425681 => 'Ստեփանավան, Լոռի',
  3742569 => 'Ստեփանավան, Լոռի',
  37425691 => 'Կուրթան, Լոռի',
  37425694 => 'Ագարակ, Լոռի',
  37425695 => 'Լեջան, Լոռի',
  374257 => 'Արագած, Արագածոտն',
  3742570 => 'Ծաղկահովիտ, Արագածոտն',
  3742572 => 'Ծաղկահովիտ, Արագածոտն',
  3742573 => 'Ծաղկահովիտ, Արագածոտն',
  3742576 => 'Ծաղկահովիտ, Արագածոտն',
  37425781 => 'Ծաղկահովիտ, Արագածոտն',
  374261 => 'Սևան, Գեղարքունիք',
  374262 => 'Մարտունի, Գեղարքունիք',
  3742623 => 'Մարտունի/Վարդենիկ, Գեղարքունիք',
  37426252 => 'Վարդենիկ, Գեղարքունիք',
  37426253 => 'Վարդենիկ, Գեղարքունիք',
  37426272 => 'Լիճք, Գեղարքունիք',
  37426281 => 'Մարտունի/Վարդենիկ, Գեղարքունիք',
  37426299 => 'Երանոս, Գեղարքունիք',
  3742630 => 'Ազատամուտ/Գետահովիտ/Իջեւան/Ենոքավան, Տավուշ',
  3742631 => 'Ազատամուտ/Գետահովիտ/Իջեւան/Ենոքավան, Տավուշ',
  3742632 => 'Իջեւան/Այգեհովիտ/Աչաջուր, Տավուշ',
  3742633 => 'Իջեւան, Տավուշ',
  3742634 => 'Իջեւան, Տավուշ',
  3742635 => 'Ազատամուտ/Գետահովիտ/Իջեւան/Ենոքավան, Տավուշ',
  3742636 => 'Իջեւան, Տավուշ',
  3742637 => 'Իջեւան, Տավուշ',
  37426374 => 'Այգեհովիտ, Տավուշ',
  3742638 => 'Ազատամուտ/Գետահովիտ/Իջեւան/Ենոքավան, Տավուշ',
  37426381 => 'Իջեւան/Այգեհովիտ/Աչաջուր, Տավուշ',
  3742639 => 'Իջեւան, Տավուշ',
  37426392 => 'Աչաջուր, Տավուշ',
  37426397 => 'Ազատամուտ, Տավուշ',
  374264 => 'Գավառ, Գեղարքունիք',
  3742640 => 'Գավառ/Սարուխան, Գեղարքունիք',
  3742641 => 'Գավառ/Սարուխան, Գեղարքունիք',
  3742647 => 'Գավառ/Սարուխան, Գեղարքունիք',
  3742648 => 'Գավառ/Սարուխան, Գեղարքունիք',
  374265 => 'Ճամբարակ, Գեղարքունիք',
  3742654 => 'Ճամբարակ/Վահան, Գեղարքունիք',
  37426581 => 'Ճամբարակ/Վահան, Գեղարքունիք',
  37426596 => 'Վահան, Գեղարքունիք',
  3742660 => 'Բերդավան/Կողբ/Նոյեմբերյան, Տավուշ',
  3742661 => 'Բերդավան/Կողբ/Նոյեմբերյան, Տավուշ',
  3742662 => 'Նոյեմբերյան, Տավուշ',
  3742663 => 'Նոյեմբերյան/Ոսկեպար/Կոթի/Կողբ, Տավուշ',
  3742664 => 'Բերդավան/Կողբ/Նոյեմբերյան, Տավուշ',
  3742665 => 'Կողբ/Նոյեմբերյան, Տավուշ',
  37426652 => 'Կողբ, Տավուշ',
  37426653 => 'Կողբ, Տավուշ',
  3742666 => 'Նոյեմբերյան, Տավուշ',
  3742667 => 'Բերդավան/Նոյեմբերյան, Տավուշ',
  3742668 => 'Բերդավան/Կողբ/Նոյեմբերյան, Տավուշ',
  37426681 => 'Նոյեմբերյան/Ոսկեպար/Կոթի/Կողբ, Տավուշ',
  37426690 => 'Նոյեմբերյան, Տավուշ',
  37426691 => 'Նոյեմբերյան, Տավուշ',
  37426692 => 'Արճիս, Տավուշ',
  37426693 => 'Բաղանիս, Տավուշ',
  37426694 => 'Նոյեմբերյան, Տավուշ',
  37426695 => 'Զորական, Տավուշ',
  37426696 => 'Ոսկեպար, Տավուշ',
  37426697 => 'Նոյեմբերյան, Տավուշ',
  37426698 => 'Նոյեմբերյան, Տավուշ',
  37426699 => 'Կոթի, Տավուշ',
  3742670 => 'Այգեպար/Բերդ, Տավուշ',
  3742671 => 'Այգեպար/Բերդ, Տավուշ',
  3742672 => 'Բերդ, Տավուշ',
  3742673 => 'Բերդ/Մոսեսգեղ/Նավուր/Նորաշեն, Տավուշ',
  3742674 => 'Այգեպար/Բերդ, Տավուշ',
  3742675 => 'Արծվաբերդ/Բերդ, Տավուշ',
  3742676 => 'Բերդ, Տավուշ',
  3742677 => 'Բերդ, Տավուշ',
  3742678 => 'Այգեպար/Բերդ, Տավուշ',
  37426781 => 'Բերդ/Մոսեսգեղ/Նավուր/Նորաշեն, Տավուշ',
  3742679 => 'Բերդ, Տավուշ',
  37426791 => 'Նավուր, Տավուշ',
  37426794 => 'Թովուզ, Տավուշ',
  37426796 => 'Մոսեսգեղ, Տավուշ',
  37426797 => 'Նորաշեն, Տավուշ',
  3742680 => 'Դիլիջան, Տավուշ',
  3742682 => 'Դիլիջան, Տավուշ',
  3742683 => 'Դիլիջան, Տավուշ',
  3742684 => 'Դիլիջան/Հաղարծին/Թեղուտ, Տավուշ',
  3742686 => 'Դիլիջան, Տավուշ',
  37426881 => 'Դիլիջան/Հաղարծին/Թեղուտ, Տավուշ',
  3742689 => 'Դիլիջան, Տավուշ',
  37426895 => 'Հաղարծին, Տավուշ',
  37426897 => 'Թեղուտ, Տավուշ',
  374269 => 'Վարդենիս, Գեղարքունիք',
  3742810 => 'Գետափ/Սալլի/Եղեգնաձոր, Վայոց Ձոր',
  3742811 => 'Գետափ/Սալլի/Եղեգնաձոր, Վայոց Ձոր',
  3742812 => 'Եղեգնաձոր, Վայոց Ձոր',
  3742813 => 'Եղեգնաձոր/Մալիշկա/Շատին, Վայոց Ձոր',
  3742814 => 'Գետափ/Սալլի/Եղեգնաձոր, Վայոց Ձոր',
  3742815 => 'Եղեգնաձոր, Վայոց Ձոր',
  37428151 => 'Խաչիկ, Վայոց Ձոր',
  3742816 => 'Եղեգնաձոր, Վայոց Ձոր',
  3742817 => 'Գետափ/Սալլի/Եղեգնաձոր, Վայոց Ձոր',
  3742818 => 'Գետափ/Սալլի/Եղեգնաձոր, Վայոց Ձոր',
  37428181 => 'Եղեգնաձոր/Մալիշկա/Շատին, Վայոց Ձոր',
  37428190 => 'Եղեգնաձոր, Վայոց Ձոր',
  37428191 => 'Արփի, Վայոց Ձոր',
  37428192 => 'Եղեգնաձոր, Վայոց Ձոր',
  37428193 => 'Աղավնաձոր, Վայոց Ձոր',
  37428194 => 'Արենի, Վայոց Ձոր',
  37428195 => 'Մալիշկա, Վայոց Ձոր',
  37428196 => 'Եղեգնաձոր, Վայոց Ձոր',
  37428197 => 'Ելփին, Վայոց Ձոր',
  37428198 => 'Ռինդ, Վայոց Ձոր',
  37428199 => 'Շատին, Վայոց Ձոր',
  374282 => 'Վայք, Վայոց Ձոր',
  3742830 => 'Սիսիան, Սյունիք',
  3742832 => 'Սիսիան, Սյունիք',
  3742833 => 'Սիսիան, Սյունիք',
  37428351 => 'Սիսիան, Սյունիք',
  3742836 => 'Սիսիան, Սյունիք',
  3742837 => 'Սիսիան, Սյունիք',
  37428375 => 'Թասիկ, Սյունիք',
  3742838 => 'Սիսիան, Սյունիք',
  3742839 => 'Սիսիան, Սյունիք',
  37428396 => 'Անգեղակոթ, Սյունիք',
  374284 => 'Գորիս, Սյունիք',
  3742840 => 'Գորիս/Վերիշեն, Սյունիք',
  3742841 => 'Գորիս/Վերիշեն, Սյունիք',
  37428427 => 'Վերիշեն, Սյունիք',
  3742847 => 'Գորիս/Վերիշեն, Սյունիք',
  3742848 => 'Գորիս/Վերիշեն, Սյունիք',
  37428491 => 'Հարժիս, Սյունիք',
  37428494 => 'Խնձորեսկ, Սյունիք',
  37428495 => 'Շինուհայր, Սյունիք',
  37428499 => 'Կոռնիձոր, Սյունիք',
  3742850 => 'Դավիթ Բեկ/Քաջարան/Կապան, Սյունիք',
  3742851 => 'Դավիթ Բեկ/Քաջարան/Կապան, Սյունիք',
  3742852 => 'Կապան, Սյունիք',
  3742853 => 'Քաջարան, Սյունիք',
  37428540 => 'Կապան, Սյունիք',
  37428541 => 'Կապան, Սյունիք',
  37428542 => 'Կապան, Սյունիք',
  37428543 => 'Կապան, Սյունիք',
  37428544 => 'Կապան, Սյունիք',
  37428545 => 'Քաջարան, Սյունիք',
  37428546 => 'Քաջարան, Սյունիք',
  37428547 => 'Քաջարան, Սյունիք',
  37428548 => 'Քաջարան, Սյունիք',
  37428549 => 'Քաջարան, Սյունիք',
  3742855 => 'Կապան, Սյունիք',
  3742856 => 'Կապան, Սյունիք',
  3742857 => 'Դավիթ Բեկ/Քաջարան/Կապան, Սյունիք',
  3742858 => 'Դավիթ Բեկ/Քաջարան/Կապան, Սյունիք',
  374285810 => 'Կապան, Սյունիք',
  374285811 => 'Կապան, Սյունիք',
  374285812 => 'Կապան, Սյունիք',
  374285813 => 'Կապան, Սյունիք',
  374285814 => 'Կապան, Սյունիք',
  374285815 => 'Քաջարան, Սյունիք',
  374285816 => 'Քաջարան, Սյունիք',
  374285817 => 'Քաջարան, Սյունիք',
  374285818 => 'Քաջարան, Սյունիք',
  374285819 => 'Քաջարան, Սյունիք',
  3742859 => 'Կապան, Սյունիք',
  3742860 => 'Մեղրի/Ագարակ, Սյունիք',
  3742861 => 'Մեղրի/Ագարակ, Սյունիք',
  3742862 => 'Ագարակ, Սյունիք',
  3742863 => 'Մեղրի, Սյունիք',
  3742864 => 'Մեղրի, Սյունիք',
  3742865 => 'Ագարակ/Շվանիձոր, Սյունիք',
  3742866 => 'Մեղրի, Սյունիք',
  3742867 => 'Մեղրի/Ագարակ, Սյունիք',
  3742868 => 'Մեղրի/Ագարակ, Սյունիք',
  374286810 => 'Մեղրի, Սյունիք',
  374286811 => 'Մեղրի, Սյունիք',
  374286812 => 'Մեղրի, Սյունիք',
  374286813 => 'Մեղրի, Սյունիք',
  374286814 => 'Մեղրի, Սյունիք',
  374286815 => 'Ագարակ/Մեղրի, Սյունիք',
  374286816 => 'Ագարակ/Մեղրի, Սյունիք',
  374286817 => 'Ագարակ/Մեղրի, Սյունիք',
  374286818 => 'Ագարակ/Մեղրի, Սյունիք',
  374286819 => 'Ագարակ/Մեղրի, Սյունիք',
  3742869 => 'Մեղրի, Սյունիք',
  37428695 => 'Շվանիձոր, Սյունիք',
  374287 => 'Ջերմուկ, Վայոց Ձոր',
  3742873 => 'Ջերմուկ/Գնդեվազ, Վայոց Ձոր',
  37428781 => 'Ջերմուկ/Գնդեվազ, Վայոց Ձոր',
  37428794 => 'Գնդեվազ, Վայոց Ձոր',
  374312 => 'Գյումրի, Շիրակ',
  3743120 => 'Գյումրի/Ախուրյան, Շիրակ',
  3743121 => 'Գյումրի/Ախուրյան, Շիրակ',
  3743127 => 'Ախուրյան, Շիրակ',
  37431280 => 'Ախուրյան, Շիրակ',
  37431281 => 'Ախուրյան, Շիրակ',
  37431282 => 'Ախուրյան, Շիրակ',
  37431283 => 'Ախուրյան, Շիրակ',
  37431284 => 'Ախուրյան, Շիրակ',
  374312859 => 'Ախուրյան, Շիրակ',
  37431286 => 'Գյումրի/Ախուրյան, Շիրակ',
  37431287 => 'Գյումրի/Ախուրյան, Շիրակ',
  37431288 => 'Գյումրի/Ախուրյան, Շիրակ',
  37431289 => 'Գյումրի/Ախուրյան, Շիրակ',
  374322 => 'Վանաձոր, Լոռի',
  3743220 => 'Վանաձոր/Գուգարք, Լոռի',
  3743221 => 'Վանաձոր/Գուգարք, Լոռի',
  3743228 => 'Վանաձոր/Գուգարք, Լոռի',
  37432293 => 'Փամբակ, Լոռի',
  37432294 => 'Լեռնապատ, Լոռի',
  37432295 => 'Եղեգնուտ, Լոռի',
  37432296 => 'Մարգահովիտ, Լոռի',
  37432297 => 'Ձորագետ, Լոռի',
  37432298 => 'Լերմոնտովո, Լոռի',
  37432299 => 'Վահագնի, Լոռի',
  374470 => 'Լեռնային Ղարաբաղ',
  374471 => 'Ստեփանակերտ',
  374472 => 'Լեռնային Ղարաբաղ',
  374473 => 'Լեռնային Ղարաբաղ',
  374474 => 'Մարտակերտ',
  374475 => 'Հադրութ',
  374476 => 'Ասկերան',
  374477 => 'Շուշի',
  37447732 => 'Բերձոր/Քաշաթաղ',
  374478 => 'Մարտունի',
  374479 => 'Ստեփանակերտ',
);
