<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    //index
    'people_not_found' => 'Contactpersoon niet gevonden',
    'people_list_number_kids' => ':count kind|:count kinderen',
    'people_list_last_updated' => 'Laatst bekeken:',
    'people_list_number_reminders' => ':count herinnering|:count herinneringen',
    'people_list_blank_title' => 'Je hebt nog niemand in je account',
    'people_list_blank_cta' => 'Voeg iemand toe',
    'people_list_sort' => 'Sorteer',
    'people_list_stats' => ':count contact|:count contacten',
    'people_list_firstnameAZ' => 'Sorteer op voornaam A → Z',
    'people_list_firstnameZA' => 'Sorteer op voornaam Z → A',
    'people_list_lastnameAZ' => 'Sorteer op achternaam A → Z',
    'people_list_lastnameZA' => 'Sorteer op achternaam Z → A',
    'people_list_lastactivitydateNewtoOld' => 'Sorteer activiteit op datum, nieuw naar oud',
    'people_list_lastactivitydateOldtoNew' => 'Sorteren op laatste activiteit datum, oudste naar nieuwste',
    'people_list_filter_tag' => 'Tonen alle contactpersonen gelabeld met',
    'people_list_clear_filter' => 'Filter wissen',
    'people_list_contacts_per_tags' => ':count contact|:count contacten',
    'people_list_show_dead' => 'Toon overleden personen (:count)',
    'people_list_hide_dead' => 'Verberg overleden personen (:count)',
    'people_search' => 'Zoek in je contacten…',
    'people_search_no_results' => 'Geen resultaten gevonden',
    'people_search_next' => 'Volgende',
    'people_search_prev' => 'Vorige',
    'people_search_rows_per_page' => 'Rijen per pagina',
    'people_search_of' => 'van',
    'people_search_page' => 'Pagina',
    'people_search_all' => 'Iedereen',
    'people_add_new' => 'Voeg nieuw persoon toe',
    'people_list_account_usage' => 'Je huidige gebruik: :current/:limit contacten',
    'people_list_account_upgrade_title' => 'Upgrade je account om alle functies te kunnen gebruiken.',
    'people_list_account_upgrade_cta' => 'Nu upgraden',
    'people_list_untagged' => 'Bekijken contacten zonder labels',
    'people_list_filter_untag' => 'All contacten zonder labels',
    'archived_contact_readonly' => 'Gearchiveerd contactpersoon kan niet worden bewerkt, verwijder deze eerst.',

    // people add
    'people_add_title' => 'Voeg een nieuwe persoon toe',
    'people_add_missing' => 'Geen persoon gevonden – voeg nu een nieuwe toe',
    'people_add_firstname' => 'Voornaam',
    'people_add_middlename' => 'Tussenvoegsel (optioneel)',
    'people_add_lastname' => 'Achternaam (optioneel)',
    'people_add_email' => 'E-mailadres (optioneel)',
    'people_add_nickname' => 'Alias (optioneel)',
    'people_add_cta' => 'Toevoegen',
    'people_save_and_add_another_cta' => 'Opslaan en nog iemand toevoegen',
    'people_add_success' => ':name is succesvol toegevoegd',
    'people_add_gender' => 'Geslacht',
    'people_delete_success' => 'De contactpersoon is verwijderd',
    'people_delete_message' => 'Contact verwijderen',
    'people_delete_confirmation' => 'Weet je zeker dat je :name\'s contactgegevens wilt verwijderen? Verwijderen is onmiddellijk en permanent.',
    'people_add_birthday_reminder' => 'Feliciteer :name met zijn/haar verjaardag',
    'people_add_birthday_reminder_deceased' => 'Op deze datum zou :name zijn verjaardag hebben gevierd',
    'people_add_import' => 'Wil je <a href=":url">contacten importeren</a>?',
    'people_edit_email_error' => 'Er is al een contactpersoon in jouw account met dit e-mailadres. Kies alsjeblieft een ander.',
    'people_export' => 'Exporteer als vCard',
    'people_add_reminder_for_birthday' => 'Maak een jaarlijkse verjaardag herinnering',

    // show
    'section_contact_information' => 'Contactinformatie',
    'section_personal_activities' => 'Activiteiten',
    'section_personal_reminders' => 'Herinneringen',
    'section_personal_tasks' => 'Taken',
    'section_personal_gifts' => 'Cadeaus',
    'section_personal_notes' => 'Notities',

    // archived contacts
    'list_link_to_active_contacts' => 'Je bekijkt gearchiveerde contacten. Bekijk in plaats daarvan de <a href=":url">lijst van actieve contacten</a>.',
    'list_link_to_archived_contacts' => 'Lijst van gearchiveerde contacten',

    // Header
    'me' => 'Dit ben jij',
    'edit_contact_information' => 'Bewerk contactinformatie',
    'contact_archive' => 'Archiveer contact',
    'contact_unarchive' => 'Dearchiveer contact',
    'contact_archive_help' => 'Gearchiveerde contacten worden niet getoond in de lijst met contactpersonen, maar worden nog steeds weergegeven in zoekresultaten.',
    'call_button' => 'Telefoongesprek registreren',
    'set_favorite' => 'Favoriete contacten worden bovenaan de lijst met contactpersonen geplaatst',

    // Stay in touch
    'stay_in_touch' => 'Blijf in contact',
    'stay_in_touch_frequency' => 'Blijf elke dag in contact | Blijf elke {count} dagen in contact',
    'stay_in_touch_next_date' => 'Volgende keer: {date}',
    'stay_in_touch_invalid' => 'De frequentie moet groter zijn dan 0.',
    'stay_in_touch_premium' => 'Je moet je account upgraden om gebruik te maken van deze functie',
    'stay_in_touch_modal_title' => 'Blijf in contact',
    'stay_in_touch_modal_desc' => 'We kunnen je herinneren via e-mail om regelmatig in contact te blijven met {firstname}.',
    'stay_in_touch_modal_label' => 'Stuur me iedere… {count} dag|Stuur me een e-mail iedere… {count} dagen',

    // Calls
    'modal_call_title' => 'Telefoongesprek registreren',
    'modal_call_comment' => 'Waar hebben jullie het over gehad? (optioneel)',
    'modal_call_exact_date' => 'Het telefoongesprek gebeurde op',
    'modal_call_who_called' => 'Wie heeft gebeld?',
    'modal_call_emotion' => 'Wil je opslaan hoe jij je voelde tijdens dit gesprek? (optioneel)',
    'calls_add_success' => 'Het telefoongesprek is opgeslagen.',
    'call_delete_confirmation' => 'Weet je zeker dat je deze oproep wil wissen?',
    'call_delete_success' => 'Deze oproep is succesvol verwijderd',
    'call_title' => 'Telefoongesprekken',
    'call_empty_comment' => 'Geen details',
    'call_blank_title' => 'Hou de telefoongesprekken bij die je met {name} hebt gevoerd',
    'call_blank_desc' => 'Jij hebt {name} gebeld',
    'call_you_called' => 'Jij belde',
    'call_he_called' => '{name} belde',
    'call_emotions' => 'Emoties:',

    // Conversation
    'conversation_blank' => 'Registreer gesprekken die je hebt met :name op sociale media, SMS…',
    'conversation_delete_link' => 'Verwijder het gesprek',
    'conversation_edit_title' => 'Gesprek bewerken',
    'conversation_edit_delete' => 'Weet je zeker dat je dit gesprek wil verwijderen? Het wordt definitief verwijderd.',
    'conversation_add_success' => 'Het gesprek is succesvol toegevoegd.',
    'conversation_edit_success' => 'Het gesprek is succesvol bijgewerkt.',
    'conversation_delete_success' => 'Het gesprek is succesvol verwijderd.',
    'conversation_add_title' => 'Nieuw gesprek registreren',
    'conversation_add_when' => 'Wanneer heb je dit gesprek gehad?',
    'conversation_add_who_wrote' => 'Wie heeft dit bericht verzonden?',
    'conversation_add_how' => 'Hoe heb je dit gesprek gevoerd?',
    'conversation_add_you' => 'Jij',
    'conversation_add_content' => 'Schrijf hier wat er is gezegd',
    'conversation_add_what_was_said' => 'Wat was de gespreksinhoud?',
    'conversation_add_another' => 'Nog een bericht toevoegen',
    'conversation_add_error' => 'Je moet tenminste één bericht toevoegen.',
    'conversation_list_table_messages' => 'Berichten',
    'conversation_list_table_content' => 'Gedeeltelijke inhoud (laatste bericht)',
    'conversation_list_title' => 'Gesprekken',
    'conversation_list_cta' => 'Gesprek toevoegen',

    // age - birthday
    'birthdate_not_set' => 'Geboortedatum is niet ingesteld',
    'age_approximate_in_years' => 'ongeveer :age jaren oud',
    'age_exact_in_years' => ':age jaren oud',
    'age_exact_birthdate' => 'geboren op :date',

    // Last called
    'last_called' => 'Laatst gebeld op: :date',
    'last_talked_to' => 'Laatst gebeld op: {date}',
    'last_called_empty' => 'Laatst gebeld op: onbekend',
    'last_activity_date' => 'Laatste activiteit samen: :date',
    'last_activity_date_empty' => 'Laatste activiteit samen: onbekend',

    // additional information
    'information_edit_success' => 'Het profiel is succesvol bijgewerkt',
    'information_edit_title' => 'Bewerk :name\'s persoonlijke informatie',
    'information_edit_max_size' => 'Maximaal :size Kb.',
    'information_edit_max_size2' => 'Maximaal {size} Kb.',
    'information_edit_firstname' => 'Voornaam',
    'information_edit_lastname' => 'Achternaam (optioneel)',
    'information_edit_description' => 'Beschrijving (optioneel)',
    'information_edit_description_help' => 'Dit wordt gebruikt in de contactenlijst om context toe te voegen, indien nodig.',
    'information_edit_unknown' => 'Ik weet de leeftijd van deze persoon niet',
    'information_edit_probably' => 'Deze persoon is waarschijnlijk…',
    'information_edit_not_year' => 'Ik weet de dag en de maand van de verjaardag van deze persoon, maar niet het jaar…',
    'information_edit_exact' => 'Ik weet precies wanneer deze persoon jarig is…',
    'information_edit_birthdate_label' => 'Geboortedatum',
    'information_no_work_defined' => 'Geen werkgegevens gedefinieerd',
    'information_work_at' => 'bij :company',
    'work_add_cta' => 'Werk informatie bijwerken',
    'work_edit_success' => 'Werkinformatie bijgewerkt',
    'work_edit_title' => 'Update :name\'s baan',
    'work_edit_job' => 'Functietitel (optioneel)',
    'work_edit_company' => 'Bedrijf (optioneel)',
    'work_information' => 'Werk informatie',

    // food preferences
    'food_preferences_add_success' => 'Voedsel voorkeuren zijn opgeslagen',
    'food_preferences_edit_description' => 'Misschien heeft :firstname of iemand in de :familiy\'s familie een allergie. Of houdt niet van een specifieke fles wijn. Vul dat hier in zodat je er bij een volgend diner aan denkt',
    'food_preferences_edit_description_no_last_name' => 'Misschien heeft :firstname een allergie. Of houdt niet van een specifieke fles wijn. Vul dat hier in zodat je er bij een volgend diner aan denkt',
    'food_preferences_edit_title' => 'Voedselvoorkeuren',
    'food_preferences_edit_cta' => 'Voedselvoorkeuren opslaan',
    'food_preferences_title' => 'Voedselvoorkeuren',
    'food_preferences_cta' => 'Voeg voedsel voorkeur toe',

    // reminders
    'reminders_blank_title' => 'Is er iets over :name waar je aan herinnert wilt worden?',
    'reminders_blank_add_activity' => 'Voeg een herinnering toe',
    'reminders_add_title' => 'Waar zou je over :name aan herinnert willen worden?',
    'reminders_add_description' => 'Herinner me om…',
    'reminders_add_next_time' => 'Wanneer is de volgende keer dat je hier aan herinnert wilt worden?',
    'reminders_add_once' => 'Herinner me slechts eenmaal hieraan',
    'reminders_add_recurrent' => 'Herinner me hier aan elke',
    'reminders_add_starting_from' => 'beginnend op bovenstaande datum',
    'reminders_add_cta' => 'Herinnering toevoegen',
    'reminders_edit_update_cta' => 'Update herinnering',
    'reminders_add_error_custom_text' => 'Je moet tekst toevoegen voor deze herinnering',
    'reminders_create_success' => 'De herinnering is met succes toegevoegd',
    'reminders_delete_success' => 'De herinnering is verwijderd',
    'reminders_update_success' => 'De herinnering is succesvol bijgewerkt',
    'reminders_add_optional_comment' => 'Opmerking (optioneel)',

    'reminder_frequency_day' => 'dagelijks | elke :number dagen',
    'reminder_frequency_week' => 'wekelijks | elke :number weken',
    'reminder_frequency_month' => 'elke maand | elke :number maanden',
    'reminder_frequency_year' => 'jaarlijks | elke :number jaren',
    'reminder_frequency_one_time' => 'op :date',
    'reminders_delete_confirmation' => 'Weet u zeker dat u deze herinnering wilt verwijderen?',
    'reminders_delete_cta' => 'Verwijderen',
    'reminders_next_expected_date' => 'op',
    'reminders_cta' => 'Voeg een herinnering toe',
    'reminders_description' => 'Wij sturen een e-mail voor elke herinnering hieronder. Herinneringen worden op de ochtend van de dag waarop de gebeurtenis zal plaatsvinden verzonden. Automatisch toegevoegde herinneringen voor verjaardagen kunnen niet worden verwijderd. Wilt u deze herinneringen wijzigen, bewerk dan de geboortedatum van de betreffende contactpersoon.',
    'reminders_one_time' => 'Eenmalig',
    'reminders_type_week' => 'week',
    'reminders_type_month' => 'maand',
    'reminders_type_year' => 'jaar',
    'reminders_birthday' => 'Verjaardag van :name',
    'reminders_free_plan_warning' => 'Je hebt een gratis abonnement. Hiermee worden geen e-mails verzonden. Als je herinneringen per e-mail wilt ontvangen, upgrade dan je account.',

    // relationships
    'relationship_form_add' => 'Voeg een nieuwe relatie toe',
    'relationship_form_edit' => 'Bewerk bestaande relatie',
    'relationship_form_is_with' => 'Deze persoon is…',
    'relationship_form_is_with_name' => ':name is…',
    'relationship_form_add_choice' => 'Wie is de relatie met?',
    'relationship_form_create_contact' => 'Voeg een nieuwe persoon toe',
    'relationship_form_associate_contact' => 'Toevoegen aan bestaand persoon',
    'relationship_form_associate_dropdown' => 'Zoek en selecteer een bestaande contactpersoon met het dropdown menu hieronder',
    'relationship_form_associate_dropdown_placeholder' => 'Zoek en selecteer een bestaande contactpersoon',
    'relationship_form_also_create_contact' => 'Een contact-kaart maken voor deze persoon.',
    'relationship_form_add_description' => 'Hierdoor kan je dit persoon bewerken, net als elk ander contact.',
    'relationship_form_add_no_existing_contact' => 'Je hebt nog geen contacten die een :name gekoppeld kunnen worden.',
    'relationship_delete_confirmation' => 'Weet je zeker dat je deze relatie wilt verwijderen? Dit is permanent.',
    'relationship_unlink_confirmation' => 'Weet je zeker dat je deze relatie wilt verwijderen? Deze persoon wordt niet verwijdert, alleen de relatie tussen de twee personen.',
    'relationship_form_add_success' => 'De relatie is succesvol toegevoegd.',
    'relationship_form_deletion_success' => 'De relatie is verwijdert.',

    // tasks
    'tasks_title' => 'Taken',
    'tasks_blank_title' => 'Je hebt nog geen taken.',
    'tasks_form_title' => 'Titel',
    'tasks_form_description' => 'Beschrijving (optioneel)',
    'tasks_add_task' => 'Voeg taak toe',
    'tasks_delete_success' => 'De taak is succesvol verwijderd',
    'tasks_complete_success' => 'De taak is met succes aangepast',

    // activities
    'activity_title' => 'Activiteiten',
    'activity_type_category_simple_activities' => 'Eenvoudige activiteiten',
    'activity_type_category_sport' => 'Sport',
    'activity_type_category_food' => 'Eten',
    'activity_type_category_cultural_activities' => 'Culturele activiteiten',
    'activity_type_just_hung_out' => 'gewoon een beetje gehangen',
    'activity_type_watched_movie_at_home' => 'thuis een film gekeken',
    'activity_type_talked_at_home' => 'thuis gekletst',
    'activity_type_did_sport_activities_together' => 'samen gesport',
    'activity_type_ate_at_his_place' => 'bij hun gegeten',
    'activity_type_went_bar' => 'naar een bar gegaan',
    'activity_type_ate_at_home' => 'thuis gegeten',
    'activity_type_picnicked' => 'gepicknickt',
    'activity_type_ate_restaurant' => 'naar een restaurant gegaan',
    'activity_type_went_theater' => 'naar het theater gegaan',
    'activity_type_went_concert' => 'naar een concert gegaan',
    'activity_type_went_play' => 'naar een toneelstuk gegaan',
    'activity_type_went_museum' => 'naar het museum gegaan',
    'activities_add_activity' => 'Voeg activiteit toe',
    'activities_add_more_details' => 'Voeg meer details toe',
    'activities_add_emotions' => 'Voeg emoties toe',
    'activities_add_category' => 'Categorie toevoegen',
    'activities_add_participants_cta' => 'Deelnemers toevoegen',
    'activities_item_information' => 'Deze :activity was op :date',
    'activities_add_title' => 'Wat heb je met {name} gedaan?',
    'activities_summary' => 'Beschrijf wat je deed',
    'activities_add_pick_activity' => 'Wil je deze activiteit categoriseren? Het hoeft niet, maar levert je later statistieken op. (optioneel)',
    'activities_add_date_occured' => 'De activiteit vond plaats op…',
    'activities_add_participants' => 'Wie nam, naast {name}, nog meer deel aan deze activiteit? (optioneel)',
    'activities_add_emotions_title' => 'Wil je opslaan hoe je je voelde tijdens deze activiteit? (optioneel)',
    'activities_blank_title' => 'Hou bij wat je samen met {name} gedaan hebt en waarover jullie gesproken hebben',
    'activities_blank_add_activity' => 'Voeg activiteit toe',
    'activities_add_success' => 'De activiteit is met succes toegevoegd',
    'activities_add_error' => 'Fout bij toevoegen van activiteit',
    'activities_update_success' => 'Deze activiteit is succesvol bijgewerkt',
    'activities_delete_success' => 'Deze activiteit is succesvol verwijdert',
    'activities_who_was_involved' => 'Wie was erbij?',
    'activities_activity' => 'Activiteit categorie',
    'activities_view_activities_report' => 'Bekijk activiteiten rapport',
    'activities_profile_title' => 'Activiteiten rapport voor :name',
    'activities_profile_subtitle' => 'Je hebt, tot nu toe, in totaal :total_activities activiteit met :name vastgelegd, waarvan :activities_last_twelve_months in de afgelopen twaalf maanden.|Je hebt, tot nu toe, in totaal :total_activities activiteiten met :name vastgelegd, waarvan :activities_last_twelve_months in de afgelopen twaalf maanden.',
    'activities_profile_year_summary_activity_types' => 'Hier is een overzicht van de soort activiteiten die jullie samen hebben gedaan in :year',
    'activities_profile_year_summary' => 'Dit is wat jullie samen hebben gedaan in :year',
    'activities_profile_number_occurences' => ':value activiteit|:value activiteiten',
    'activities_list_participants' => 'Deelnemers ({total}):',
    'activities_list_emotions' => 'Gevoelde emoties:',
    'activities_list_date' => 'Vond plaats op',
    'activities_list_category' => 'Categorie:',

    // notes
    'notes_create_success' => 'Nieuwe notitie succesvol toegevoegd',
    'notes_update_success' => 'De notitie is succesvol opgeslagen',
    'notes_delete_success' => 'De notitie is succesvol verwijderd',
    'notes_add_cta' => 'Notitie toevoegen',
    'notes_favorite' => 'Toevoegen/verwijderen uit favorieten',
    'notes_delete_title' => 'Notitie verwijderen',
    'notes_delete_confirmation' => 'Weet je zeker dat je deze notitie wil verwijderen? Het wordt definitief verwijderd',

    // gifts
    'gifts_title' => 'Cadeaus',
    'gifts_add_success' => 'Het cadeau is succesvol toegevoegd',
    'gifts_delete_success' => 'Het cadeau is succesvol verwijderd',
    'gifts_delete_confirmation' => 'Weet je zeker dat je dit cadeau wil verwijderen?',
    'gifts_add_gift' => 'Cadeau toevoegen',
    'gifts_link' => 'Link',
    'gifts_for' => 'Voor: {name}',
    'gifts_delete_cta' => 'Verwijderen',
    'gifts_add_title' => 'Cadeaubeheer voor :name',
    'gifts_add_gift_idea' => 'Cadeau idee',
    'gifts_add_gift_already_offered' => 'Cadeau aangeboden',
    'gifts_add_gift_received' => 'Cadeau ontvangen',
    'gifts_add_gift_title' => 'Wat is dit voor een cadeau?',
    'gifts_add_gift_name' => 'Titel cadeau',
    'gifts_add_link' => 'Link naar de webpagina (optioneel)',
    'gifts_add_value' => 'Waarde (optioneel)',
    'gifts_add_comment' => 'Opmerking (optioneel)',
    'gifts_add_recipient' => 'Ontvanger (optioneel)',
    'gifts_add_recipient_field' => 'Ontvanger',
    'gifts_add_photo' => 'Foto (optioneel)',
    'gifts_add_photo_title' => 'Voeg een foto toe aan dit cadeau',
    'gifts_add_someone' => 'Dit cadeau is voor iemand in {name}\'s familie',
    'gifts_delete_title' => 'Een cadeau verwijderen',
    'gifts_ideas' => 'Cadeau-ideeën',
    'gifts_offered' => 'Cadeau aangeboden',
    'gifts_offered_as_an_idea' => 'Als idee markeren',
    'gifts_received' => 'Ontvangen cadeaus',
    'gifts_view_comment' => 'Opmerking bekijken',
    'gifts_mark_offered' => 'Als aangeboden markeren',
    'gifts_update_success' => 'Het cadeau is succesvol bijgewerkt',
    'gifts_add_date' => 'Datum (optioneel)',

    // debts
    'debt_delete_confirmation' => 'Weet je zeker dat je deze schuld wil verwijderen?',
    'debt_delete_success' => 'De schuld is succesvol verwijderd',
    'debt_add_success' => 'De schuld is succesvol toegevoegd',
    'debt_title' => 'Schulden',
    'debt_add_cta' => 'Schuld toevoegen',
    'debt_you_owe' => 'Jij verschuldigd :amount',
    'debt_they_owe' => ':name verschuldigd jou :amount',
    'debt_add_title' => 'Schuldenbeheer',
    'debt_add_you_owe' => 'Je bent :name verschuldigd',
    'debt_add_they_owe' => ':name is jou verschuldigd',
    'debt_add_amount' => 'een totaal van',
    'debt_add_reason' => 'om de volgende reden (optioneel)',
    'debt_add_add_cta' => 'Schuld toevoegen',
    'debt_edit_update_cta' => 'Schuld bijwerken',
    'debt_edit_success' => 'De schuld is succesvol bijgewerkt',
    'debts_blank_title' => 'Beheer schulden die je bent verschuldigd aan :name of :name jou is verschuldigd',

    // tags
    'tag_edit' => 'Label bewerken',
    'tag_add' => 'Labels toevoegen',
    'tag_add_search' => 'Labels toevoegen of zoeken',
    'tag_no_tags' => 'Nog geen labels',

    // Introductions
    'introductions_sidebar_title' => 'Hoe jullie elkaar ontmoet hebben',
    'introductions_blank_cta' => 'Geef aan hoe je :name hebt ontmoet',
    'introductions_title_edit' => 'Hoe heb je :name leren kennen?',
    'introductions_additional_info' => 'Leg uit hoe en waar jullie elkaar hebben ontmoet',
    'introductions_edit_met_through' => 'Heeft iemand je voorgesteld?',
    'introductions_no_met_through' => 'Niemand',
    'introductions_first_met_date' => 'Datum eerste ontmoeting',
    'introductions_no_first_met_date' => 'Ik weet meer wanneer wij elkaar voor het eerst ontmoet hebben',
    'introductions_first_met_date_known' => 'Dit is de datum dat wij elkaar ontmoet hebben',
    'introductions_add_reminder' => 'Voeg een herinnering toe voor het jubileum van deze ontmoeting',
    'introductions_update_success' => 'Eerste ontmoeting is succesvol bijgewerkt',
    'introductions_met_through' => 'Voorgesteld door <a href=":url">:name</a>',
    'introductions_met_date' => 'Ontmoet op :date',
    'introductions_reminder_title' => 'Jubileum van jullie eerste ontmoeting',

    // Deceased
    'deceased_reminder_title' => 'Sterfdag van :name',
    'deceased_mark_person_deceased' => 'Markeer dit als overleden',
    'deceased_know_date' => 'Ik weet de datum waarop deze persoon is gestorven',
    'deceased_add_reminder' => 'Stel een herinnering in voor de sterfdag',
    'deceased_label' => 'Overleden',
    'deceased_date_label' => 'Datum van overlijden',
    'deceased_label_with_date' => 'Overleden op :date',
    'deceased_age' => 'Leeftijd bij overlijden',

    // Contact information
    'contact_info_title' => 'Contactinformatie',
    'contact_info_form_content' => 'Inhoud',
    'contact_info_form_contact_type' => 'Contactsoort',
    'contact_info_form_personalize' => 'Personaliseer',
    'contact_info_address' => 'Woont in',

    // Addresses
    'contact_address_title' => 'Adressen',
    'contact_address_form_name' => 'Label (optioneel)',
    'contact_address_form_street' => 'Straat (optioneel)',
    'contact_address_form_city' => 'Stad (optioneel)',
    'contact_address_form_province' => 'Provincie (optioneel)',
    'contact_address_form_postal_code' => 'Postcode (optioneel)',
    'contact_address_form_country' => 'Land (optioneel)',
    'contact_address_form_latitude' => 'Breedtegraad (alleen cijfers) (optioneel)',
    'contact_address_form_longitude' => 'Lengtegraad (alleen cijfers) (optioneel)',

    // Pets
    'pets_kind' => 'Soort huisdier',
    'pets_name' => 'Naam (optioneel)',
    'pets_create_success' => 'Het huisdier is succesvol toegevoegd',
    'pets_update_success' => 'Het huisdier is succesvol bijgewerkt',
    'pets_delete_success' => 'Het huisdier is succesvol verwijderd',
    'pets_title' => 'Huisdieren',
    'pets_reptile' => 'Reptiel',
    'pets_bird' => 'Vogel',
    'pets_cat' => 'Kat',
    'pets_dog' => 'Hond',
    'pets_fish' => 'Vis',
    'pets_hamster' => 'Hamster',
    'pets_horse' => 'Paard',
    'pets_rabbit' => 'Konijn',
    'pets_rat' => 'Rat',
    'pets_small_animal' => 'Klein dier',
    'pets_other' => 'Andere',

    // life events
    'life_event_list_tab_life_events' => 'Levensgebeurtenissen',
    'life_event_list_tab_other' => 'Notities, herinneringen, …',
    'life_event_list_title' => 'Levensgebeurtenissen',
    'life_event_blank' => 'Leg vast wat er in het leven van {name} gebeurd voor toekomstige referentie.',
    'life_event_list_cta' => 'Levensgebeurtenis toevoegen',
    'life_event_create_category' => 'Alle categorieën',
    'life_event_create_life_event' => 'Levensgebeurtenis toevoegen',
    'life_event_create_default_title' => 'Titel (optioneel)',
    'life_event_create_default_story' => 'Verhaal (optioneel)',
    'life_event_create_date' => 'Je hoeft geen maand of dag aan te geven - alleen het jaar is verplicht.',
    'life_event_create_default_description' => 'Voeg toe wat je hierover weet',
    'life_event_create_add_yearly_reminder' => 'Voeg een jaarlijkse herinnering toe voor deze gebeurtenis',
    'life_event_create_success' => 'De levensgebeurtenis is toegevoegd',
    'life_event_delete_title' => 'Verwijder levensgebeurtenis',
    'life_event_delete_description' => 'Weet je zeker dat je deze levensgebeurtenis wil verwijderen? Dit is permanent.',
    'life_event_delete_success' => 'De levensgebeurtenis is verwijderd',
    'life_event_date_it_happened' => 'Datum van de gebeurtenis',
    'life_event_category_work_education' => 'Werk & onderwijs',
    'life_event_category_family_relationships' => 'Familie & relaties',
    'life_event_category_home_living' => 'Thuis & leven',
    'life_event_category_health_wellness' => 'Gezondheid & welzijn',
    'life_event_category_travel_experiences' => 'Reizen & ervaringen',
    'life_event_sentence_new_job' => 'Nieuwe baan gekregen',
    'life_event_sentence_retirement' => 'Met pensioen gegaan',
    'life_event_sentence_new_school' => 'Begonnen met school',
    'life_event_sentence_study_abroad' => 'Gestudeerd in het buitenland',
    'life_event_sentence_volunteer_work' => 'Begonnen met vrijwilligerswerk',
    'life_event_sentence_published_book_or_paper' => 'Werd gepubliceerd',
    'life_event_sentence_military_service' => 'Begonnen in militaire dienst',
    'life_event_sentence_new_relationship' => 'Begon een relatie',
    'life_event_sentence_engagement' => 'Verloofd',
    'life_event_sentence_marriage' => 'Getrouwd',
    'life_event_sentence_anniversary' => 'Jubileum',
    'life_event_sentence_expecting_a_baby' => 'Verwacht een baby',
    'life_event_sentence_new_child' => 'Kreeg een kind',
    'life_event_sentence_new_family_member' => 'Familielid toegevoegd',
    'life_event_sentence_new_pet' => 'Kreeg een huisdier',
    'life_event_sentence_end_of_relationship' => 'Relatie beëindigd',
    'life_event_sentence_loss_of_a_loved_one' => 'Een geliefde verloren',
    'life_event_sentence_moved' => 'Verhuisd',
    'life_event_sentence_bought_a_home' => 'Huis gekocht',
    'life_event_sentence_home_improvement' => 'Verbouwd',
    'life_event_sentence_holidays' => 'Op vakantie geweest',
    'life_event_sentence_new_vehicle' => 'Kreeg een nieuw voertuig',
    'life_event_sentence_new_roommate' => 'Kreeg een huisgenoot',
    'life_event_sentence_overcame_an_illness' => 'Overwon een ziekte',
    'life_event_sentence_quit_a_habit' => 'Stopte met slechte gewoonte',
    'life_event_sentence_new_eating_habits' => 'Begon met nieuw voedingspatroon',
    'life_event_sentence_weight_loss' => 'Afgevallen',
    'life_event_sentence_wear_glass_or_contact' => 'Begon met dragen van bril of contactlenzen',
    'life_event_sentence_broken_bone' => 'Bot gebroken',
    'life_event_sentence_removed_braces' => 'Beugel verwijderd',
    'life_event_sentence_surgery' => 'Operatie ondergaan',
    'life_event_sentence_dentist' => 'Ging naar de tandarts',
    'life_event_sentence_new_sport' => 'Begon met een sport',
    'life_event_sentence_new_hobby' => 'Begon met een hobby',
    'life_event_sentence_new_instrument' => 'Nieuw instrument geleerd',
    'life_event_sentence_new_language' => 'Nieuwe taal geleerd',
    'life_event_sentence_tattoo_or_piercing' => 'Kreeg een tatoeage of piercing',
    'life_event_sentence_new_license' => 'Kreeg een diploma',
    'life_event_sentence_travel' => 'Heeft gereisd',
    'life_event_sentence_achievement_or_award' => 'Ontving een prestatie of prijs',
    'life_event_sentence_changed_beliefs' => 'Van overtuiging veranderd',
    'life_event_sentence_first_word' => 'Voor het eerst gesproken',
    'life_event_sentence_first_kiss' => 'De eerste kus',

    // documents
    'document_list_title' => 'Documenten',
    'document_list_cta' => 'Document uploaden',
    'document_list_blank_desc' => 'Hier kan je documenten opslaan gerelateerd aan deze persoon.',
    'document_upload_zone_cta' => 'Bestand uploaden',
    'document_upload_zone_progress' => 'Document uploaden…',
    'document_upload_zone_error' => 'Er is een fout opgetreden tijdens uploaden van het document, probeer het a.u.b. opnieuw.',

    // Photos
    'photo_title' => 'Foto\'s',
    'photo_list_title' => 'Gerelateerde foto\'s',
    'photo_list_cta' => 'Foto uploaden',
    'photo_list_blank_desc' => 'Je kan afbeeldingen van dit contact opslaan. Upload er nu eentje!',
    'photo_upload_zone_cta' => 'Upload een foto',
    'photo_current_profile_pic' => 'Huidige profielfoto',
    'photo_make_profile_pic' => 'Stel in als profielfoto',
    'photo_delete' => 'Foto verwijderen',
    'photo_next' => 'Volgende foto ❯',
    'photo_previous' => '❮ Vorige foto',

    // Avatars
    'avatar_change_title' => 'Wijzig je profielfoto',
    'avatar_question' => 'Welke avatar wil je gebruiken?',
    'avatar_default_avatar' => 'De standaard-avatar',
    'avatar_adorable_avatar' => 'De Schattige avatar',
    'avatar_gravatar' => 'The Gravatar dat geassocieerd is met dit contact. <a href="https://gravatar.com/">Gravatar</a> is een wereldwijd systeem dat gebruikers hun emailadres laat associëren met hun foto\'s.',
    'avatar_current' => 'Huidige avatar houden',
    'avatar_photo' => 'Van een foto die je upload',
    'avatar_crop_new_avatar_photo' => 'Snij nieuwe avatar foto bij',

    // emotions
    'emotion_this_made_me_feel' => 'Je voelde je…',

    // logs
    'auditlogs_link' => 'Geschiedenis',
    'auditlogs_title' => 'Alles wat er met :name is gebeurd',
    'auditlogs_breadcrumb' => 'Geschiedenis',
    'auditlogs_author' => 'Door :name op :date',

    // contact field label
    'contact_field_label_home' => 'Home',
    'contact_field_label_work' => 'Werk',
    'contact_field_label_cell' => 'Mobiel',
    'contact_field_label_fax' => 'Fax',
    'contact_field_label_pager' => 'Pieper',
    'contact_field_label_main' => 'Algemeen',
    'contact_field_label_other' => 'Ander',
    'contact_field_label_personal' => 'Persoonlijk',
];
