<?php
namespace Aws\Acm\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Certificate Manager** service.
 */
class AcmException extends AwsException {}
