<?php
namespace Aws\MediaPackageV2\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Elemental MediaPackage v2** service.
 */
class MediaPackageV2Exception extends AwsException {}
