<?php
namespace Aws\ServerlessApplicationRepository\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWSServerlessApplicationRepository** service.
 */
class ServerlessApplicationRepositoryException extends AwsException {}
