<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  2294 => 'Celtiis',
  22942 => 'MTN',
  22946 => 'MTN',
  2295 => 'MTN',
  22955 => 'Moov',
  22956 => 'Moov',
  22960 => 'Moov',
  22961 => 'MTN',
  22962 => 'MTN',
  22963 => 'Moov',
  22964 => 'Moov',
  22965 => 'Moov',
  22966 => 'MTN',
  22967 => 'MTN',
  22968 => 'Moov',
  22969 => 'MTN',
  22990 => 'MTN',
  22991 => 'MTN',
  22993 => 'BLK',
  22994 => 'Moov',
  22995 => 'Moov',
  22996 => 'MTN',
  22997 => 'MTN',
  22998 => 'Moov',
  22999 => 'Moov',
);
