<?php
namespace Aws\WorkSpacesWeb\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon WorkSpaces Web** service.
 */
class WorkSpacesWebException extends AwsException {}
