<?php
namespace Aws\S3Control\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS S3 Control** service.
 */
class S3ControlException extends AwsException {}
