<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    //index
    'people_not_found' => 'Contatto non trovato',
    'people_list_number_kids' => ':count bambino|:count bambini',
    'people_list_last_updated' => 'Consultato l\'ultima volta:',
    'people_list_number_reminders' => ':count promemoria|:count promemoria',
    'people_list_blank_title' => 'Non ci sono contatti nel tuo account',
    'people_list_blank_cta' => 'Aggiungi qualcuno',
    'people_list_sort' => 'Ordina',
    'people_list_stats' => ':count contatto|:count contatti',
    'people_list_firstnameAZ' => 'Ordina per nome A → Z',
    'people_list_firstnameZA' => 'Ordina per nome Z → A',
    'people_list_lastnameAZ' => 'Ordina per cognome A → Z',
    'people_list_lastnameZA' => 'Ordina per cognome Z → A',
    'people_list_lastactivitydateNewtoOld' => 'Ordina per data di ultima attività, da più recente a meno recente',
    'people_list_lastactivitydateOldtoNew' => 'Ordina per data di ultima attività, dalla meno recente alla più recente',
    'people_list_filter_tag' => 'Tutti i contatti etichettati con',
    'people_list_clear_filter' => 'Rimuovi filtro',
    'people_list_contacts_per_tags' => ':count contatto|:count contatti',
    'people_list_show_dead' => 'Mostra persone decedute (:count)',
    'people_list_hide_dead' => 'Nascondi persone decedute (:count)',
    'people_search' => 'Cerca i tuoi contatti…',
    'people_search_no_results' => 'Nessun risultato trovato',
    'people_search_next' => 'Successivo',
    'people_search_prev' => 'Precedente',
    'people_search_rows_per_page' => 'Righe per pagina',
    'people_search_of' => 'di',
    'people_search_page' => 'Pagina',
    'people_search_all' => 'Tutto',
    'people_add_new' => 'Aggiungi una persona',
    'people_list_account_usage' => 'Utilizzo account: :current/:limit contatti',
    'people_list_account_upgrade_title' => 'Effettua l\'upgrade del tuo account per poter usufruire delle sue piene funzionalitá.',
    'people_list_account_upgrade_cta' => 'Effettua l\'upgrade ora',
    'people_list_untagged' => 'Mostra contatti senza etichette',
    'people_list_filter_untag' => 'Tutti i contatti senza etichette',
    'archived_contact_readonly' => 'Il contatto archiviato non è modificabile, sei pregato di de archiviarlo prima.',

    // people add
    'people_add_title' => 'Aggiungi una nuova persona',
    'people_add_missing' => 'Nessuna persona trovata, aggiungine ora una nuova',
    'people_add_firstname' => 'Nome',
    'people_add_middlename' => 'Secondo nome (facoltativo)',
    'people_add_lastname' => 'Cognome (facoltativo)',
    'people_add_email' => 'Email (facoltativa)',
    'people_add_nickname' => 'Nickname (facoltativo)',
    'people_add_cta' => 'Aggiungi questa persona',
    'people_save_and_add_another_cta' => 'Salva e aggiungi un\'altra persona',
    'people_add_success' => 'Contatto creato con successo',
    'people_add_gender' => 'Sesso',
    'people_delete_success' => 'Il contatto è stato rimosso',
    'people_delete_message' => 'Elimina contatto',
    'people_delete_confirmation' => 'Sei sicuro di voler eliminare il contatto di :name? L\'eliminazione è immediata e permanente.',
    'people_add_birthday_reminder' => 'Fai gli auguri di compleanno a :name',
    'people_add_birthday_reminder_deceased' => 'In questa data, :name avrebbe celebrato il suo compleanno',
    'people_add_import' => 'Vuoi <a href=":url">importare i tuoi contatti</a>?',
    'people_edit_email_error' => 'Esiste già un contatto nel tuo account con questo indirizzo email. Scegline un altro, per favore.',
    'people_export' => 'Esporta in formato vCard',
    'people_add_reminder_for_birthday' => 'Crea un promemoria annuale del compleanno',

    // show
    'section_contact_information' => 'Informazioni sul contatto',
    'section_personal_activities' => 'Attività',
    'section_personal_reminders' => 'Promemoria',
    'section_personal_tasks' => 'Cose da fare',
    'section_personal_gifts' => 'Regali',
    'section_personal_notes' => 'Note',

    // archived contacts
    'list_link_to_active_contacts' => 'Stai visualizzando i contatti archiviati. Mostra i <a href=":url">contatti attivi</a> invece.',
    'list_link_to_archived_contacts' => 'Lista di contatti archiviati',

    // Header
    'me' => 'Questo sei tu',
    'edit_contact_information' => 'Modifica informazioni del contatto',
    'contact_archive' => 'Archivia contatto',
    'contact_unarchive' => 'Ripristina contatto',
    'contact_archive_help' => 'I contatti archiviati non sono mostrati sull\'elenco di contatti, ma appaiono comunque nei risultati della ricerca.',
    'call_button' => 'Aggiungi chiamata',
    'set_favorite' => 'I contatti preferiti vengono mostrati per primi nella lista',

    // Stay in touch
    'stay_in_touch' => 'Rimani in contatto',
    'stay_in_touch_frequency' => 'Rimani in contatto ogni giorno|Rimani in contatto ogni {count} giorni',
    'stay_in_touch_next_date' => 'Prossima scadenza: {date}',
    'stay_in_touch_invalid' => 'La frequenza dev\'essere un numero maggiore di 0.',
    'stay_in_touch_premium' => 'Devi fare l\'upgrade al tuo account per usare questa funzione',
    'stay_in_touch_modal_title' => 'Rimani in contatto',
    'stay_in_touch_modal_desc' => 'Possiamo ricordarti di rimanere in contatto con {firstname} tramite email a intervalli regolari.',
    'stay_in_touch_modal_label' => 'Inviami un\'email ogni… {count} giorno| Inviami un\'email ogni… {count} giorni',

    // Calls
    'modal_call_title' => 'Aggiungi chiamata',
    'modal_call_comment' => 'Di cosa avete parlato? (facoltativo)',
    'modal_call_exact_date' => 'La chiamata é stata fatta il',
    'modal_call_who_called' => 'Chi ha chiamato?',
    'modal_call_emotion' => 'Vuoi registrare come ti sei sentito durante questa chiamata? (facoltativo)',
    'calls_add_success' => 'La chiamata é stata salvata.',
    'call_delete_confirmation' => 'Rimuovere questa chiamata?',
    'call_delete_success' => 'La chiamata é stata rimossa',
    'call_title' => 'Chiamate',
    'call_empty_comment' => 'Nessuna informazione',
    'call_blank_title' => 'Tieni traccia delle chiamate effettuate con {name}',
    'call_blank_desc' => 'Hai chiamato {name}',
    'call_you_called' => 'Hai chiamato',
    'call_he_called' => '{name} ti ha chiamato',
    'call_emotions' => 'Emozioni:',

    // Conversation
    'conversation_blank' => 'Registra le conversazioni che hai con :name sui social, SMS…',
    'conversation_delete_link' => 'Elimina la conversazione',
    'conversation_edit_title' => 'Modifica conversazione',
    'conversation_edit_delete' => 'Sei sicuro di voler eliminare questa conversazione? Non si può annullare.',
    'conversation_add_success' => 'Conversazione aggiunta con successo.',
    'conversation_edit_success' => 'Conversazione aggiornata con successo.',
    'conversation_delete_success' => 'Conversazione eliminata con successo.',
    'conversation_add_title' => 'Registra una nuova conversazione',
    'conversation_add_when' => 'Quando hai avuto questa conversazione?',
    'conversation_add_who_wrote' => 'Chi ha inviato questo messaggio?',
    'conversation_add_how' => 'Come avete comunicato?',
    'conversation_add_you' => 'Tu',
    'conversation_add_content' => 'Scrivi cos\'è stato detto',
    'conversation_add_what_was_said' => 'Che cosa hai detto?',
    'conversation_add_another' => 'Aggiungi un altro messaggio',
    'conversation_add_error' => 'Devi aggiungere almeno un messaggio.',
    'conversation_list_table_messages' => 'Messaggi',
    'conversation_list_table_content' => 'Contenuto parziale (ultimo messaggio)',
    'conversation_list_title' => 'Conversazioni',
    'conversation_list_cta' => 'Registra conversazione',

    // age - birthday
    'birthdate_not_set' => 'Il compleanno non è impostato',
    'age_approximate_in_years' => 'circa :age anni',
    'age_exact_in_years' => ':age anni',
    'age_exact_birthdate' => 'nato :date',

    // Last called
    'last_called' => 'Ultima chiamata: :date',
    'last_talked_to' => 'Ultima chiamata: {date}',
    'last_called_empty' => 'Ultima chiamata: sconosciuta',
    'last_activity_date' => 'Ultima attività insieme: :date',
    'last_activity_date_empty' => 'Ultima attività insieme: sconosciuta',

    // additional information
    'information_edit_success' => 'Il profilo è stato aggiornato',
    'information_edit_title' => 'Modifica le informazioni personali di :name',
    'information_edit_max_size' => 'Massimo :size Kb.',
    'information_edit_max_size2' => 'Massimo {size} Kb.',
    'information_edit_firstname' => 'Nome',
    'information_edit_lastname' => 'Cognome (facoltativo)',
    'information_edit_description' => 'Descrizione (facoltativa)',
    'information_edit_description_help' => 'Usato nella lista dei contatti per aggiungere contesto, se necessario.',
    'information_edit_unknown' => 'Non conosco l\'età di questa persona',
    'information_edit_probably' => 'Questa persona è probabilmente…',
    'information_edit_not_year' => 'Conosco il giorno e il mese del compleanno di questa persona, ma non l\'anno…',
    'information_edit_exact' => 'Conosco il compleanno esatto di questa persona…',
    'information_edit_birthdate_label' => 'Compleanno',
    'information_no_work_defined' => 'Nessuna informazione professionale',
    'information_work_at' => 'alla :company',
    'work_add_cta' => 'Aggiorna informazioni professionali',
    'work_edit_success' => 'Informazioni lavorative aggiornate',
    'work_edit_title' => 'Aggiorna informazioni professionali di :name',
    'work_edit_job' => 'Titolo (facoltativo)',
    'work_edit_company' => 'Azienda (facoltativa)',
    'work_information' => 'Informazioni professionali',

    // food preferences
    'food_preferences_add_success' => 'Le preferenze alimentari sono state salvate',
    'food_preferences_edit_description' => 'Magari :firstname o qualcuno nella famiglia :family ha un\'allergia. O non gli piace un certo vino. Indica queste cose qui così da ricordarle la prossima volta che li inviti a cena',
    'food_preferences_edit_description_no_last_name' => 'Magari :firstname ha un\'allergia. O non gli piace un certo vino. Indica queste cose qui così da ricordarle la prossima volta che li inviti a cena',
    'food_preferences_edit_title' => 'Indica le preferenze alimentari',
    'food_preferences_edit_cta' => 'Salva preferenze alimentari',
    'food_preferences_title' => 'Preferenze alimentari',
    'food_preferences_cta' => 'Aggiunti preferenze alimentari',

    // reminders
    'reminders_blank_title' => 'C\'è qualcosa di cui ti vuoi ricordare riguardo a :name?',
    'reminders_blank_add_activity' => 'Aggiungi un promemoria',
    'reminders_add_title' => 'Cosa vorresti ricordare a proposito di :name?',
    'reminders_add_description' => 'Per favore ricordami di…',
    'reminders_add_next_time' => 'Quando vorresti ti fosse ricordato?',
    'reminders_add_once' => 'Ricordamelo una sola volta',
    'reminders_add_recurrent' => 'Ricordamelo ogni',
    'reminders_add_starting_from' => 'a partire dalla data specificata qui sopra',
    'reminders_add_cta' => 'Aggiungi promemoria',
    'reminders_edit_update_cta' => 'Aggiorna promemoria',
    'reminders_add_error_custom_text' => 'Devi scrivere qualcosa per questo promemoria',
    'reminders_create_success' => 'Il promemoria è stato creato',
    'reminders_delete_success' => 'Il promemoria è stato rimosso',
    'reminders_update_success' => 'Il promemoria è stato aggiornato',
    'reminders_add_optional_comment' => 'Informazioni aggiuntive',

    'reminder_frequency_day' => 'ogni giorno|ogni :number giorni',
    'reminder_frequency_week' => 'ogni settimana|ogni :number settimane',
    'reminder_frequency_month' => 'ogni mese|ogni :number mesi',
    'reminder_frequency_year' => 'ogni anno|ogni :number anni',
    'reminder_frequency_one_time' => 'il :date',
    'reminders_delete_confirmation' => 'Rimuovere questo promemoria?',
    'reminders_delete_cta' => 'Rimuovi',
    'reminders_next_expected_date' => 'il',
    'reminders_cta' => 'Aggiungi un promemoria',
    'reminders_description' => 'Invieremo un\'email per ognuno dei seguenti promemoria. I promemoria sono inviati ogni mattina in cui si verificherà l\'evento. I promemoria aggiunti automaticamente per i compleanno non sono eliminabili. Se vuoi modificare queste date, modifica il compleanno dei contatti.',
    'reminders_one_time' => 'Una volta',
    'reminders_type_week' => 'settimana',
    'reminders_type_month' => 'mese',
    'reminders_type_year' => 'anno',
    'reminders_birthday' => 'Compleanno di :name',
    'reminders_free_plan_warning' => 'Nella versione gratuita di Monica non vengono inviate email. Per ricevere promemoria via email, effettua l\'upgrade.',

    // relationships
    'relationship_form_add' => 'Aggiungi relazione',
    'relationship_form_edit' => 'Modifica una relazione esistente',
    'relationship_form_is_with' => 'Questa persona è…',
    'relationship_form_is_with_name' => ':name è…',
    'relationship_form_add_choice' => 'Con chi è la relazione?',
    'relationship_form_create_contact' => 'Aggiungi persona',
    'relationship_form_associate_contact' => 'Un contatto esistente',
    'relationship_form_associate_dropdown' => 'Cerca e seleziona un contatto dalla lista',
    'relationship_form_associate_dropdown_placeholder' => 'Cerca e seleziona un contatto esistente',
    'relationship_form_also_create_contact' => 'Aggiungi questa persona anche come Contatto.',
    'relationship_form_add_description' => 'Ti permetterà di trattare questa persona come ogni altro contatto.',
    'relationship_form_add_no_existing_contact' => 'Al momento non hai contatti che possono essere una relazione :name.',
    'relationship_delete_confirmation' => 'Sei sicuro di voler eliminare questa relazione? L\'eliminazione è permanente.',
    'relationship_unlink_confirmation' => 'Rimuovere questa relazione? Il contatto non sará cancellato – solo la relazione.',
    'relationship_form_add_success' => 'Relazione impostata correttamente.',
    'relationship_form_deletion_success' => 'La relazione è stata eliminata.',

    // tasks
    'tasks_title' => 'Cose da fare',
    'tasks_blank_title' => 'Nulla da fare.',
    'tasks_form_title' => 'Titolo',
    'tasks_form_description' => 'Descrizione (facoltativa)',
    'tasks_add_task' => 'Aggiungi compito',
    'tasks_delete_success' => 'Compito rimosso',
    'tasks_complete_success' => 'Compito completato',

    // activities
    'activity_title' => 'Attività',
    'activity_type_category_simple_activities' => 'Attività semplici',
    'activity_type_category_sport' => 'Sport',
    'activity_type_category_food' => 'Cibo',
    'activity_type_category_cultural_activities' => 'Attività culturali',
    'activity_type_just_hung_out' => 'siamo usciti',
    'activity_type_watched_movie_at_home' => 'visto un film, a casa',
    'activity_type_talked_at_home' => 'parlato, a casa',
    'activity_type_did_sport_activities_together' => 'hanno giocato insieme a uno sport',
    'activity_type_ate_at_his_place' => 'mangiato a casa sua/loro',
    'activity_type_went_bar' => 'andati al bar',
    'activity_type_ate_at_home' => 'mangiato a casa',
    'activity_type_picnicked' => 'abbiamo fatto un picnic',
    'activity_type_ate_restaurant' => 'mangiato al ristorante',
    'activity_type_went_theater' => 'andati a teatro',
    'activity_type_went_concert' => 'andati a un concerto',
    'activity_type_went_play' => 'andati a una rappresentazione teatrale',
    'activity_type_went_museum' => 'andati al museo',
    'activities_add_activity' => 'Aggiungi attività',
    'activities_add_more_details' => 'Aggiungi ulteriori dettagli',
    'activities_add_emotions' => 'Aggiungi Umori/emozioni',
    'activities_add_category' => 'Indica una categoria',
    'activities_add_participants_cta' => 'Aggiungi partecipanti',
    'activities_item_information' => ':Activity il :date',
    'activities_add_title' => 'Cosa hai fatto con {name}?',
    'activities_summary' => 'Descrivi cosa avete fatto',
    'activities_add_pick_activity' => 'Vorresti categorizzare quest\'attività? Non devi, ma ti darà le statistiche in seguito (facoltativo)',
    'activities_add_date_occured' => 'L\'attività è avvenuta il…',
    'activities_add_participants' => 'Chi, a parte {name}, ha partecipato a questa attività? (opzionale)',
    'activities_add_emotions_title' => 'Vuoi registrare come ti sei sentito durante questa attivitá? (facoltativo)',
    'activities_blank_title' => 'Tieni traccia di quello che tu e {name} avete fatto, e ciò di cui avete parlato',
    'activities_blank_add_activity' => 'Agginugi attività',
    'activities_add_success' => 'Attività aggiunta',
    'activities_add_error' => 'Errore durante l\'aggiunta dell\'attività',
    'activities_update_success' => 'Attività aggiornata',
    'activities_delete_success' => 'Attività rimossa',
    'activities_who_was_involved' => 'Chi era coinvolto?',
    'activities_activity' => 'Categoria dell\'attività',
    'activities_view_activities_report' => 'Visualizza resoconti attività',
    'activities_profile_title' => 'Attività tra tu e :name',
    'activities_profile_subtitle' => 'Hai registrato :total_activities attività con :name e :activities_last_twelve_months negli ultimi 12 mesi.|Hai registrato :total_activities attività con :name e :activities_last_twelve_months negli ultimi 12 mesi.',
    'activities_profile_year_summary_activity_types' => 'Ecco un resoconto dei tipi di attività svolte nel :year',
    'activities_profile_year_summary' => 'Ecco cosa avete fatto insieme nel :year',
    'activities_profile_number_occurences' => ':value attività|:value attività',
    'activities_list_participants' => 'Partecipanti ({total}):',
    'activities_list_emotions' => 'Emozioni provate:',
    'activities_list_date' => 'Accaduto il',
    'activities_list_category' => 'Categoria:',

    // notes
    'notes_create_success' => 'Nota creata',
    'notes_update_success' => 'Nota aggiornata',
    'notes_delete_success' => 'Nota rimossa',
    'notes_add_cta' => 'Aggiungi nota',
    'notes_favorite' => 'Aggiungi/rimuovi dalle note preferite',
    'notes_delete_title' => 'Rimuovi nota',
    'notes_delete_confirmation' => 'Rimuovere nota? Questo cambio è permanente.',

    // gifts
    'gifts_title' => 'Regali',
    'gifts_add_success' => 'Regalo aggiunto',
    'gifts_delete_success' => 'Regalo rimosso',
    'gifts_delete_confirmation' => 'Rimuovere regalo?',
    'gifts_add_gift' => 'Aggiungi regalo',
    'gifts_link' => 'Collegamento',
    'gifts_for' => 'Per: {name}',
    'gifts_delete_cta' => 'Rimuovi',
    'gifts_add_title' => 'Gestione dei regali a :name',
    'gifts_add_gift_idea' => 'Idea regalo',
    'gifts_add_gift_already_offered' => 'Regalo dato',
    'gifts_add_gift_received' => 'Regalo ricevuto',
    'gifts_add_gift_title' => 'Cos\'è questo regalo?',
    'gifts_add_gift_name' => 'Nome del regalo',
    'gifts_add_link' => 'Link alla pagina web (facoltativo)',
    'gifts_add_value' => 'Valore (facoltativo)',
    'gifts_add_comment' => 'Commenti (facoltativo)',
    'gifts_add_recipient' => 'Destinatario (opzionale)',
    'gifts_add_recipient_field' => 'Destinatario',
    'gifts_add_photo' => 'Foto (opzionale)',
    'gifts_add_photo_title' => 'Aggiungi una foto per questo regalo',
    'gifts_add_someone' => 'Questo regalo é per qualcuno in particolare nella famiglia di {name}',
    'gifts_delete_title' => 'Rimuovi un regalo',
    'gifts_ideas' => 'Idee regalo',
    'gifts_offered' => 'Regali dati',
    'gifts_offered_as_an_idea' => 'Segna come idea',
    'gifts_received' => 'Regali ricevuti',
    'gifts_view_comment' => 'Visualizza commento',
    'gifts_mark_offered' => 'Segna come dato',
    'gifts_update_success' => 'Regalo modificato',
    'gifts_add_date' => 'Data (opzionale)',

    // debts
    'debt_delete_confirmation' => 'Rimuovere questo debito?',
    'debt_delete_success' => 'Debito rimosso',
    'debt_add_success' => 'Debito aggiunto',
    'debt_title' => 'Debiti',
    'debt_add_cta' => 'Aggiungi debito',
    'debt_you_owe' => 'Devi :amount',
    'debt_they_owe' => ':name ti deve :amount',
    'debt_add_title' => 'Gestione dei debiti',
    'debt_add_you_owe' => 'devi a :name',
    'debt_add_they_owe' => ':name ti deve',
    'debt_add_amount' => 'l\'ammontare di',
    'debt_add_reason' => 'per questo motivo (facoltativo)',
    'debt_add_add_cta' => 'Aggiungi debito',
    'debt_edit_update_cta' => 'Aggiorna debito',
    'debt_edit_success' => 'Debito aggiornato',
    'debts_blank_title' => 'Gestisci ciò che devi a :name e quello che :name ti deve',

    // tags
    'tag_edit' => 'Modifica etichetta',
    'tag_add' => 'Aggiungi etichette',
    'tag_add_search' => 'Aggiungi o cerca etichette',
    'tag_no_tags' => 'Nessuna etichetta',

    // Introductions
    'introductions_sidebar_title' => 'Come vi siete conosciuti',
    'introductions_blank_cta' => 'Indica come hai conosciuto :name',
    'introductions_title_edit' => 'Come hai conosciuto :name?',
    'introductions_additional_info' => 'Spiega come e dove vi siete conosciuti',
    'introductions_edit_met_through' => 'Qualcuno ti ha presentato a questa persona?',
    'introductions_no_met_through' => 'Nessuno',
    'introductions_first_met_date' => 'Data in cui vi siete conosciuti',
    'introductions_no_first_met_date' => 'Non ricordo la data in cui ci siamo conosciuti',
    'introductions_first_met_date_known' => 'Questo é il giorno in cui si siamo conosciuti',
    'introductions_add_reminder' => 'Aggiungi un promemoria per celebrare questo incontro nel suo anniversario',
    'introductions_update_success' => 'Informazioni sull\'incontro con questa persona aggiornate',
    'introductions_met_through' => 'Conosciuto/a attraverso <a href=":url">:name</a>',
    'introductions_met_date' => 'Incontrato/a il :date',
    'introductions_reminder_title' => 'Anniversario del giorno in cui vi siete conosciuti',

    // Deceased
    'deceased_reminder_title' => 'Anniversario della morte di :name',
    'deceased_mark_person_deceased' => 'Segna come deceduto',
    'deceased_know_date' => 'Conosco la data di decesso di questa persona',
    'deceased_add_reminder' => 'Aggiungi un promemoria per questa data',
    'deceased_label' => 'Deceduto/a',
    'deceased_date_label' => 'Data morte',
    'deceased_label_with_date' => 'Deceduto/a il :date',
    'deceased_age' => 'Età di decesso',

    // Contact information
    'contact_info_title' => 'Informazioni di contatto',
    'contact_info_form_content' => 'Contenuti',
    'contact_info_form_contact_type' => 'Tipo di contatto',
    'contact_info_form_personalize' => 'Personalizza',
    'contact_info_address' => 'Vive in',

    // Addresses
    'contact_address_title' => 'Indirizzi',
    'contact_address_form_name' => 'Etichetta (facoltativa)',
    'contact_address_form_street' => 'Via (facoltativa)',
    'contact_address_form_city' => 'Cittá (facoltativa)',
    'contact_address_form_province' => 'Provincia (facoltativa)',
    'contact_address_form_postal_code' => 'Codice postale (facoltativa)',
    'contact_address_form_country' => 'Regione (facoltativa)',
    'contact_address_form_latitude' => 'Latitudine (solo numeri) (facoltativa)',
    'contact_address_form_longitude' => 'Longitudine (solo numeri) (facoltativa)',

    // Pets
    'pets_kind' => 'Tipo di animale domestico',
    'pets_name' => 'Nome (facoltativo)',
    'pets_create_success' => 'Animale domestico aggiunto con successo',
    'pets_update_success' => 'Animale domestico modificato',
    'pets_delete_success' => 'Animale domestico rimosso',
    'pets_title' => 'Animali domestici',
    'pets_reptile' => 'Rettile',
    'pets_bird' => 'Uccello',
    'pets_cat' => 'Gatto',
    'pets_dog' => 'Cane',
    'pets_fish' => 'Pesce',
    'pets_hamster' => 'Criceto',
    'pets_horse' => 'Cavallo',
    'pets_rabbit' => 'Coniglio',
    'pets_rat' => 'Topo/Ratto',
    'pets_small_animal' => 'Animale di piccole dimensioni',
    'pets_other' => 'Altro',

    // life events
    'life_event_list_tab_life_events' => 'Eventi della vita',
    'life_event_list_tab_other' => 'Note, promemoria, …',
    'life_event_list_title' => 'Eventi della vita',
    'life_event_blank' => 'Memorizza gli eventi importanti della vita di {name} per riferimento futuro.',
    'life_event_list_cta' => 'Aggiungi evento',
    'life_event_create_category' => 'Tutte le categorie',
    'life_event_create_life_event' => 'Aggiungi evento',
    'life_event_create_default_title' => 'Titolo (facoltativo)',
    'life_event_create_default_story' => 'Storia (facoltativo)',
    'life_event_create_date' => 'Non devi indicare un giorno o un mese, solo l\'anno è obbligatorio.',
    'life_event_create_default_description' => 'Aggiungi informazioni su quello che sai',
    'life_event_create_add_yearly_reminder' => 'Aggiungi un promemoria per l\'anniversario di questo evento',
    'life_event_create_success' => 'Evento aggiunto',
    'life_event_delete_title' => 'Elimina un evento',
    'life_event_delete_description' => 'Sei sicuro di eliminare questo evento? Non si può annullare.',
    'life_event_delete_success' => 'Evento eliminato con successo',
    'life_event_date_it_happened' => 'Data di avvenimento',
    'life_event_category_work_education' => 'Lavoro e Istruzione',
    'life_event_category_family_relationships' => 'Famiglia e Relazioni',
    'life_event_category_home_living' => 'Casa e Vita',
    'life_event_category_health_wellness' => 'Salute e Benessere',
    'life_event_category_travel_experiences' => 'Viaggi ed Esperienze',
    'life_event_sentence_new_job' => 'Inizio di un nuovo lavoro',
    'life_event_sentence_retirement' => 'Pensionamento',
    'life_event_sentence_new_school' => 'Inizio scuola',
    'life_event_sentence_study_abroad' => 'Studi all\'estero',
    'life_event_sentence_volunteer_work' => 'Inizio volontariato',
    'life_event_sentence_published_book_or_paper' => 'Pubblicato un articolo',
    'life_event_sentence_military_service' => 'Inizio servizio militare',
    'life_event_sentence_new_relationship' => 'Inizio di una relazione',
    'life_event_sentence_engagement' => 'Fidanzamento',
    'life_event_sentence_marriage' => 'Matrimonio',
    'life_event_sentence_anniversary' => 'Anniversario',
    'life_event_sentence_expecting_a_baby' => 'Aspetta un bambino',
    'life_event_sentence_new_child' => 'Ha avuto un bambino',
    'life_event_sentence_new_family_member' => 'Nuovo membro in famiglia',
    'life_event_sentence_new_pet' => 'Ha preso un animale domestico',
    'life_event_sentence_end_of_relationship' => 'Fine di una relazione',
    'life_event_sentence_loss_of_a_loved_one' => 'Perdita di un caro',
    'life_event_sentence_moved' => 'Trasferimento',
    'life_event_sentence_bought_a_home' => 'Comprato una casa',
    'life_event_sentence_home_improvement' => 'Miglioramento alla casa',
    'life_event_sentence_holidays' => 'Andato in vacanza',
    'life_event_sentence_new_vehicle' => 'Nuovo veicolo',
    'life_event_sentence_new_roommate' => 'Nuovo coinquilino',
    'life_event_sentence_overcame_an_illness' => 'Superamento di una malattia',
    'life_event_sentence_quit_a_habit' => 'Fine di un vizio',
    'life_event_sentence_new_eating_habits' => 'Inizio di nuove abitudini alimentari',
    'life_event_sentence_weight_loss' => 'Perso peso',
    'life_event_sentence_wear_glass_or_contact' => 'Occhiali o lenti a contatto',
    'life_event_sentence_broken_bone' => 'Rotto un osso',
    'life_event_sentence_removed_braces' => 'Levato l\'apparecchio',
    'life_event_sentence_surgery' => 'Ha subito un intervento',
    'life_event_sentence_dentist' => 'Andato dal dentista',
    'life_event_sentence_new_sport' => 'Iniziato uno sport',
    'life_event_sentence_new_hobby' => 'Iniziato un hobby',
    'life_event_sentence_new_instrument' => 'Imparato un nuovo strumento',
    'life_event_sentence_new_language' => 'Imparato una nuova lingua',
    'life_event_sentence_tattoo_or_piercing' => 'Fatto un piercing o un tatuaggio',
    'life_event_sentence_new_license' => 'Preso una patente',
    'life_event_sentence_travel' => 'Viaggiato',
    'life_event_sentence_achievement_or_award' => 'Preso un premio o un riconoscimento',
    'life_event_sentence_changed_beliefs' => 'Cambiato credo',
    'life_event_sentence_first_word' => 'Parlato per la prima volta',
    'life_event_sentence_first_kiss' => 'Primo bacio',

    // documents
    'document_list_title' => 'Documenti',
    'document_list_cta' => 'Carica documento',
    'document_list_blank_desc' => 'Qui puoi archiviare documenti relativi a questa persona.',
    'document_upload_zone_cta' => 'Carica un file',
    'document_upload_zone_progress' => 'Caricando il documento…',
    'document_upload_zone_error' => 'Si è verificato un errore. Per favore, riprova a caricare il documento.',

    // Photos
    'photo_title' => 'Foto',
    'photo_list_title' => 'Foto',
    'photo_list_cta' => 'Carica foto',
    'photo_list_blank_desc' => 'Qui puoi salvare foto relative a questa persona, caricane una adesso!',
    'photo_upload_zone_cta' => 'Carica una foto',
    'photo_current_profile_pic' => 'Attuale immagine del profilo',
    'photo_make_profile_pic' => 'Rendi questa foto immagine del profilo',
    'photo_delete' => 'Elimina foto',
    'photo_next' => 'Prossima foto ❯',
    'photo_previous' => '❮ Foto precedente',

    // Avatars
    'avatar_change_title' => 'Cambia il tuo avatar',
    'avatar_question' => 'Quale account preferisci usare?',
    'avatar_default_avatar' => 'Avatar predefinito',
    'avatar_adorable_avatar' => 'L\'avatar adorabile',
    'avatar_gravatar' => 'Il Gravatar associato all\'indirizzo email di questa persona. <a href="https://gravatar.com/">Gravatar</a> è un sistema globale che permette agli utenti di associare indirizzi email con foto.',
    'avatar_current' => 'Mantieni l\'avatar attuale',
    'avatar_photo' => 'Da una foto che carichi',
    'avatar_crop_new_avatar_photo' => 'Ritaglia nuova foto dell\'avatar',

    // emotions
    'emotion_this_made_me_feel' => 'Questo mi ha fatto sentire…',

    // logs
    'auditlogs_link' => 'Cronologia',
    'auditlogs_title' => 'Tutto ciò che è accaduto a :name',
    'auditlogs_breadcrumb' => 'Cronologia',
    'auditlogs_author' => 'Da :name il :date',

    // contact field label
    'contact_field_label_home' => 'Casa',
    'contact_field_label_work' => 'Lavoro',
    'contact_field_label_cell' => 'Cellulare',
    'contact_field_label_fax' => 'Fax',
    'contact_field_label_pager' => 'Cercapersone',
    'contact_field_label_main' => 'Principale',
    'contact_field_label_other' => 'Altro',
    'contact_field_label_personal' => 'Personale',
];
