<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  84203 => 'Quảng Ninh',
  84204 => 'Bắc Giang',
  84205 => 'Lạng Sơn',
  84206 => 'Cao Bằng',
  84207 => 'Tuyên Quang',
  84208 => 'Thái Nguyên',
  84209 => 'Tỉnh Bắc Kạn',
  84210 => 'Phú Thọ',
  84211 => 'Vĩnh Phúc',
  84212 => 'Sơn La',
  84213 => 'Lai Châu',
  84214 => 'Lào Cai',
  84215 => 'Điện Biên',
  84216 => 'Yên Bái',
  84218 => 'Hòa Bình',
  84219 => 'Hà Giang',
  84220 => 'Hải Dương',
  84221 => 'Hưng Yên',
  84222 => 'Bắc Ninh',
  84225 => 'Thành phố Hải Phòng',
  84226 => 'Hà Nam',
  84227 => 'Thái Bình',
  84228 => 'Nam Định',
  84229 => 'Ninh Bình',
  84232 => 'Quảng Bình',
  84233 => 'Quảng Trị',
  84234 => 'Thừa Thiên-Huế',
  84235 => 'Quảng Nam',
  84236 => 'TP Đà Nẵng',
  84237 => 'Thanh Hóa',
  84238 => 'Nghệ An',
  84239 => 'Hà Tĩnh',
  8424 => 'Thủ đô Hà Nội',
  84251 => 'Đồng Nai',
  84252 => 'Bình Thuận',
  84254 => 'Bà Rịa-Vũng Tàu',
  84255 => 'Quảng Ngãi',
  84256 => 'Bình Định',
  84257 => 'Phú Yên',
  84258 => 'Khánh Hòa',
  84259 => 'Ninh Thuận',
  84260 => 'Kon Tum',
  84261 => 'Đăk Nông',
  84262 => 'Đăk Lăk',
  84263 => 'Lâm Đồng',
  84269 => 'Gia Lai',
  84270 => 'Vĩnh Long',
  84271 => 'Bình Phước',
  84272 => 'Long An',
  84273 => 'Tiền Giang',
  84274 => 'Bình Dương',
  84275 => 'Bến Tre',
  84276 => 'Tây Ninh',
  84277 => 'Đồng Tháp',
  8428 => 'Thành phố Hồ Chí Minh',
  84290 => 'Cà Mau',
  84291 => 'Bạc Liêu',
  84292 => 'Thành phố Cần Thơ',
  84293 => 'Hậu Giang',
  84294 => 'Trà Vinh',
  84296 => 'An Giang',
  84297 => 'Kiên Giang',
  84299 => 'Sóc Trăng',
);
