<?php
namespace Aws\DynamoDbStreams\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Amazon DynamoDB Streams service.
 */
class DynamoDbStreamsException extends AwsException {}
