<?php

declare(strict_types=1);

namespace SpomkyLabs\Pki\X509\CertificationPath\Exception;

use RuntimeException;

/**
 * Exception thrown on certification path building errors.
 */
final class PathBuildingException extends RuntimeException
{
}
