<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    //index
    'people_not_found' => 'Contacto não encontrado',
    'people_list_number_kids' => ':count criança|:count crianças',
    'people_list_last_updated' => 'Última consulta:',
    'people_list_number_reminders' => ':count lembrete|:count lembretes',
    'people_list_blank_title' => 'Você ainda não tem ninguém em sua conta',
    'people_list_blank_cta' => 'Adicionar uma pessoa',
    'people_list_sort' => 'Ordenar',
    'people_list_stats' => ':count contacto|:count contactos',
    'people_list_firstnameAZ' => 'Classificar por primeiro nome A → Z',
    'people_list_firstnameZA' => 'Classificar por primeiro nome Z → A',
    'people_list_lastnameAZ' => 'Classificar por sobrenome A → Z',
    'people_list_lastnameZA' => 'Classificar por sobrenome Z → A',
    'people_list_lastactivitydateNewtoOld' => 'Ordenar por data da última atividade, mais recente para mais antigo',
    'people_list_lastactivitydateOldtoNew' => 'Ordenar por data da última atividade, mais antigo para mais recente',
    'people_list_filter_tag' => 'A mostrar todos os contactos etiquetados com',
    'people_list_clear_filter' => 'Limpar filtro',
    'people_list_contacts_per_tags' => ':count contacto|:count contactos',
    'people_list_show_dead' => 'Show deceased people (:count)',
    'people_list_hide_dead' => 'Hide deceased people (:count)',
    'people_search' => 'Search your contacts…',
    'people_search_no_results' => 'No results found',
    'people_search_next' => 'Next',
    'people_search_prev' => 'Previous',
    'people_search_rows_per_page' => 'Rows per page',
    'people_search_of' => 'of',
    'people_search_page' => 'Page',
    'people_search_all' => 'All',
    'people_add_new' => 'Add new person',
    'people_list_account_usage' => 'Consumo da sua conta: :current/:limit contactos',
    'people_list_account_upgrade_title' => 'Upgrade your account to unlock it to its full potential.',
    'people_list_account_upgrade_cta' => 'Upgrade now',
    'people_list_untagged' => 'View untagged contacts',
    'people_list_filter_untag' => 'Showing all untagged contacts',
    'archived_contact_readonly' => 'Archived contact can’t be edited, please unarchive it first.',

    // people add
    'people_add_title' => 'Adicione uma nova pessoa',
    'people_add_missing' => 'No person found – add a new one now',
    'people_add_firstname' => 'Primeiro nome',
    'people_add_middlename' => 'Middle name (optional)',
    'people_add_lastname' => 'Last name (optional)',
    'people_add_email' => 'Email (optional)',
    'people_add_nickname' => 'Nickname (optional)',
    'people_add_cta' => 'Adicionar essa pessoa',
    'people_save_and_add_another_cta' => 'Enviar e adicionar outra pessoa',
    'people_add_success' => ':name foi criado com sucesso',
    'people_add_gender' => 'Gênero',
    'people_delete_success' => 'O contato foi excluído',
    'people_delete_message' => 'Delete contact',
    'people_delete_confirmation' => 'Are you sure you want to delete :name’s contact? Deletion is immediate and permanent.',
    'people_add_birthday_reminder' => 'Desejar feliz aniversário a :name',
    'people_add_birthday_reminder_deceased' => 'On this date, :name would have celebrated their birthday',
    'people_add_import' => 'Deseja <a href=":url">importar os seus contatos</a>?',
    'people_edit_email_error' => 'Já existe um contacto na sua conta com este endereço de e-mail. Por favor escolha outro.',
    'people_export' => 'Export as vCard',
    'people_add_reminder_for_birthday' => 'Create an annual birthday reminder',

    // show
    'section_contact_information' => 'Informações de contacto',
    'section_personal_activities' => 'Atividades',
    'section_personal_reminders' => 'Lembretes',
    'section_personal_tasks' => 'Tarefas',
    'section_personal_gifts' => 'Presentes',
    'section_personal_notes' => 'Notes',

    // archived contacts
    'list_link_to_active_contacts' => 'You are viewing archived contacts. See the <a href=":url">list of active contacts</a> instead.',
    'list_link_to_archived_contacts' => 'List of archived contacts',

    // Header
    'me' => 'This is you',
    'edit_contact_information' => 'Editar informação do contato',
    'contact_archive' => 'Archive contact',
    'contact_unarchive' => 'Unarchive contact',
    'contact_archive_help' => 'Archived contacts are not be shown on the contact list, but still appear in search results.',
    'call_button' => 'Registar uma chamada',
    'set_favorite' => 'Favorite contacts are placed at the top of the contact list',

    // Stay in touch
    'stay_in_touch' => 'Stay in touch',
    'stay_in_touch_frequency' => 'Stay in touch every day|Stay in touch every {count} days',
    'stay_in_touch_next_date' => 'Next due: {date}',
    'stay_in_touch_invalid' => 'The frequency must be a number greater than 0.',
    'stay_in_touch_premium' => 'You need to upgrade your account to make use of this feature',
    'stay_in_touch_modal_title' => 'Stay in touch',
    'stay_in_touch_modal_desc' => 'We can remind you by email to keep in touch with {firstname} at a regular interval.',
    'stay_in_touch_modal_label' => 'Send me an email every… {count} day|Send me an email every… {count} days',

    // Calls
    'modal_call_title' => 'Registar uma chamada',
    'modal_call_comment' => 'Sobre o que falaram? (opcional)',
    'modal_call_exact_date' => 'O telefonema aconteceu em',
    'modal_call_who_called' => 'Who called?',
    'modal_call_emotion' => 'Do you want to log how you felt during this call? (optional)',
    'calls_add_success' => 'O telefonema foi guardado.',
    'call_delete_confirmation' => 'Tem certeza que deseja eliminar esta chamada?',
    'call_delete_success' => 'A chamada foi eliminada com sucesso',
    'call_title' => 'Chamadas telefónicas',
    'call_empty_comment' => 'Sem detalhes',
    'call_blank_title' => 'Keep track of the phone calls you’ve done with {name}',
    'call_blank_desc' => 'You called {name}',
    'call_you_called' => 'You called',
    'call_he_called' => '{name} called',
    'call_emotions' => 'Emotions:',

    // Conversation
    'conversation_blank' => 'Record conversations you have with :name on social media, SMS…',
    'conversation_delete_link' => 'Delete the conversation',
    'conversation_edit_title' => 'Edit conversation',
    'conversation_edit_delete' => 'Are you sure you want to delete this conversation? Deletion is permanent.',
    'conversation_add_success' => 'The conversation has been successfully added.',
    'conversation_edit_success' => 'The conversation has been successfully updated.',
    'conversation_delete_success' => 'The conversation has been successfully deleted.',
    'conversation_add_title' => 'Record a new conversation',
    'conversation_add_when' => 'When did you have this conversation?',
    'conversation_add_who_wrote' => 'Who sent this message?',
    'conversation_add_how' => 'How did you communicate?',
    'conversation_add_you' => 'You',
    'conversation_add_content' => 'Write down what was said',
    'conversation_add_what_was_said' => 'What did you say?',
    'conversation_add_another' => 'Add another message',
    'conversation_add_error' => 'You must add at least one message.',
    'conversation_list_table_messages' => 'Messages',
    'conversation_list_table_content' => 'Partial content (last message)',
    'conversation_list_title' => 'Conversations',
    'conversation_list_cta' => 'Log conversation',

    // age - birthday
    'birthdate_not_set' => 'Birthday is not set',
    'age_approximate_in_years' => 'por volta de :age anos de idade',
    'age_exact_in_years' => ':age anos de idade',
    'age_exact_birthdate' => 'nascido :date',

    // Last called
    'last_called' => 'Last called: :date',
    'last_talked_to' => 'Last called: {date}',
    'last_called_empty' => 'Last called: unknown',
    'last_activity_date' => 'Last activity together: :date',
    'last_activity_date_empty' => 'Last activity together: unknown',

    // additional information
    'information_edit_success' => 'O perfil foi atualizado com sucesso',
    'information_edit_title' => 'Editar informações pessoais para :name',
    'information_edit_max_size' => 'Max :size Kb.',
    'information_edit_max_size2' => 'Max {size} Kb.',
    'information_edit_firstname' => 'Primeiro nome',
    'information_edit_lastname' => 'Last name (optional)',
    'information_edit_description' => 'Description (optional)',
    'information_edit_description_help' => 'Used on the contact list to add some context, if necessary.',
    'information_edit_unknown' => 'Eu não sei a idade desta pessoa',
    'information_edit_probably' => 'This person is probably…',
    'information_edit_not_year' => 'I know the day and month of this person’s birthday, but not the year…',
    'information_edit_exact' => 'I know this person’s exact birthday…',
    'information_edit_birthdate_label' => 'Birthday',
    'information_no_work_defined' => 'Nenhuma informação profissional definida',
    'information_work_at' => 'em :company',
    'work_add_cta' => 'Atualizar informação de trabalho',
    'work_edit_success' => 'Work information updated',
    'work_edit_title' => 'Atualizar a informação profissional de :name',
    'work_edit_job' => 'Cargo (opcional)',
    'work_edit_company' => 'Empresa (opcional)',
    'work_information' => 'Work information',

    // food preferences
    'food_preferences_add_success' => 'As preferências de alimentos foram salvas',
    'food_preferences_edit_description' => 'Talvez :firstname ou alguém na família de :family tenha uma alergia. Ou não gosta de uma garrafa específica de vinho. Indique-os aqui para que você lembre-se da próxima vez que você os convide para o jantar',
    'food_preferences_edit_description_no_last_name' => 'Talvez :firstname tenha uma alergia. Ou não gosta de uma garrafa específica de vinho. Indique-os aqui para que você lembre-se da próxima vez que você os convide para o jantar',
    'food_preferences_edit_title' => 'Indique preferências de alimentos',
    'food_preferences_edit_cta' => 'Guardar preferências de alimentos',
    'food_preferences_title' => 'Preferências alimentares',
    'food_preferences_cta' => 'Adicione preferências de alimentos',

    // reminders
    'reminders_blank_title' => 'Há algo sobre o qual você quer se lembrar :name?',
    'reminders_blank_add_activity' => 'Adicionar um lembrete',
    'reminders_add_title' => 'Sobre o que você gostaria de lembrar sobre :name?',
    'reminders_add_description' => 'Please remind me to…',
    'reminders_add_next_time' => 'Quando é a próxima vez que você gostaria de ser lembrado sobre isso?',
    'reminders_add_once' => 'Lembre-me sobre isso apenas uma vez',
    'reminders_add_recurrent' => 'Lembre-me sobre isso a todo momento',
    'reminders_add_starting_from' => 'começar a partir da data especificada acima',
    'reminders_add_cta' => 'Adicionar lembrete',
    'reminders_edit_update_cta' => 'Atualizar lembrete',
    'reminders_add_error_custom_text' => 'Você precisa indicar um texto para esse lembrete',
    'reminders_create_success' => 'O lembrete foi adicionado com sucesso',
    'reminders_delete_success' => 'O lembrete foi excluído com sucesso',
    'reminders_update_success' => 'O lembrete foi atualizado com sucesso',
    'reminders_add_optional_comment' => 'Optional comment',

    'reminder_frequency_day' => 'todos os dias|a cada :number dias',
    'reminder_frequency_week' => 'toda semana|cada :number semanas',
    'reminder_frequency_month' => 'todo month|cada :number mêses',
    'reminder_frequency_year' => 'todo year|cada :number anos',
    'reminder_frequency_one_time' => 'em :date',
    'reminders_delete_confirmation' => 'em certeza de que deseja excluir esse lembrete?',
    'reminders_delete_cta' => 'Deletar',
    'reminders_next_expected_date' => 'em',
    'reminders_cta' => 'Adicionar um lembrete',
    'reminders_description' => 'We will send an email for each one of the reminders below. Reminders are sent every morning the day events will happen. Reminders automatically added for birthdays can not be deleted. If you want to change those dates, edit the birthday of the contacts.',
    'reminders_one_time' => 'Uma vez',
    'reminders_type_week' => 'semana',
    'reminders_type_month' => 'mês',
    'reminders_type_year' => 'ano',
    'reminders_birthday' => 'Birthdate of :name',
    'reminders_free_plan_warning' => 'You are on the Free plan. No emails are sent on this plan. To receive your reminders by email, upgrade your account.',

    // relationships
    'relationship_form_add' => 'Add a new relationship',
    'relationship_form_edit' => 'Edit an existing relationship',
    'relationship_form_is_with' => 'This person is…',
    'relationship_form_is_with_name' => ':name is…',
    'relationship_form_add_choice' => 'Who is the relationship with?',
    'relationship_form_create_contact' => 'Add a new person',
    'relationship_form_associate_contact' => 'An existing contact',
    'relationship_form_associate_dropdown' => 'Search and select an existing contact from the dropdown below',
    'relationship_form_associate_dropdown_placeholder' => 'Search and select an existing contact',
    'relationship_form_also_create_contact' => 'Create a Contact entry for this person.',
    'relationship_form_add_description' => 'This will let you treat this person like any other contact.',
    'relationship_form_add_no_existing_contact' => 'You don’t have any contacts who can be related to :name at the moment.',
    'relationship_delete_confirmation' => 'Are you sure you want to delete this relationship? Deletion is permanent.',
    'relationship_unlink_confirmation' => 'Are you sure you want to delete this relationship? This person will not be deleted – only the relationship between the two.',
    'relationship_form_add_success' => 'The relationship has been successfully set.',
    'relationship_form_deletion_success' => 'The relationship has been deleted.',

    // tasks
    'tasks_title' => 'Tasks',
    'tasks_blank_title' => 'You don’t have any tasks yet.',
    'tasks_form_title' => 'Título',
    'tasks_form_description' => 'Description (optional)',
    'tasks_add_task' => 'Adicionar uma tarefa',
    'tasks_delete_success' => 'A tarefa foi excluída com sucesso',
    'tasks_complete_success' => 'O status da tarefa foi alterado com sucesso',

    // activities
    'activity_title' => 'Atividades',
    'activity_type_category_simple_activities' => 'Simple activities',
    'activity_type_category_sport' => 'Sport',
    'activity_type_category_food' => 'Food',
    'activity_type_category_cultural_activities' => 'Cultural activities',
    'activity_type_just_hung_out' => 'apenas sai',
    'activity_type_watched_movie_at_home' => 'assisti um filme em casa',
    'activity_type_talked_at_home' => 'apenas fiquei em casa',
    'activity_type_did_sport_activities_together' => 'played a sport together',
    'activity_type_ate_at_his_place' => 'ate at their place',
    'activity_type_went_bar' => 'fui para um bar',
    'activity_type_ate_at_home' => 'comi em casa',
    'activity_type_picnicked' => 'picnicked',
    'activity_type_ate_restaurant' => 'comi em um restaurante',
    'activity_type_went_theater' => 'fui a um teatro',
    'activity_type_went_concert' => 'fui a um concerto',
    'activity_type_went_play' => 'fui jogar',
    'activity_type_went_museum' => 'fui a um museu',
    'activities_add_activity' => 'Adicionar atividade',
    'activities_add_more_details' => 'Add more details',
    'activities_add_emotions' => 'Add emotions',
    'activities_add_category' => 'Indicate a category',
    'activities_add_participants_cta' => 'Add participants',
    'activities_item_information' => ':Activity. Aconteceu em :date',
    'activities_add_title' => 'What did you do with {name}?',
    'activities_summary' => 'Descreva o que você fez',
    'activities_add_pick_activity' => 'Would you like to categorize this activity? You don’t have to, but it will give you statistics later on (optional)',
    'activities_add_date_occured' => 'The activity happened on…',
    'activities_add_participants' => 'Who, apart from {name}, participated in this activity? (optional)',
    'activities_add_emotions_title' => 'Do you want to log how you felt during this activity? (optional)',
    'activities_blank_title' => 'Keep track of what you’ve done with {name} in the past, and what you’ve talked about',
    'activities_blank_add_activity' => 'Adicionar uma atividade',
    'activities_add_success' => 'A atividade foi adicionada com sucesso',
    'activities_add_error' => 'Error when adding the activity',
    'activities_update_success' => 'A atividade foi atualizada com sucesso',
    'activities_delete_success' => 'A atividade foi excluída com sucesso',
    'activities_who_was_involved' => 'Quem estava envolvido?',
    'activities_activity' => 'Activity Category',
    'activities_view_activities_report' => 'View activities report',
    'activities_profile_title' => 'Activities report between :name and you',
    'activities_profile_subtitle' => 'You’ve logged :total_activities activity with :name in total and :activities_last_twelve_months in the last 12 months so far.|You’ve logged :total_activities activities with :name in total and :activities_last_twelve_months in the last 12 months so far.',
    'activities_profile_year_summary_activity_types' => 'Here is a breakdown of the type of activities you’ve done together in :year',
    'activities_profile_year_summary' => 'Here is what you two have done in :year',
    'activities_profile_number_occurences' => ':value activity|:value activities',
    'activities_list_participants' => 'Participants ({total}):',
    'activities_list_emotions' => 'Emotions felt:',
    'activities_list_date' => 'Happened on',
    'activities_list_category' => 'Category:',

    // notes
    'notes_create_success' => 'A nota foi adicionada com sucesso',
    'notes_update_success' => 'A nota foi guardada com sucesso',
    'notes_delete_success' => 'A nota foi excluída com sucesso',
    'notes_add_cta' => 'Adicionar nota',
    'notes_favorite' => 'Add/remove from favorites',
    'notes_delete_title' => 'Eliminar nota',
    'notes_delete_confirmation' => 'Tem certeza de que deseja excluir esta anotação? A exclusão é permanente',

    // gifts
    'gifts_title' => 'Gifts',
    'gifts_add_success' => 'O presente foi adicionado com sucesso',
    'gifts_delete_success' => 'O presente foi excluído com sucesso',
    'gifts_delete_confirmation' => 'Tem certeza de que deseja excluir esse presente?',
    'gifts_add_gift' => 'Adicionar um presente',
    'gifts_link' => 'Ligar',
    'gifts_for' => 'For: {name}',
    'gifts_delete_cta' => 'Deletar',
    'gifts_add_title' => 'Gerenciamento de presentes para :name',
    'gifts_add_gift_idea' => 'Ideia de presente',
    'gifts_add_gift_already_offered' => 'Presente já oferecido',
    'gifts_add_gift_received' => 'Gift received',
    'gifts_add_gift_title' => 'O que é esse presente?',
    'gifts_add_gift_name' => 'Gift name',
    'gifts_add_link' => 'Ligar com o site (Opcional)',
    'gifts_add_value' => 'Valor (Opcional)',
    'gifts_add_comment' => 'Comentário (Opcional)',
    'gifts_add_recipient' => 'Recipient (optional)',
    'gifts_add_recipient_field' => 'Recipient',
    'gifts_add_photo' => 'Photo (optional)',
    'gifts_add_photo_title' => 'Add a photo for this gift',
    'gifts_add_someone' => 'This gift is for someone in {name}’s family in particular',
    'gifts_delete_title' => 'Delete a gift',
    'gifts_ideas' => 'Gift ideas',
    'gifts_offered' => 'Gifts given',
    'gifts_offered_as_an_idea' => 'Mark as an idea',
    'gifts_received' => 'Gifts received',
    'gifts_view_comment' => 'Ver comentário',
    'gifts_mark_offered' => 'Mark as given',
    'gifts_update_success' => 'The gift has been updated successfully',
    'gifts_add_date' => 'Date (optional)',

    // debts
    'debt_delete_confirmation' => 'Tem certeza de que deseja excluir esta dívida?',
    'debt_delete_success' => 'A dívida foi excluída com sucesso',
    'debt_add_success' => 'A dívida foi adicionada com sucesso',
    'debt_title' => 'Dívidas',
    'debt_add_cta' => 'Adicionar dívida',
    'debt_you_owe' => 'Você deve :amount',
    'debt_they_owe' => ':name te deve :amount',
    'debt_add_title' => 'Debt management',
    'debt_add_you_owe' => 'Você deve a :name',
    'debt_add_they_owe' => ':name te deve',
    'debt_add_amount' => 'a soma de',
    'debt_add_reason' => 'Pelo seguinte motivo (Opcional)',
    'debt_add_add_cta' => 'Adicionar dívida',
    'debt_edit_update_cta' => 'Update debt',
    'debt_edit_success' => 'The debt has been updated successfully',
    'debts_blank_title' => 'Manage debts you owe to :name or :name owes you',

    // tags
    'tag_edit' => 'Edit tag',
    'tag_add' => 'Add tags',
    'tag_add_search' => 'Add or search tags',
    'tag_no_tags' => 'No tags yet',

    // Introductions
    'introductions_sidebar_title' => 'How you met',
    'introductions_blank_cta' => 'Indicate how you met :name',
    'introductions_title_edit' => 'How did you meet :name?',
    'introductions_additional_info' => 'Explain how and where you met',
    'introductions_edit_met_through' => 'Has someone introduced you to this person?',
    'introductions_no_met_through' => 'No one',
    'introductions_first_met_date' => 'Date you met',
    'introductions_no_first_met_date' => 'I don’t know the date we met',
    'introductions_first_met_date_known' => 'This is the date we met',
    'introductions_add_reminder' => 'Add a reminder to celebrate this encounter on the anniversary this event happened',
    'introductions_update_success' => 'You’ve successfully updated the information about how you met this person',
    'introductions_met_through' => 'Met through <a href=":url">:name</a>',
    'introductions_met_date' => 'Met on :date',
    'introductions_reminder_title' => 'Anniversary of the day you first met',

    // Deceased
    'deceased_reminder_title' => 'Anniversary of the death of :name',
    'deceased_mark_person_deceased' => 'Mark this as deceased',
    'deceased_know_date' => 'I know the date that this person died',
    'deceased_add_reminder' => 'Add a reminder for this date',
    'deceased_label' => 'Deceased',
    'deceased_date_label' => 'Deceased date',
    'deceased_label_with_date' => 'Deceased on :date',
    'deceased_age' => 'Age at death',

    // Contact information
    'contact_info_title' => 'Contact information',
    'contact_info_form_content' => 'Content',
    'contact_info_form_contact_type' => 'Contact type',
    'contact_info_form_personalize' => 'Personalize',
    'contact_info_address' => 'Lives in',

    // Addresses
    'contact_address_title' => 'Addresses',
    'contact_address_form_name' => 'Label (optional)',
    'contact_address_form_street' => 'Street (optional)',
    'contact_address_form_city' => 'City (optional)',
    'contact_address_form_province' => 'Province (optional)',
    'contact_address_form_postal_code' => 'Postal code (optional)',
    'contact_address_form_country' => 'Country (optional)',
    'contact_address_form_latitude' => 'Latitude (numbers only) (optional)',
    'contact_address_form_longitude' => 'Longitude (numbers only) (optional)',

    // Pets
    'pets_kind' => 'Kind of pet',
    'pets_name' => 'Name (optional)',
    'pets_create_success' => 'The pet has been successfully added',
    'pets_update_success' => 'The pet has been updated',
    'pets_delete_success' => 'The pet has been deleted',
    'pets_title' => 'Pets',
    'pets_reptile' => 'Réptil',
    'pets_bird' => 'Pássaro',
    'pets_cat' => 'Gato',
    'pets_dog' => 'Cão',
    'pets_fish' => 'Peixe',
    'pets_hamster' => 'Hamster',
    'pets_horse' => 'Cavalo',
    'pets_rabbit' => 'Coelho',
    'pets_rat' => 'Rato',
    'pets_small_animal' => 'Animal pequeno',
    'pets_other' => 'Outro',

    // life events
    'life_event_list_tab_life_events' => 'Life events',
    'life_event_list_tab_other' => 'Notes, reminders, …',
    'life_event_list_title' => 'Life events',
    'life_event_blank' => 'Log what happens to the life of {name} for your future reference.',
    'life_event_list_cta' => 'Add life event',
    'life_event_create_category' => 'All categories',
    'life_event_create_life_event' => 'Add life event',
    'life_event_create_default_title' => 'Title (optional)',
    'life_event_create_default_story' => 'Story (optional)',
    'life_event_create_date' => 'You do not need to indicate a month or a day – only the year is mandatory.',
    'life_event_create_default_description' => 'Add information about what you know',
    'life_event_create_add_yearly_reminder' => 'Add a yearly reminder for this event',
    'life_event_create_success' => 'The life event has been added',
    'life_event_delete_title' => 'Delete a life event',
    'life_event_delete_description' => 'Are you sure you want to delete this life event? Deletion is permanent.',
    'life_event_delete_success' => 'The life event has been deleted',
    'life_event_date_it_happened' => 'Date it happened',
    'life_event_category_work_education' => 'Work & education',
    'life_event_category_family_relationships' => 'Family & relationships',
    'life_event_category_home_living' => 'Home & living',
    'life_event_category_health_wellness' => 'Health & wellness',
    'life_event_category_travel_experiences' => 'Travel & experiences',
    'life_event_sentence_new_job' => 'Started a new job',
    'life_event_sentence_retirement' => 'Retired',
    'life_event_sentence_new_school' => 'Started school',
    'life_event_sentence_study_abroad' => 'Studied abroad',
    'life_event_sentence_volunteer_work' => 'Started volunteering',
    'life_event_sentence_published_book_or_paper' => 'Published a paper',
    'life_event_sentence_military_service' => 'Started military service',
    'life_event_sentence_new_relationship' => 'Started a relationship',
    'life_event_sentence_engagement' => 'Got engaged',
    'life_event_sentence_marriage' => 'Got married',
    'life_event_sentence_anniversary' => 'Anniversary',
    'life_event_sentence_expecting_a_baby' => 'Expects a baby',
    'life_event_sentence_new_child' => 'Had a child',
    'life_event_sentence_new_family_member' => 'Added a family member',
    'life_event_sentence_new_pet' => 'Got a pet',
    'life_event_sentence_end_of_relationship' => 'Ended a relationship',
    'life_event_sentence_loss_of_a_loved_one' => 'Lost a loved one',
    'life_event_sentence_moved' => 'Moved',
    'life_event_sentence_bought_a_home' => 'Bought a home',
    'life_event_sentence_home_improvement' => 'Made a home improvement',
    'life_event_sentence_holidays' => 'Went on holidays',
    'life_event_sentence_new_vehicle' => 'Got a new vehicle',
    'life_event_sentence_new_roommate' => 'Got a roommate',
    'life_event_sentence_overcame_an_illness' => 'Overcame an illness',
    'life_event_sentence_quit_a_habit' => 'Quit a habit',
    'life_event_sentence_new_eating_habits' => 'Started new eating habits',
    'life_event_sentence_weight_loss' => 'Lost weight',
    'life_event_sentence_wear_glass_or_contact' => 'Started to wear glass or contact lenses',
    'life_event_sentence_broken_bone' => 'Broke a bone',
    'life_event_sentence_removed_braces' => 'Removed braces',
    'life_event_sentence_surgery' => 'Had surgery',
    'life_event_sentence_dentist' => 'Went to the dentist',
    'life_event_sentence_new_sport' => 'Started a sport',
    'life_event_sentence_new_hobby' => 'Started a hobby',
    'life_event_sentence_new_instrument' => 'Learned a new instrument',
    'life_event_sentence_new_language' => 'Learned a new language',
    'life_event_sentence_tattoo_or_piercing' => 'Got a tattoo or piercing',
    'life_event_sentence_new_license' => 'Got a license',
    'life_event_sentence_travel' => 'Traveled',
    'life_event_sentence_achievement_or_award' => 'Got an achievement or award',
    'life_event_sentence_changed_beliefs' => 'Changed beliefs',
    'life_event_sentence_first_word' => 'Spoke for the first time',
    'life_event_sentence_first_kiss' => 'Kissed for the first time',

    // documents
    'document_list_title' => 'Documents',
    'document_list_cta' => 'Upload document',
    'document_list_blank_desc' => 'Here you can store documents related to this person.',
    'document_upload_zone_cta' => 'Upload a file',
    'document_upload_zone_progress' => 'Uploading the document…',
    'document_upload_zone_error' => 'There was an error uploading the document. Please try again below.',

    // Photos
    'photo_title' => 'Photos',
    'photo_list_title' => 'Related photos',
    'photo_list_cta' => 'Upload photo',
    'photo_list_blank_desc' => 'You can store images about this contact. Upload one now!',
    'photo_upload_zone_cta' => 'Upload a photo',
    'photo_current_profile_pic' => 'Current profile picture',
    'photo_make_profile_pic' => 'Make profile picture',
    'photo_delete' => 'Delete photo',
    'photo_next' => 'Next photo ❯',
    'photo_previous' => '❮ Previous photo',

    // Avatars
    'avatar_change_title' => 'Change your avatar',
    'avatar_question' => 'Which avatar would you like to use?',
    'avatar_default_avatar' => 'The default avatar',
    'avatar_adorable_avatar' => 'The Adorable avatar',
    'avatar_gravatar' => 'The Gravatar associated with the email address of this person. <a href="https://gravatar.com/">Gravatar</a> is a global system that lets users associate email addresses with photos.',
    'avatar_current' => 'Keep the current avatar',
    'avatar_photo' => 'From a photo that you upload',
    'avatar_crop_new_avatar_photo' => 'Crop new avatar photo',

    // emotions
    'emotion_this_made_me_feel' => 'This made you feel…',

    // logs
    'auditlogs_link' => 'History',
    'auditlogs_title' => 'Everything that happened to :name',
    'auditlogs_breadcrumb' => 'History',
    'auditlogs_author' => 'By :name on :date',

    // contact field label
    'contact_field_label_home' => 'Home',
    'contact_field_label_work' => 'Work',
    'contact_field_label_cell' => 'Mobile',
    'contact_field_label_fax' => 'Fax',
    'contact_field_label_pager' => 'Pager',
    'contact_field_label_main' => 'Main',
    'contact_field_label_other' => 'Other',
    'contact_field_label_personal' => 'Personal',
];
