<?php
namespace Aws\Textract\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Textract** service.
 */
class TextractException extends AwsException {}
