<?php
namespace Aws\Organizations\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Organizations** service.
 */
class OrganizationsException extends AwsException {}
