<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'title' => 'تغيرات المنتج',
    'note' => 'ملاحظة: لسوء الحظ، هذه الصفحة تظهر فقط باللغة الإنكليزية.',
];
