<?php
namespace Aws\Greengrass\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Greengrass** service.
 */
class GreengrassException extends AwsException {}
