<?php
namespace Aws\Tnb\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Telco Network Builder** service.
 */
class TnbException extends AwsException {}
