<?php
namespace Aws\AppRunner\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS App Runner** service.
 */
class AppRunnerException extends AwsException {}
