<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  2612022 => 'Antananarivo',
  2612044 => 'Antsirabe',
  2612047 => 'Ambositra',
  2612053 => 'Toamasina',
  2612054 => 'Ambatondrazaka',
  2612056 => 'Moramanga',
  2612057 => 'Maroantsetra/Sainte Marie',
  2612062 => 'Mahajanga',
  2612067 => 'Antsohihy',
  2612069 => 'Maintirano',
  26120722 => 'Manakara',
  26120729 => 'Mananjary',
  2612073 => 'Farafangana',
  2612075 => 'Fianarantsoa',
  2612082 => 'Antsiranana',
  2612086 => 'Nosy Be',
  2612088 => 'Sambava',
  2612092 => 'Taolañaro',
  2612094 => 'Toliary',
  2612095 => 'Morondava',
);
