<?php
namespace Aws\CloudTrailData;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS CloudTrail Data Service** service.
 * @method \Aws\Result putAuditEvents(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putAuditEventsAsync(array $args = [])
 */
class CloudTrailDataClient extends AwsClient {}
