<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reset Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'reset' => 'Sua senha foi redefinida!',
    'sent' => 'Enviamos um link para redefinir a sua senha por e-mail.',
    'token' => 'Esse código de redefinição de senha é inválido.',
    'user' => 'Não conseguimos encontrar nenhum usuário com o endereço de e-mail informado.',
    'changed' => 'Senha alterada com sucesso.',
    'invalid' => 'A senha que introduziu não está correta.',
    'throttled' => 'Por favor espere antes de tentar novamente.',

];
