<?php
namespace Aws\Transfer\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Transfer for SFTP** service.
 */
class TransferException extends AwsException {}
