<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'כן',
    'no' => 'לא',
    'update' => 'עדכון',
    'save' => 'שמירה',
    'add' => 'הוספה',
    'cancel' => 'ביטול',
    'confirm' => 'אישור',
    'delete_confirm' => 'להמשיך?',
    'delete' => 'מחיקה',
    'edit' => 'עריכה',
    'upload' => 'העלאה',
    'download' => 'הורדה',
    'save_close' => 'שמירה וסגירה',
    'close' => 'סגירה',
    'copy' => 'העתקה',
    'create' => 'יצירה',
    'remove' => 'הסרה',
    'revoke' => 'שלילה',
    'done' => 'סיום',
    'back' => 'חזרה',
    'verify' => 'אימות',
    'new' => 'חדש/ה',
    'unknown' => 'לא ידוע לי',
    'load_more' => 'לטעון עוד',
    'loading' => 'בטעינה…',
    'with' => 'עם',
    'today' => 'היום',
    'yesterday' => 'אתמול',
    'another_day' => 'יום אחר',
    'date' => 'תאריך',
    'type' => 'סוג',
    'zoom' => 'תקריב',
    'upgrade' => 'יש לשדרג כדי לשחרר',
    'percent_uploaded' => '{percent}% נשלחו',
    'retry' => 'לנסות שוב',
    'filter' => 'סינון הרשימה',
    'go_back' => 'חזרה',
    'file_selected' => 'נבחר קובץ אחד…|{count} קבצים נבחרו…',

    'application_title' => 'מוניקה - ניהול יחסים בינאישיים',
    'application_description' => 'מוניקה היא כלי לניהול הקשרים החברתיים שלך עם אהוביך, חבריך ומשפחתך.',
    'application_og_title' => 'חיזוק הקשר עם אהוביך. מערכת ניהול קשרים עם חברים ומשפחה, מקוונת ובחינם.',

    'markdown_description' => 'רוצה להוסיף קצת עניין לטקסט שלך? במערכת זו קיימת תמיכה ב־Markdown כדי להוסיף הדגשה, הטיה, רשימות ועוד.',
    'markdown_link' => 'קריאת התיעוד',

    'header_settings_link' => 'הגדרות',
    'header_logout_link' => 'יציאה',
    'header_changelog_link' => 'שינויים במוצר',

    'main_nav_cta' => 'הוספת אנשים',
    'main_nav_dashboard' => 'לוח מחוונים',
    'main_nav_family' => 'אנשי קשר',
    'main_nav_journal' => 'יומן',
    'main_nav_activities' => 'פעילויות',
    'main_nav_tasks' => 'משימות',

    'footer_remarks' => 'הערות?',
    'footer_send_email' => 'ניתן לשלוח לנו דוא״ל',
    'footer_privacy' => 'מדיניות פרטיות',
    'footer_release' => 'הערות הוצאה לאור',
    'footer_newsletter' => 'רשימת דיוור',
    'footer_source_code' => 'תרומה',
    'footer_version' => 'גרסה: :version',
    'footer_new_version' => 'גרסה חדשה של מוניקה זמינה',

    'footer_modal_version_whats_new' => 'מה חדש',
    'footer_modal_version_release_away' => 'גרסה זו יצאה לאור גרסה אחת לפני הגרסה העדכנית הנוכחית. עליך לעדכן את העותק שלך.|גרסה זו יצאה לאור :number גרסאות לפני הגרסה העדכנית הנוכחית. עליך לעדכן את העותק שלך.',

    'breadcrumb_dashboard' => 'לוח מחוונים',
    'breadcrumb_list_contacts' => 'רשימת אנשים',
    'breadcrumb_archived_contacts' => 'אנשי קשר בארכיון',
    'breadcrumb_journal' => 'יומן',
    'breadcrumb_settings' => 'הגדרות',
    'breadcrumb_settings_export' => 'יצוא',
    'breadcrumb_settings_users' => 'משתמשים',
    'breadcrumb_settings_users_add' => 'הוספת משתמש',
    'breadcrumb_settings_subscriptions' => 'הרשמה',
    'breadcrumb_settings_import' => 'יבוא',
    'breadcrumb_settings_import_report' => 'דוח יבוא',
    'breadcrumb_settings_import_upload' => 'העלאה',
    'breadcrumb_settings_tags' => 'תגיות',
    'breadcrumb_add_significant_other' => 'הוספת קשר זוגי',
    'breadcrumb_edit_significant_other' => 'עריכת קשר זוגי',
    'breadcrumb_add_note' => 'הוספת הערה',
    'breadcrumb_edit_note' => 'עריכת הערה',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'משאבי DAV',
    'breadcrumb_edit_introductions' => 'איך הכרתם',
    'breadcrumb_settings_personalization' => 'התאמה אישית',
    'breadcrumb_settings_security' => 'אבטחה',
    'breadcrumb_settings_security_2fa' => 'אימות דו־שלבי',
    'breadcrumb_profile' => 'הפרופיל של :name',

    'gender_male' => 'גבר',
    'gender_female' => 'אישה',
    'gender_none' => 'שמור במערכת',
    'gender_no_gender' => 'אין מגדר',

    'error_title' => 'אופס! משהו השתבש.',
    'error_unauthorized' => 'אין לך את ההרשאה לערוך את המשאב הזה.',
    'error_user_account' => 'משתמש זה אינו שייך לחשבון שצוין.',
    'error_save' => 'אירעה שגיאה בעת שמירת הנתונים.',
    'error_try_again' => 'משהו השתבש. נא לנסות שוב.',
    'error_id' => 'מזהה שגיאה: :id',
    'error_unavailable' => 'השירות אינו זמין',
    'error_maintenance' => 'מתבצעות עבודות תחזוקה. תכף נשוב.',
    'error_help' => 'מיד נשוב.',
    'error_twitter' => 'ניתן לעקוב אחר <a href="https://twitter.com/:twitter">חשבון הטוויטר שלנו</a> כדי להתעדכן אם השירות שב לפעילות.',
    'error_no_term' => 'עדיין אין מדיניות עבור העותק הזה.',

    'default_save_success' => 'הנתונים נשמרו.',

    'compliance_title' => 'סליחה על ההפרעה.',
    'compliance_desc' => 'ערכנו את <a href=":urlterm" hreflang=":hreflang">תנאי השימוש</a> ואת <a href=":url" hreflang=":hreflang">מדיניות הפרטיות</a> שלנו. מכוח החוק עלינו לבקש ממך לעיין בשינויים ולאשר את הסכמתך להם כדי להמשיך לאפשר לך להשתמש בחשבונך.',
    'compliance_desc_end' => 'אנו לא משתמשים בנתונים או בחשבון שלך לאף מטרה זדונית וגם לא נעשה זאת בעתיד.',
    'compliance_terms' => 'קבלת התנאים ומדיניות הפרטיות החדשים',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'קשרים רומנטיים',
    'relationship_type_group_family' => 'קשרים משפחתיים',
    'relationship_type_group_friend' => 'קשרים חברתיים',
    'relationship_type_group_work' => 'קשרי עבודה',
    'relationship_type_group_other' => 'סוגי קשר אחרים',

    'relationship_type_partner' => 'בן זוג',
    'relationship_type_partner_female' => 'בת זוג',
    'relationship_type_partner_male' => 'בזוגיות עם',
    'relationship_type_partner_with_name' => 'בן הזוג של :name',
    'relationship_type_partner_female_with_name' => 'בת הזוג של :name',
    'relationship_type_partner_male_with_name' => 'הזוגיות של :name',

    'relationship_type_spouse' => 'בעל',
    'relationship_type_spouse_female' => 'אישה',
    'relationship_type_spouse_male' => 'בעל',
    'relationship_type_spouse_with_name' => 'בעלה של :name',
    'relationship_type_spouse_female_with_name' => 'אשתו של :name',
    'relationship_type_spouse_male_with_name' => 'בעלה של :name',

    'relationship_type_date' => 'ליציאה',
    'relationship_type_date_female' => 'יוצאת קבוע',
    'relationship_type_date_male' => 'דייט',
    'relationship_type_date_with_name' => 'יוצא קבוע עם :name',
    'relationship_type_date_female_with_name' => 'יוצאת קבוע עם :name',
    'relationship_type_date_male_with_name' => 'הדייט של :name',

    'relationship_type_lover' => 'מאהב',
    'relationship_type_lover_female' => 'מאהבת',
    'relationship_type_lover_male' => 'מאהב',
    'relationship_type_lover_with_name' => 'מאהב של :name',
    'relationship_type_lover_female_with_name' => 'מאהבת של :name',
    'relationship_type_lover_male_with_name' => 'המאהב של :name',

    'relationship_type_inlovewith' => 'מאוהב',
    'relationship_type_inlovewith_female' => 'מאוהבת',
    'relationship_type_inlovewith_male' => 'מאוהב',
    'relationship_type_inlovewith_with_name' => 'מושא אהבתו של :name',
    'relationship_type_inlovewith_female_with_name' => 'מושא אהבתה של :name',
    'relationship_type_inlovewith_male_with_name' => 'מישהו ש־:name מאוהבת בו',

    'relationship_type_lovedby' => 'נאהב על ידי',
    'relationship_type_lovedby_female' => 'נאהבת על ידי',
    'relationship_type_lovedby_male' => 'נאהב על ידי',
    'relationship_type_lovedby_with_name' => 'מאהב סודי של :name',
    'relationship_type_lovedby_female_with_name' => 'מאהבת סודית של :name',
    'relationship_type_lovedby_male_with_name' => 'מאהב סודי של :name',

    'relationship_type_ex' => 'שותף לשעבר לחיים',
    'relationship_type_ex_female' => 'חברה לשעבר',
    'relationship_type_ex_male' => 'חבר לשעבר',
    'relationship_type_ex_with_name' => 'שותף לחיים לשעבר של :name',
    'relationship_type_ex_female_with_name' => 'חברה לשעבר של :name',
    'relationship_type_ex_male_with_name' => 'חבר לשעבר של :name',

    'relationship_type_parent' => 'הורה',
    'relationship_type_parent_female' => 'אימא',
    'relationship_type_parent_male' => 'אבא',
    'relationship_type_parent_with_name' => 'הורה של :name',
    'relationship_type_parent_female_with_name' => 'אימא של :name',
    'relationship_type_parent_male_with_name' => 'אבא של :name',

    'relationship_type_child' => 'ילד',
    'relationship_type_child_female' => 'בת',
    'relationship_type_child_male' => 'בן',
    'relationship_type_child_with_name' => 'הילד של :name',
    'relationship_type_child_female_with_name' => 'בת של :name',
    'relationship_type_child_male_with_name' => 'בן של :name',

    'relationship_type_stepparent' => 'הורה חורג',
    'relationship_type_stepparent_female' => 'אם חורגת',
    'relationship_type_stepparent_male' => 'אב חורג',
    'relationship_type_stepparent_with_name' => 'הורה חורג של :name',
    'relationship_type_stepparent_female_with_name' => 'אם חורגת של :name',
    'relationship_type_stepparent_male_with_name' => 'אב חורג של :name',

    'relationship_type_stepchild' => 'ילד חורג',
    'relationship_type_stepchild_female' => 'בת חורגת',
    'relationship_type_stepchild_male' => 'בן חורג',
    'relationship_type_stepchild_with_name' => 'הילד החורג של :name',
    'relationship_type_stepchild_female_with_name' => 'בת חורגת של :name',
    'relationship_type_stepchild_male_with_name' => 'בן חורג של :name',

    'relationship_type_sibling' => 'אחאי',
    'relationship_type_sibling_female' => 'אחות',
    'relationship_type_sibling_male' => 'אח',
    'relationship_type_sibling_with_name' => 'אחאי של :name',
    'relationship_type_sibling_female_with_name' => 'אחות של :name',
    'relationship_type_sibling_male_with_name' => 'אח של :name',

    'relationship_type_grandparent' => 'סב',
    'relationship_type_grandparent_female' => 'סבתא',
    'relationship_type_grandparent_male' => 'סבא',
    'relationship_type_grandparent_with_name' => 'הסבא או הסבתא של :name',
    'relationship_type_grandparent_female_with_name' => 'סבתא של :name',
    'relationship_type_grandparent_male_with_name' => 'סבא של :name',

    'relationship_type_grandchild' => 'נכד/ה',
    'relationship_type_grandchild_female' => 'נכדה',
    'relationship_type_grandchild_male' => 'נכד',
    'relationship_type_grandchild_with_name' => 'הנכד או הנכדה של :name',
    'relationship_type_grandchild_female_with_name' => 'נכדה של :name',
    'relationship_type_grandchild_male_with_name' => 'נכד של :name',

    'relationship_type_uncle' => 'דוד',
    'relationship_type_uncle_female' => 'דודה',
    'relationship_type_uncle_male' => 'דוד',
    'relationship_type_uncle_with_name' => 'דוד של :name',
    'relationship_type_uncle_female_with_name' => 'דודה של :name',
    'relationship_type_uncle_male_with_name' => 'דוד של :name',

    'relationship_type_nephew' => 'אחיין',
    'relationship_type_nephew_female' => 'אחיינית',
    'relationship_type_nephew_male' => 'אחיין',
    'relationship_type_nephew_with_name' => 'אחיין של :name',
    'relationship_type_nephew_female_with_name' => 'אחיינית של :name',
    'relationship_type_nephew_male_with_name' => 'אחיין של :name',

    'relationship_type_cousin' => 'בן דוד',
    'relationship_type_cousin_female' => 'בת דודה',
    'relationship_type_cousin_male' => 'בן דוד',
    'relationship_type_cousin_with_name' => 'בן דוד של :name',
    'relationship_type_cousin_female_with_name' => 'בת דודה של :name',
    'relationship_type_cousin_male_with_name' => 'בן דוד של :name',

    'relationship_type_godfather' => 'אפוטרופוס',
    'relationship_type_godfather_female' => 'סנדקית',
    'relationship_type_godfather_male' => 'סנדק',
    'relationship_type_godfather_with_name' => 'האפוטרופוס/ית של :name',
    'relationship_type_godfather_female_with_name' => 'הסנדקית של :name',
    'relationship_type_godfather_male_with_name' => 'הסנדק של :name',

    'relationship_type_godson' => 'godchild',
    'relationship_type_godson_female' => 'בת סנדקות',
    'relationship_type_godson_male' => 'בן סנדקות',
    'relationship_type_godson_with_name' => ':name’s godchild',
    'relationship_type_godson_female_with_name' => 'בת הסנדקות של :name',
    'relationship_type_godson_male_with_name' => 'בן הסנדקות של :name',

    'relationship_type_friend' => 'חבר',
    'relationship_type_friend_female' => 'חברה',
    'relationship_type_friend_male' => 'חבר',
    'relationship_type_friend_with_name' => 'חבר של :name',
    'relationship_type_friend_female_with_name' => 'חברה של :name',
    'relationship_type_friend_male_with_name' => 'חבר של :name',

    'relationship_type_bestfriend' => 'החבר הטוב ביותר',
    'relationship_type_bestfriend_female' => 'החברה הטובה ביותר',
    'relationship_type_bestfriend_male' => 'החבר הטוב ביותר',
    'relationship_type_bestfriend_with_name' => 'החבר הכי טוב של :name',
    'relationship_type_bestfriend_female_with_name' => 'החברה הכי טובה של :name',
    'relationship_type_bestfriend_male_with_name' => 'החבר הכי טוב של :name',

    'relationship_type_colleague' => 'עמית לעבודה',
    'relationship_type_colleague_female' => 'עמיתה לעבודה',
    'relationship_type_colleague_male' => 'עמית לעבודה',
    'relationship_type_colleague_with_name' => 'עמית לעבודה של :name',
    'relationship_type_colleague_female_with_name' => 'עמיתה לעבודה של :name',
    'relationship_type_colleague_male_with_name' => 'עמית לעבודה של :name',

    'relationship_type_boss' => 'מנהל',
    'relationship_type_boss_female' => 'מנהלת',
    'relationship_type_boss_male' => 'מנהל',
    'relationship_type_boss_with_name' => 'מנהל של :name',
    'relationship_type_boss_female_with_name' => 'מנהלת של :name',
    'relationship_type_boss_male_with_name' => 'מנהל של :name',

    'relationship_type_subordinate' => 'כפוף',
    'relationship_type_subordinate_female' => 'כפופה',
    'relationship_type_subordinate_male' => 'כפוף',
    'relationship_type_subordinate_with_name' => 'כפוף ל:name',
    'relationship_type_subordinate_female_with_name' => 'כפופה ל:name',
    'relationship_type_subordinate_male_with_name' => 'כפוף ל:name',

    'relationship_type_mentor' => 'חונך',
    'relationship_type_mentor_female' => 'חונכת',
    'relationship_type_mentor_male' => 'חונך',
    'relationship_type_mentor_with_name' => 'חונך של :name',
    'relationship_type_mentor_female_with_name' => 'חונך של :name',
    'relationship_type_mentor_male_with_name' => 'חונך של :name',

    'relationship_type_protege' => 'protégé',
    'relationship_type_protege_female' => 'חניכה',
    'relationship_type_protege_male' => 'protégé',
    'relationship_type_protege_with_name' => ':name’s protégé',
    'relationship_type_protege_female_with_name' => 'חניכה של :name',
    'relationship_type_protege_male_with_name' => ':name’s protégé',

    'relationship_type_ex_husband' => 'ex-spouse',
    'relationship_type_ex_husband_female' => 'גרושה',
    'relationship_type_ex_husband_male' => 'גרוש',
    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
    'relationship_type_ex_husband_female_with_name' => 'הגרושה של :name',
    'relationship_type_ex_husband_male_with_name' => 'הגרוש של :name',

    // emotions
    'emotion_primary_love' => 'אהבה',
    'emotion_primary_joy' => 'שמחה',
    'emotion_primary_surprise' => 'הפתעה',
    'emotion_primary_anger' => 'כעס',
    'emotion_primary_sadness' => 'עצב',
    'emotion_primary_fear' => 'פחד',

    'emotion_secondary_affection' => 'אהדה',
    'emotion_secondary_lust' => 'תשוקה',
    'emotion_secondary_longing' => 'געגועים',
    'emotion_secondary_cheerfulness' => 'עליזות',
    'emotion_secondary_zest' => 'להט',
    'emotion_secondary_contentment' => 'סיפוק',
    'emotion_secondary_pride' => 'גאווה',
    'emotion_secondary_optimism' => 'אופטימיות',
    'emotion_secondary_enthrallment' => 'קסם',
    'emotion_secondary_relief' => 'רגיעה',
    'emotion_secondary_surprise' => 'הפתעה',
    'emotion_secondary_irritation' => 'קנטרנות',
    'emotion_secondary_exasperation' => 'מרמור',
    'emotion_secondary_rage' => 'זעם',
    'emotion_secondary_disgust' => 'גועל',
    'emotion_secondary_envy' => 'קנאה',
    'emotion_secondary_suffering' => 'סבל',
    'emotion_secondary_sadness' => 'עצב',
    'emotion_secondary_disappointment' => 'אכזבה',
    'emotion_secondary_shame' => 'בושה',
    'emotion_secondary_neglect' => 'הזנחה',
    'emotion_secondary_sympathy' => 'אהדה',
    'emotion_secondary_horror' => 'אימה',
    'emotion_secondary_nervousness' => 'עצבנות',

    'emotion_adoration' => 'הערצה',
    'emotion_affection' => 'אהדה',
    'emotion_love' => 'אהבה',
    'emotion_fondness' => 'חיבה',
    'emotion_liking' => 'התחבבות',
    'emotion_attraction' => 'משיכה',
    'emotion_caring' => 'אכפתיות',
    'emotion_tenderness' => 'רוך',
    'emotion_compassion' => 'חמלה',
    'emotion_sentimentality' => 'רגשנות',
    'emotion_arousal' => 'גירוי',
    'emotion_desire' => 'שקיקה',
    'emotion_lust' => 'תאווה',
    'emotion_passion' => 'חשקנות',
    'emotion_infatuation' => 'אהבה עיוורת',
    'emotion_longing' => 'געגועים',
    'emotion_amusement' => 'שעשוע',
    'emotion_bliss' => 'אושר עילאי',
    'emotion_cheerfulness' => 'עליזות',
    'emotion_gaiety' => 'עליצות',
    'emotion_glee' => 'צהלה',
    'emotion_jolliness' => 'דיצה',
    'emotion_joviality' => 'גילה',
    'emotion_joy' => 'שמחה',
    'emotion_delight' => 'עונג',
    'emotion_enjoyment' => 'שעשוע',
    'emotion_gladness' => 'רינה',
    'emotion_happiness' => 'אושר',
    'emotion_jubilation' => 'ששון',
    'emotion_elation' => 'התעלות',
    'emotion_satisfaction' => 'סיפוק',
    'emotion_ecstasy' => 'אקסטזה',
    'emotion_euphoria' => 'זחיחות',
    'emotion_enthusiasm' => 'התלהבות',
    'emotion_zeal' => 'מתלהב',
    'emotion_zest' => 'להט',
    'emotion_excitement' => 'התרגשות',
    'emotion_thrill' => 'מתרגש',
    'emotion_exhilaration' => 'הרננה',
    'emotion_contentment' => 'שביעות רצון',
    'emotion_pleasure' => 'הנאה',
    'emotion_pride' => 'גאווה',
    'emotion_eagerness' => 'מתלהב',
    'emotion_hope' => 'תקווה',
    'emotion_optimism' => 'אופטימיות',
    'emotion_enthrallment' => 'ריגוש',
    'emotion_rapture' => 'התלהבות',
    'emotion_relief' => 'רגיעה',
    'emotion_amazement' => 'פליאה',
    'emotion_surprise' => 'הפתעה',
    'emotion_astonishment' => 'תדהמה',
    'emotion_aggravation' => 'עגמת נפש',
    'emotion_irritation' => 'הרגזה',
    'emotion_agitation' => 'סערת נפש',
    'emotion_annoyance' => 'מטרד',
    'emotion_grouchiness' => 'נרגנות',
    'emotion_grumpiness' => 'רגזנות',
    'emotion_exasperation' => 'מרמור',
    'emotion_frustration' => 'תסכול',
    'emotion_anger' => 'כעס',
    'emotion_rage' => 'זעם',
    'emotion_outrage' => 'עלבון חמור',
    'emotion_fury' => 'זעף',
    'emotion_wrath' => 'חרון',
    'emotion_hostility' => 'עוינות',
    'emotion_ferocity' => 'אכזריות',
    'emotion_bitterness' => 'מרירות',
    'emotion_hate' => 'שנאה',
    'emotion_loathing' => 'תיעוב',
    'emotion_scorn' => 'בוז',
    'emotion_spite' => 'הקנטה',
    'emotion_vengefulness' => 'נקמה',
    'emotion_dislike' => 'סלידה',
    'emotion_resentment' => 'טינה',
    'emotion_disgust' => 'גועל',
    'emotion_revulsion' => 'בחילה',
    'emotion_contempt' => 'בוז',
    'emotion_envy' => 'קנאה',
    'emotion_jealousy' => 'קנאה',
    'emotion_agony' => 'ייסורים',
    'emotion_suffering' => 'סבל',
    'emotion_hurt' => 'פגיעה',
    'emotion_anguish' => 'חלחלה',
    'emotion_depression' => 'דיכאון',
    'emotion_despair' => 'ייאוש',
    'emotion_hopelessness' => 'חוסר תקווה',
    'emotion_gloom' => 'יגון',
    'emotion_glumness' => 'דכדוך',
    'emotion_sadness' => 'עצב',
    'emotion_unhappiness' => 'העדר שמחה',
    'emotion_grief' => 'תוגה',
    'emotion_sorrow' => 'צער',
    'emotion_woe' => 'צער עמוק',
    'emotion_misery' => 'אומללות',
    'emotion_melancholy' => 'דכאון',
    'emotion_dismay' => 'רפיון ידיים',
    'emotion_disappointment' => 'אכזבה',
    'emotion_displeasure' => 'אי שביעות רצון',
    'emotion_guilt' => 'אשמה',
    'emotion_shame' => 'בושה',
    'emotion_regret' => 'חרטה',
    'emotion_remorse' => 'נקיפת לב',
    'emotion_alienation' => 'ניכור',
    'emotion_isolation' => 'בידוד',
    'emotion_neglect' => 'הזנחה',
    'emotion_loneliness' => 'בדידות',
    'emotion_rejection' => 'דחייה',
    'emotion_homesickness' => 'געגועים הביתה',
    'emotion_defeat' => 'תבוסה',
    'emotion_dejection' => 'עצבות',
    'emotion_insecurity' => 'חוסר ביטחון',
    'emotion_embarrassment' => 'מבוכה',
    'emotion_humiliation' => 'השפלה',
    'emotion_insult' => 'עלבון',
    'emotion_pity' => 'רחמים',
    'emotion_sympathy' => 'אהדה',
    'emotion_alarm' => 'דריכות',
    'emotion_shock' => 'הלם',
    'emotion_fear' => 'פחד',
    'emotion_fright' => 'בעתה',
    'emotion_horror' => 'אימה',
    'emotion_terror' => 'טרור',
    'emotion_panic' => 'פאניקה',
    'emotion_hysteria' => 'היסטריה',
    'emotion_mortification' => 'המתה',
    'emotion_anxiety' => 'חרדה',
    'emotion_nervousness' => 'עצבנות',
    'emotion_tenseness' => 'מתיחות',
    'emotion_uneasiness' => 'חוסר נוחות',
    'emotion_apprehension' => 'חשש',
    'emotion_worry' => 'דאגה',
    'emotion_distress' => 'מצוקה',
    'emotion_dread' => 'מורא',

    // weather
    'weather_sunny' => 'שמשי',
    'weather_clear' => 'בהיר',
    'weather_clear-day' => 'בהיר',
    'weather_clear-night' => 'לילה בהיר',
    'weather_light-drizzle' => 'טפטוף קל',
    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
    'weather_patchy-light-rain' => 'Patchy light rain',
    'weather_light-rain' => 'גשם קל',
    'weather_moderate-rain-at-times' => 'Moderate rain at times',
    'weather_moderate-rain' => 'Moderate rain',
    'weather_patchy-rain-possible' => 'Patchy rain possible',
    'weather_heavy-rain-at-times' => 'גשם כבד במקטעים',
    'weather_heavy-rain' => 'גשם כבד',
    'weather_light-freezing-rain' => 'Light freezing rain',
    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
    'weather_light-sleet' => 'Light sleet',
    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
    'weather_light-rain-shower' => 'Light rain shower',
    'weather_torrential-rain-shower' => 'Torrential rain shower',
    'weather_rain' => 'גשם',
    'weather_snow' => 'שלג',
    'weather_blowing-snow' => 'משבי שלג',
    'weather_patchy-light-snow' => 'Patchy light snow',
    'weather_light-snow' => 'שלג קל',
    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
    'weather_moderate-snow' => 'שלג מתון',
    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
    'weather_heavy-snow' => 'שלג כבד',
    'weather_light-snow-showers' => 'ממטרי שלג קלים',
    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
    'weather_patchy-snow-possible' => 'Patchy snow possible',
    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
    'weather_light-sleet-showers' => 'Light sleet showers',
    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
    'weather_sleet' => 'גשם שלג',
    'weather_wind' => 'רוח',
    'weather_fog' => 'ערפל',
    'weather_freezing-fog' => 'Freezing fog',
    'weather_mist' => 'ערפל',
    'weather_blizzard' => 'סופת שלג',
    'weather_overcast' => 'קודר',
    'weather_cloudy' => 'מעונן',
    'weather_partly-cloudy-day' => 'מעונן חלקית',
    'weather_partly-cloudy-night' => 'מעונן חלקית',
    'weather_freezing-drizzle' => 'טפטוף קפוא',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Ice pellets',
    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'מזג אוויר נוכחי',

    // dav
    'dav_contacts' => 'אנשי קשר',
    'dav_contacts_description' => 'אנשי הקשר של :name',
    'dav_birthdays' => 'ימי הולדת',
    'dav_birthdays_description' => 'ימי ההולדת של אנשי הקשר של :name',
    'dav_tasks' => 'משימות',
    'dav_tasks_description' => 'המשימות של :name',

    // contact list
    'contact_list_avatar' => 'תמונה ייצוגית',
    'contact_list_name' => 'איש קשר',
    'contact_list_description' => 'תיאור',

];
