<?php
namespace Aws\CloudFormation\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the AWS CloudFormation service.
 */
class CloudFormationException extends AwsException {}
