<?php
namespace Aws\GuardDuty\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon GuardDuty** service.
 */
class GuardDutyException extends AwsException {}
