<?php
// This file was auto-generated from sdk-root/src/data/resourcegroupstaggingapi/2017-01-26/paginators-1.json
return [ 'pagination' => [ 'GetComplianceSummary' => [ 'input_token' => 'PaginationToken', 'limit_key' => 'MaxResults', 'output_token' => 'PaginationToken', 'result_key' => 'SummaryList', ], 'GetResources' => [ 'input_token' => 'PaginationToken', 'limit_key' => 'ResourcesPerPage', 'output_token' => 'PaginationToken', 'result_key' => 'ResourceTagMappingList', ], 'GetTagKeys' => [ 'input_token' => 'PaginationToken', 'output_token' => 'PaginationToken', 'result_key' => 'TagKeys', ], 'GetTagValues' => [ 'input_token' => 'PaginationToken', 'output_token' => 'PaginationToken', 'result_key' => 'TagValues', ], ],];
