<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  8862 => '臺北',
  8863 => '桃園、新竹、花蓮、宜蘭',
  88637 => '苗栗',
  88642 => '臺中、彰化',
  88643 => '臺中、彰化',
  88647 => '臺中、彰化',
  88648 => '臺中、彰化',
  88649 => '南投',
  8865 => '嘉義、雲林',
  8866 => '臺南、澎湖',
  8867 => '高雄',
  88680 => '屏東',
  886823 => '金門',
  886826 => '烏坵',
  88683 => '馬祖',
  88687 => '屏東',
  88688 => '屏東',
  88689 => '臺東',
);
