<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AE' => 'Ɛmirate ti Awɔn Arabu',
  'AS' => 'Sámóánì ti Orílɛ́ède Àméríkà',
  'AX' => 'Àwɔn Erékùsù ti Åland',
  'AZ' => 'Asɛ́bájánì',
  'BA' => 'Bɔ̀síníà àti Ɛtisɛgófínà',
  'BE' => 'Bégíɔ́mù',
  'BJ' => 'Bɛ̀nɛ̀',
  'BL' => 'Ìlú Bátílɛ́mì',
  'BN' => 'Búrúnɛ́lì',
  'BO' => 'Bɔ̀lífíyà',
  'BQ' => 'Kàríbíánì ti Nɛ́dálándì',
  'BW' => 'Bɔ̀tìsúwánà',
  'BZ' => 'Bèlísɛ̀',
  'CH' => 'switishilandi',
  'CL' => 'Shílè',
  'CN' => 'Sháínà',
  'CZ' => 'Shɛ́ɛ́kì',
  'DG' => 'Diego Gashia',
  'DJ' => 'Díbɔ́ótì',
  'DK' => 'Dɛ́mákì',
  'EH' => 'Ìwɔ̀òòrùn Sàhárà',
  'FO' => 'Àwɔn Erékùsù ti Faroe',
  'GB' => 'Gɛ̀ɛ́sì',
  'GE' => 'Gɔgia',
  'GF' => 'Firenshi Guana',
  'GS' => 'Gúúsù Georgia àti Gúúsù Àwɔn Erékùsù Sandwich',
  'HK' => 'Agbègbè Ìshàkóso Ìshúná Hong Kong Tí Shánà Ń Darí',
  'IC' => 'Ɛrékùsù Kánárì',
  'IL' => 'Iserɛli',
  'IS' => 'Ashilandi',
  'JO' => 'Jɔdani',
  'KG' => 'Kurishisitani',
  'KP' => 'Guusu Kɔria',
  'KR' => 'Ariwa Kɔria',
  'KZ' => 'Kashashatani',
  'LC' => 'Lushia',
  'LI' => 'Lɛshitɛnisiteni',
  'MH' => 'Etikun Máshali',
  'MO' => 'Agbègbè Ìshàkóso Pàtàkì Macao',
  'MZ' => 'Moshamibiku',
  'NF' => 'Etikun Nɔ́úfókì',
  'NO' => 'Nɔɔwii',
  'NZ' => 'Shilandi Titun',
  'OM' => 'Ɔɔma',
  'PF' => 'Firenshi Polinesia',
  'PM' => 'Pɛɛri ati mikuloni',
  'PR' => 'Pɔto Riko',
  'PS' => 'Agbègbè ara Palɛsítínì',
  'PT' => 'Pɔ́túgà',
  'RS' => 'Sɛ́bíà',
  'RU' => 'Rɔshia',
  'SC' => 'Sheshɛlɛsi',
  'SH' => 'Hɛlena',
  'SJ' => 'Sífábáàdì àti Jánì Máyɛ̀nì',
  'SN' => 'Sɛnɛga',
  'ST' => 'Sao tomi ati piriishipi',
  'SV' => 'Ɛɛsáfádò',
  'SX' => 'Síntì Mátɛ́ɛ̀nì',
  'SZ' => 'Sashiland',
  'TC' => 'Tɔɔki ati Etikun Kakɔsi',
  'TD' => 'Shààdì',
  'TF' => 'Agbègbè Gúúsù Faranshé',
  'TL' => 'ÌlàOòrùn Tímɔ̀',
  'TM' => 'Tɔɔkimenisita',
  'TN' => 'Tunishia',
  'TR' => 'Tɔɔki',
  'UM' => 'Àwɔn Erékùsù Kékèké Agbègbè US',
  'US' => 'Amɛrikà',
  'UZ' => 'Nshibɛkisitani',
  'VC' => 'Fisɛnnti ati Genadina',
  'VE' => 'Fɛnɛshuɛla',
  'VI' => 'Etikun Fagini ti Amɛrika',
  'VN' => 'Fɛtinami',
  'WS' => 'Samɔ',
  'ZA' => 'Gúúshù Áfíríkà',
  'ZM' => 'Shamibia',
  'ZW' => 'Shimibabe',
);
