<?php
namespace Aws\VPCLattice\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon VPC Lattice** service.
 */
class VPCLatticeException extends AwsException {}
