<?php

/**
 * ⚠️ Edition not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'user_unauthenticated' => 'Vous devez vous connecter avant de faire une authentification Webauthn',
    'auth_data_not_found' => 'Données d’authentification introuvables',
    'create_data_not_found' => 'Données d’enregistrement non trouvées',
    'object_not_found' => 'Objet introuvable',

];
