<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  38730 => 'Средњoбосански кантон',
  38731 => 'Посавски кантон',
  38732 => 'Зеничко-добојски кантон',
  38733 => 'Сарајевски кантон',
  38734 => 'Кантон 10',
  38735 => 'Тузлански кантон',
  38737 => 'Унско-сански кантон',
  38738 => 'Босанско-подрињски кантон Горажде',
  3874 => 'Брчко Дистрикт',
  38750 => 'Мркоњић Град',
  38751 => 'Бања Лука',
  38752 => 'Приједор',
  38753 => 'Добој',
  38754 => 'Шамац',
  38755 => 'Бијељина',
  38756 => 'Зворник',
  38757 => 'Источно Сарајево',
  38758 => 'Фоча',
  38759 => 'Требиње',
);
