<?php
namespace Aws\Honeycode\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Honeycode** service.
 */
class HoneycodeException extends AwsException {}
