<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AD' => 'Andóra',
  'AE' => 'Ʉtemi wa Kɨaráabu',
  'AF' => 'Afuganisitáani',
  'AG' => 'Antigúua na Baribúuda',
  'AI' => 'Anguíila',
  'AL' => 'Alubánia',
  'AM' => 'Ariménia',
  'AO' => 'Angóola',
  'AR' => 'Ajentíina',
  'AS' => 'Samóoa ya Amerɨ́ka',
  'AT' => 'Áusitiria',
  'AU' => 'Ausiteréelia',
  'AW' => 'Arúuba',
  'AZ' => 'Azabajáani',
  'BA' => 'Bósinia',
  'BB' => 'Babadóosi',
  'BD' => 'Bangaladéeshi',
  'BE' => 'Ʉbeligíiji',
  'BF' => 'Bukinafáaso',
  'BG' => 'Buligaría',
  'BH' => 'Baharéeni',
  'BI' => 'Burúundi',
  'BJ' => 'Beníini',
  'BM' => 'Berimúuda',
  'BN' => 'Burunéei',
  'BO' => 'Bolívia',
  'BR' => 'Brasíili',
  'BS' => 'Baháama',
  'BT' => 'Butáani',
  'BW' => 'Botiswáana',
  'BY' => 'Belarúusi',
  'BZ' => 'Belíise',
  'CA' => 'Kánada',
  'CD' => 'Jamuhúuri ya Kɨdemokurasía ya Kóongo',
  'CF' => 'Juhúuri ya Afɨrɨka ya katɨ katɨ',
  'CG' => 'Kóongo',
  'CH' => 'Uswíisi',
  'CI' => 'Ivori Kositi',
  'CK' => 'Visíiwa vya Kúuku',
  'CL' => 'Chíile',
  'CM' => 'Kamerúuni',
  'CN' => 'Chíina',
  'CO' => 'Kolómbia',
  'CR' => 'Kósita Rɨ́ɨka',
  'CU' => 'Kyúuba',
  'CV' => 'Kepuvéede',
  'CY' => 'Kupuróosi',
  'CZ' => 'Jamuhúuri ya Chéeki',
  'DE' => 'Ʉjerumáani',
  'DJ' => 'Jibúuti',
  'DK' => 'Denimaki',
  'DM' => 'Domínɨka',
  'DO' => 'Jamuhúuri ya Dominɨka',
  'DZ' => 'Alijéria',
  'EC' => 'Íkwado',
  'EE' => 'Estonía',
  'EG' => 'Mísiri',
  'ER' => 'Eriterea',
  'ES' => 'Hisipánia',
  'ET' => 'Ʉhabéeshi',
  'FI' => 'Ufíini',
  'FJ' => 'Fíiji',
  'FK' => 'Visíiwa vya Fakulandi',
  'FM' => 'Mikironésia',
  'FR' => 'Ʉfaráansa',
  'GA' => 'Gabóoni',
  'GB' => 'Ʉɨngeréesa',
  'GD' => 'Girenáada',
  'GE' => 'Jójia',
  'GF' => 'Gwiyáana yʉ Ʉfaráansa',
  'GH' => 'Gáana',
  'GI' => 'Jiburálita',
  'GL' => 'Giriniláandi',
  'GM' => 'Gámbia',
  'GN' => 'Gíine',
  'GP' => 'Gwadelúupe',
  'GQ' => 'Gíine Ikwéeta',
  'GR' => 'Ugiríki',
  'GT' => 'Gwatemáala',
  'GU' => 'Gwani',
  'GW' => 'Gíine Bisáau',
  'GY' => 'Guyáana',
  'HN' => 'Honduráasi',
  'HR' => 'Koréshia',
  'HT' => 'Haíiti',
  'HU' => 'Hungária',
  'ID' => 'Indonésia',
  'IE' => 'Ayaláandi',
  'IL' => 'Isiraéeli',
  'IN' => 'Índia',
  'IQ' => 'Iráaki',
  'IR' => 'Ʉajéemi',
  'IS' => 'Aisiláandi',
  'IT' => 'Itália',
  'JM' => 'Jamáika',
  'JO' => 'Jódani',
  'JP' => 'Japáani',
  'KE' => 'Kéenya',
  'KG' => 'Kirigisitáani',
  'KH' => 'Kambódia',
  'KI' => 'Kiribáati',
  'KM' => 'Komóoro',
  'KN' => 'Mʉtakatíifu kitisi na Nevíisi',
  'KP' => 'Koréa yʉ ʉtʉrʉko',
  'KR' => 'Koréa ya Saame',
  'KW' => 'Kʉwáiti',
  'KY' => 'Visíiwa vya Kayimani',
  'KZ' => 'Kazakasitáani',
  'LA' => 'Laóosi',
  'LB' => 'Lebanóoni',
  'LC' => 'Mʉtakatíifu Lusíia',
  'LI' => 'Lishentéeni',
  'LK' => 'Siriláanka',
  'LR' => 'Liibéria',
  'LS' => 'Lesóoto',
  'LT' => 'Lisuánia',
  'LU' => 'Lasembáagi',
  'LV' => 'Lativia',
  'LY' => 'Líbia',
  'MA' => 'Moróoko',
  'MC' => 'Monáako',
  'MD' => 'Molidóova',
  'MG' => 'Bukíini',
  'MH' => 'Visíiwa vya Marisháali',
  'ML' => 'Máali',
  'MM' => 'Miáama',
  'MN' => 'Mongólia',
  'MP' => 'Visiwa vya Mariana vya Kaskazini',
  'MQ' => 'Maritiníiki',
  'MR' => 'Moritánia',
  'MS' => 'Monteráati',
  'MT' => 'Málita',
  'MU' => 'Moríisi',
  'MV' => 'Modíivu',
  'MW' => 'Maláawi',
  'MX' => 'Mekisiko',
  'MY' => 'Maleísia',
  'MZ' => 'Musumbíiji',
  'NA' => 'Namíbia',
  'NC' => 'Kaledónia Ifya',
  'NE' => 'Níija',
  'NF' => 'Kisíiwa cha Nofifóoki',
  'NG' => 'Niijéria',
  'NI' => 'Nikarágʉa',
  'NL' => 'Ʉholáanzi',
  'NO' => 'Norwe',
  'NP' => 'Nepáali',
  'NR' => 'Naúuru',
  'NU' => 'Niúue',
  'NZ' => 'Nyuzílandi',
  'OM' => 'Ómani',
  'PA' => 'Panáama',
  'PE' => 'Péeru',
  'PF' => 'Polinésia yʉ Ʉfaráansa',
  'PG' => 'Papúua',
  'PH' => 'Ufilipíino',
  'PK' => 'Pakisitáani',
  'PL' => 'Pólandi',
  'PM' => 'Mʉtakatíifu Peéteri na Mɨkaéeli',
  'PN' => 'Patikaírini',
  'PR' => 'Pwetorɨ́ɨko',
  'PS' => 'Mweemberera wa kʉmweeri wa Gáaza',
  'PT' => 'Ʉréeno',
  'PW' => 'Paláau',
  'PY' => 'Paraguáai',
  'QA' => 'Katáari',
  'RE' => 'Reyunióoni',
  'RO' => 'Romaníia',
  'RU' => 'Urúusi',
  'RW' => 'Rwáanda',
  'SA' => 'Saudíia Arabíia',
  'SB' => 'Visíiwa vya Solomóoni',
  'SC' => 'Shelishéeli',
  'SD' => 'Sudáani',
  'SE' => 'Uswíidi',
  'SG' => 'Singapoo',
  'SH' => 'Mʉtakatíifu Heléena',
  'SI' => 'Sulovénia',
  'SK' => 'Sulováakia',
  'SL' => 'Seraleóoni',
  'SM' => 'Samaríino',
  'SN' => 'Senegáali',
  'SO' => 'Somália',
  'SR' => 'Surináamu',
  'ST' => 'Sao Tóome na Pirinsipe',
  'SV' => 'Elisalivado',
  'SY' => 'Síria',
  'SZ' => 'Ʉswáazi',
  'TC' => 'Visíiwa vya Turíiki na Kaíiko',
  'TD' => 'Cháadi',
  'TG' => 'Tóogo',
  'TH' => 'Táilandi',
  'TJ' => 'Tajikisitáani',
  'TK' => 'Tokeláau',
  'TL' => 'Timóori yi Itʉʉmba',
  'TM' => 'Uturukimenisitáani',
  'TN' => 'Tunísia',
  'TO' => 'Tóonga',
  'TR' => 'Uturúuki',
  'TT' => 'Tiriníida ya Tobáago',
  'TV' => 'Tuváalu',
  'TW' => 'Taiwáani',
  'TZ' => 'Taansanía',
  'UA' => 'Ʉkɨréeni',
  'UG' => 'Ʉgáanda',
  'US' => 'Amerɨka',
  'UY' => 'Uruguáai',
  'UZ' => 'Usibekisitáani',
  'VA' => 'Vatikáani',
  'VC' => 'Mʉtakatíifu Viséenti na Gernadíini',
  'VE' => 'Venezuéela',
  'VG' => 'Visíiwa vya Vigíini vya Ʉɨngeréesa',
  'VI' => 'Visíiwa vya Vigíini vya Amerɨ́ka',
  'VN' => 'Vietináamu',
  'VU' => 'Vanuáatu',
  'WF' => 'Walíisi na Futúuna',
  'WS' => 'Samóoa',
  'YE' => 'Yémeni',
  'YT' => 'Mayóote',
  'ZA' => 'Afɨrɨka ya Saame',
  'ZM' => 'Sámbia',
  'ZW' => 'Simbáabwe',
);
