<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Sentry\\Laravel\\' => array($vendorDir . '/sentry/sentry-laravel/src'),
    'Parsedown' => array($vendorDir . '/erusev/parsedown'),
    'OK\\Ipstack\\' => array($vendorDir . '/ok/ipstack-client/src'),
    'JShrink' => array($vendorDir . '/tedivm/jshrink/src'),
);
