<?php
namespace Aws\SageMakerGeospatial\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon SageMaker geospatial capabilities** service.
 */
class SageMakerGeospatialException extends AwsException {}
