<?php
namespace Aws\CleanRooms\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Clean Rooms Service** service.
 */
class CleanRoomsException extends AwsException {}
