<?php

declare(strict_types=1);

namespace Webauthn\CertificateChainChecker;

use Webauthn\MetadataService\CertificateChain\PhpCertificateChainValidator;

/**
 * @deprecated since v4.1. Please use Webauthn\MetadataService\CertificateChainChecker\PhpCertificateChainValidator instead
 * @infection-ignore-all
 */
final class PhpCertificateChainChecker extends PhpCertificateChainValidator
{
}
