<?php
namespace Aws\EntityResolution\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS EntityResolution** service.
 */
class EntityResolutionException extends AwsException {}
