<?php

/**
 * ⚠️ Edition not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'message' => 'Terima kasih telah mendaftar! Silakan periksa email Anda untuk mengkonfirmasi alamat email Anda.',
    'success' => 'Anda telah berhasil memverifikasi akun Anda! Sekarang Anda bisa masuk.',
    'again' => 'Anda harus memverifikasi email Anda sebelum Anda dapat mengakses situs. 
                <br/> Jika Anda belum menerima email konfirmasi, silahkan periksa folder spam Anda.
                <br/> Untuk mendapatkan email konfirmasi baru, silahkan <a href=":url" class="alert-link">klik di sini</a>.',
    'resend' => 'Sebuah pesan konfirmasi telah dikirimkan. Silakan periksa kotak surat Anda.'
];
