<?php
namespace Aws\MediaStore\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Elemental MediaStore** service.
 */
class MediaStoreException extends AwsException {}
