<?php
namespace Aws\Route53RecoveryCluster\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Route53 Recovery Cluster** service.
 */
class Route53RecoveryClusterException extends AwsException {}
