<?php
namespace Aws\KendraRanking\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Kendra Intelligent Ranking** service.
 */
class KendraRankingException extends AwsException {}
