<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => ':contact için hatırlatıcı',
    'greetings' => 'Merhaba :username',
    'want_reminded_of' => ':reason için hatırlatma istediniz',
    'for' => ':name için',
    'comment' => 'Yorum: :comment',
    'footer_contact_info' => 'Bu kişiyle ilgili bilgileri ekleyin, görüntüleyin, tamamlayın ve değiştirin:',
    'footer_contact_info2' => ':name adlı kişinin profilini gör',
    'footer_contact_info2_link' => ':name adlı kişinin profilini gör: :url',

    'notification_subject_line' => 'Yaklaşan etkinliğiniz var',
    'notification_description' => ':count gün içinde (:date tarihinde), şu olay meydana gelecek:',

    'stay_in_touch_subject_line' => ':name ile iletişimde kal',
    'stay_in_touch_subject_description' => ':name ile her :frequency günde bir irtibatta kalmayı hatırlatılmak istediniz.',

    'notifications_whoops' => 'Hoppala!',
    'notifications_hello' => 'Merhaba!',
    'notifications_regards' => 'Saygılarımızla',
    'notifications_footer' => '":actionText" butonuna basmakta sorun yaşıyorsanız, aşağıdaki URL\'yi kopyalayıp web tarayıcınıza yapıştırın: [:actionURL](:actionURL)',
    'notifications_rights' => 'Tüm Hakları Saklıdır',

    'confirmation_email_title' => 'Monica – E-posta Adresi Onayı',
    'confirmation_email_intro'=> 'E-postanızı doğrulamak için aşağıdaki butona tıklayın',
    'confirmation_email_button' => 'E-posta adresini doğrula',
    'confirmation_email_bottom' => 'Eğer bir hesap oluşturmadıysanız, başka bir işlem yapmanıza gerek yoktur.',

    'password_reset_title' => 'Monica – Parola Sıfırlama Bildirimi',
    'password_reset_intro' => 'Hesabınız için bir parola sıfırlama talebi aldığımız için bu e-postayı alıyorsunuz.',
    'password_reset_button' => 'Parola Sıfırla',
    'password_reset_expiration' => 'Bu parola sıfırlama linkinin geçerlilik süresi :count dakika içinde dolacaktır.',
    'password_reset_bottom' => 'Eğer parola sıfırlama talebinde bulunmadıysanız, başka bir işlem yapmanıza gerek yoktur.',

    'invitation_title' => 'Monica - :name tarafından davet edildiniz',
    'invitation_intro' => ':name (:email) tarafından güzel bir Kişisel İlişki Yönetimi aracı olan Monica\'yı kullanmaya davet edildiniz.',
    'invitation_link' => 'Daveti kabul etmek için aşağıdaki linke tıklayın:',
    'invitation_button' => 'Daveti kabul et',
    'invitation_expiration' => 'Bu linkin süresi :count gün içinde dolacaktır.',

    'export_title' => 'Dışa aktarım dosyanız hazır',
    'export_description' => ':date tarihinde verilerinizi indirmek için talep oluşturdunuz. Şimdi indirilmeye hazır.',
    'export_download' => 'Download export',

];
