<?php
namespace Aws\KinesisVideo\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Kinesis Video Streams** service.
 */
class KinesisVideoException extends AwsException {}
