<?php

/**
 * ⚠️ Edition not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'message' => 'Ευχαριστούμε για την εγγραφή σας! Παρακαλούμε ελέγξτε τα email σας για να επιβεβαιώσετε την διεύθυνση email σας.',
    'success' => 'Έχετε επιβεβαιώσει το λογαριασμό σας! Τώρα μπορείτε να συνδεθείτε.',
    'again' => 'Πρέπει να επιβεβαιώσετε το email σας προτού σας επιτραπεί η είσοδος στον ιστότοπο.
                <br/>Αν δεν έχετε λάβει το email επιβεβαίωσης ελέγξτε τον φάκελο spam.
                <br/>Για να σας αποστείλουμε νέο email επιβεβαίωσης παρακαλώ <a href=":url" class="alert-link">πατήστε εδώ</a>.',
    'resend' => 'Σας έχουμε αποστείλει ένα email επιβεβαίωσης. Παρακαλώ ελέγξτε το mailbox σας.'
];
