<?php

return [
    'buttonAdvise' => 'Wenn Ihr Sicherkeitsschlüssel einen Knopf hat, drücken Sie ihn jetzt.',
    'noButtonAdvise' => 'Falls er keinen hat, bitte entfernen Sie das Gerät und schließen Sie es erneut an.',
    'success' => 'Ihr Sicherheitsschlüssel wurde gefunden und verifiziert.',
    'insertKey' => 'Bitte Sicherheitsschlüssel anschließen',
    'cancel' => 'Abbrechen',

    'auth' => [
        'title' => 'Anmeldung mit einem Sicherheitsschlüssel',
    ],

    'register' => [
        'title' => 'Neuen Sicherheitsschlüssel registrieren',
    ],
];
