<?php
// This file was auto-generated from sdk-root/src/data/b2bi/2022-06-23/paginators-1.json
return [ 'pagination' => [ 'ListCapabilities' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'capabilities', ], 'ListPartnerships' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'partnerships', ], 'ListProfiles' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'profiles', ], 'ListTransformers' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'transformers', ], ],];
