<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  96473 => 'ITPC',
  9647400 => 'Itisaluna',
  9647401 => 'Itisaluna',
  9647435 => 'Kalimat',
  9647436 => 'Kalimat',
  9647444 => 'Mobitel',
  9647480 => 'ITC Fanoos',
  9647481 => 'ITC Fanoos',
  9647491 => 'ITPC',
  9647494 => 'Imam Hussien Holy Shrine',
  9647495 => 'IraqTel',
  9647496 => 'IraqTel',
  96475 => 'Korek',
  96476 => 'Omnnea',
  96477 => 'Asiacell',
  96478 => 'Zain',
  96479 => 'Zain',
);
