<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  22601 => 'Onatel',
  22602 => 'Onatel',
  22603 => 'Onatel',
  22605 => 'Orange',
  22606 => 'Orange',
  22607 => 'Orange',
  22650 => 'Onatel',
  22651 => 'Onatel',
  22652 => 'Onatel',
  22653 => 'Onatel',
  22654 => 'Orange',
  22655 => 'Orange',
  22656 => 'Orange',
  22657 => 'Orange',
  22658 => 'Telecel Faso',
  22660 => 'Onatel',
  22661 => 'Onatel',
  22662 => 'Onatel',
  22663 => 'Onatel',
  22664 => 'Orange',
  22665 => 'Orange',
  22666 => 'Orange',
  22667 => 'Orange',
  22668 => 'Telecel Faso',
  22669 => 'Telecel Faso',
  22670 => 'Onatel',
  22671 => 'Onatel',
  22672 => 'Onatel',
  22673 => 'Onatel',
  22674 => 'Orange',
  22675 => 'Orange',
  22676 => 'Orange',
  22677 => 'Orange',
  22678 => 'Telecel Faso',
  22679 => 'Telecel Faso',
);
