<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  673228 => 'DSTCom',
  673229 => 'DSTCom',
  67371 => 'DSTCom',
  67372 => 'DSTCom',
  67373 => 'DSTCom',
  67374 => 'Imagine',
  67377 => 'DSTCom',
  67381 => 'Progresif Cellular',
  67382 => 'Progresif Cellular',
  67383 => 'Progresif Cellular',
  67386 => 'DSTCom',
  67387 => 'DSTCom',
  67388 => 'DSTCom',
  67389 => 'DSTCom',
);
